(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     58560,       5158]*)
(*NotebookOutlinePosition[     59430,       5190]*)
(*  CellTagsIndexPosition[     59386,       5186]*)
(*WindowFrame->Normal*)



Notebook[{


Cell[CellGroupData[{Cell["\<\
Creating Fuzzy Sets
 
 
 
 \
\>", "Title",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Introduction", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
The Fuzzy Logic Pack provides a number of convenient ways to create fuzzy \
sets. In this chapter, we demonstrate these functions and the options \
associated with each function. \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
First we need to load the proper routines. This is done with the following \
command. \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Needs[\"FuzzyLogic`Master`\"]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
If the package loading command fails, verify that the directory containing \
the Fuzzy Logic directory is on Mathematica's $Path. You can use the command \
AppendTo[$Path, \"directory\"]. For convenience, this should be in your \
init.m file.\
\>", "SmallText",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Create a Trapezoidal Fuzzy Set", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
FuzzyTrapezoid[a,b,c,d,h,opts] returns a fuzzy set with membership grades \
that linearly increase from 0 to h in the range a to b, is h in the range b \
to c, and linearly decrease from h to 0 in the range c to d. Arguments a, b, \
c, and d must be integers in increasing order, and h must be a value between \
0 and 1 inclusive. If a value for h is not specified, the function will use h \
= 1. The universal space may be explicitly defined using the UniversalSpace \
option, or if a universal space is not specified, the default universal space \
is used. \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
This example shows how to create a trapezoidal fuzzy set with height 0.9. \
Note that we explicitly set the universal space for this fuzzy set.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["\<\
FS1 = FuzzyTrapezoid[1,5,9,15,0.9,
        UniversalSpace->{0,25}]\
\>", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
FuzzySet[{{2, 0.225}, {3, 0.45}, {4, 0.675}, {5, 0.9}, 
 
   {6, 0.9}, {7, 0.9}, {8, 0.9}, {9, 0.9}, {10, 0.75}, 
 
   {11, 0.6}, {12, 0.45}, {13, 0.2999999999999998}, 
 
   {14, 0.15}}, UniversalSpace -> {0, 25}]









\
\>", "\<\
FuzzySet[{{2, 0.225}, {3, 0.45}, {4, 0.675}, {5, 0.9}, 
 
   {6, 0.9}, {7, 0.9}, {8, 0.9}, {9, 0.9}, {10, 0.75}, 
 
   {11, 0.6}, {12, 0.45}, {13, 0.3}, {14, 0.15}}, 
 
  UniversalSpace -> {0, 25}]\
\>"], "Output",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell["\<\
After evaluating this command, we receive a fuzzy set containing a list of \
the element and membership grade pairs followed by a universal space. \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
When studying fuzzy sets, it is often more instructive to look at fuzzy sets \
graphically. A description of the graphing functions and how to use them \
appears later in this manual. We use one of the graphing functions here to \
look at our newly created fuzzy set.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzyPlot[FS1];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.037037 0.037037 0 0.618034 [
[(1)] .07407 0 0 2 Msboxa
[(3)] .14815 0 0 2 Msboxa
[(5)] .22222 0 0 2 Msboxa
[(7)] .2963 0 0 2 Msboxa
[(9)] .37037 0 0 2 Msboxa
[(11)] .44444 0 0 2 Msboxa
[(13)] .51852 0 0 2 Msboxa
[(15)] .59259 0 0 2 Msboxa
[(17)] .66667 0 0 2 Msboxa
[(19)] .74074 0 0 2 Msboxa
[(21)] .81481 0 0 2 Msboxa
[(23)] .88889 0 0 2 Msboxa
[(25)] .96296 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.07407 0 m
.07407 .00625 L
s
P
[(1)] .07407 0 0 2 Mshowa
p
.002 w
.14815 0 m
.14815 .00625 L
s
P
[(3)] .14815 0 0 2 Mshowa
p
.002 w
.22222 0 m
.22222 .00625 L
s
P
[(5)] .22222 0 0 2 Mshowa
p
.002 w
.2963 0 m
.2963 .00625 L
s
P
[(7)] .2963 0 0 2 Mshowa
p
.002 w
.37037 0 m
.37037 .00625 L
s
P
[(9)] .37037 0 0 2 Mshowa
p
.002 w
.44444 0 m
.44444 .00625 L
s
P
[(11)] .44444 0 0 2 Mshowa
p
.002 w
.51852 0 m
.51852 .00625 L
s
P
[(13)] .51852 0 0 2 Mshowa
p
.002 w
.59259 0 m
.59259 .00625 L
s
P
[(15)] .59259 0 0 2 Mshowa
p
.002 w
.66667 0 m
.66667 .00625 L
s
P
[(17)] .66667 0 0 2 Mshowa
p
.002 w
.74074 0 m
.74074 .00625 L
s
P
[(19)] .74074 0 0 2 Mshowa
p
.002 w
.81481 0 m
.81481 .00625 L
s
P
[(21)] .81481 0 0 2 Mshowa
p
.002 w
.88889 0 m
.88889 .00625 L
s
P
[(23)] .88889 0 0 2 Mshowa
p
.002 w
.96296 0 m
.96296 .00625 L
s
P
[(25)] .96296 0 0 2 Mshowa
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
p
p
2.5 Mabswid
.03704 0 m
.03704 0 L
s
P
p
2.5 Mabswid
.07407 0 m
.07407 0 L
s
P
p
2.5 Mabswid
.11111 .13906 m
.11111 0 L
s
P
p
2.5 Mabswid
.14815 .27812 m
.14815 0 L
s
P
p
2.5 Mabswid
.18519 .41717 m
.18519 0 L
s
P
p
2.5 Mabswid
.22222 .55623 m
.22222 0 L
s
P
p
2.5 Mabswid
.25926 .55623 m
.25926 0 L
s
P
p
2.5 Mabswid
.2963 .55623 m
.2963 0 L
s
P
p
2.5 Mabswid
.33333 .55623 m
.33333 0 L
s
P
p
2.5 Mabswid
.37037 .55623 m
.37037 0 L
s
P
p
2.5 Mabswid
.40741 .46353 m
.40741 0 L
s
P
p
2.5 Mabswid
.44444 .37082 m
.44444 0 L
s
P
p
2.5 Mabswid
.48148 .27812 m
.48148 0 L
s
P
p
2.5 Mabswid
.51852 .18541 m
.51852 0 L
s
P
p
2.5 Mabswid
.55556 .09271 m
.55556 0 L
s
P
p
2.5 Mabswid
.59259 0 m
.59259 0 L
s
P
p
2.5 Mabswid
.62963 0 m
.62963 0 L
s
P
p
2.5 Mabswid
.66667 0 m
.66667 0 L
s
P
p
2.5 Mabswid
.7037 0 m
.7037 0 L
s
P
p
2.5 Mabswid
.74074 0 m
.74074 0 L
s
P
p
2.5 Mabswid
.77778 0 m
.77778 0 L
s
P
p
2.5 Mabswid
.81481 0 m
.81481 0 L
s
P
p
2.5 Mabswid
.85185 0 m
.85185 0 L
s
P
p
2.5 Mabswid
.88889 0 m
.88889 0 L
s
P
p
2.5 Mabswid
.92593 0 m
.92593 0 L
s
P
p
2.5 Mabswid
.96296 0 m
.96296 0 L
s
P
P
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{396, 244},
  ImageMargins->{{33, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]],

Cell["\<\
Following is another example of creating a trapezoidal fuzzy set. This time, \
we give the vertices of the trapezoid and allow the function to provide a \
default setting for the height and universal space. Another thing to note \
about this example is that the second and third parameters for specifying the \
trapezoid are the same. This technique is used to create triangular fuzzy \
sets.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FS2 = FuzzyTrapezoid[3,9,9,17]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
FuzzySet[{{4, 1/6}, {5, 1/3}, {6, 1/2}, {7, 2/3}, {8, 5/6}, 
 
   {9, 1}, {10, 7/8}, {11, 3/4}, {12, 5/8}, {13, 1/2}, 
 
   {14, 3/8}, {15, 1/4}, {16, 1/8}}, 
 
  UniversalSpace -> {0, 20}]









\
\>", "\<\
              1       1       1       2       5
FuzzySet[{{4, -}, {5, -}, {6, -}, {7, -}, {8, -}, {9, 1}, 
              6       3       2       3       6
 
        7        3        5        1        3        1
   {10, -}, {11, -}, {12, -}, {13, -}, {14, -}, {15, -}, 
        8        4        8        2        8        4
 
        1
   {16, -}}, UniversalSpace -> {0, 20}]
        8\
\>"], "Output",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["FuzzyPlot[FS2];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0454545 0.0454545 0 0.618034 [
[(1)] .09091 0 0 2 Msboxa
[(3)] .18182 0 0 2 Msboxa
[(5)] .27273 0 0 2 Msboxa
[(7)] .36364 0 0 2 Msboxa
[(9)] .45455 0 0 2 Msboxa
[(11)] .54545 0 0 2 Msboxa
[(13)] .63636 0 0 2 Msboxa
[(15)] .72727 0 0 2 Msboxa
[(17)] .81818 0 0 2 Msboxa
[(19)] .90909 0 0 2 Msboxa
[(21)] 1 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.09091 0 m
.09091 .00625 L
s
P
[(1)] .09091 0 0 2 Mshowa
p
.002 w
.18182 0 m
.18182 .00625 L
s
P
[(3)] .18182 0 0 2 Mshowa
p
.002 w
.27273 0 m
.27273 .00625 L
s
P
[(5)] .27273 0 0 2 Mshowa
p
.002 w
.36364 0 m
.36364 .00625 L
s
P
[(7)] .36364 0 0 2 Mshowa
p
.002 w
.45455 0 m
.45455 .00625 L
s
P
[(9)] .45455 0 0 2 Mshowa
p
.002 w
.54545 0 m
.54545 .00625 L
s
P
[(11)] .54545 0 0 2 Mshowa
p
.002 w
.63636 0 m
.63636 .00625 L
s
P
[(13)] .63636 0 0 2 Mshowa
p
.002 w
.72727 0 m
.72727 .00625 L
s
P
[(15)] .72727 0 0 2 Mshowa
p
.002 w
.81818 0 m
.81818 .00625 L
s
P
[(17)] .81818 0 0 2 Mshowa
p
.002 w
.90909 0 m
.90909 .00625 L
s
P
[(19)] .90909 0 0 2 Mshowa
p
.002 w
1 0 m
1 .00625 L
s
P
[(21)] 1 0 0 2 Mshowa
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
p
p
2.5 Mabswid
.04545 0 m
.04545 0 L
s
P
p
2.5 Mabswid
.09091 0 m
.09091 0 L
s
P
p
2.5 Mabswid
.13636 0 m
.13636 0 L
s
P
p
2.5 Mabswid
.18182 0 m
.18182 0 L
s
P
p
2.5 Mabswid
.22727 .10301 m
.22727 0 L
s
P
p
2.5 Mabswid
.27273 .20601 m
.27273 0 L
s
P
p
2.5 Mabswid
.31818 .30902 m
.31818 0 L
s
P
p
2.5 Mabswid
.36364 .41202 m
.36364 0 L
s
P
p
2.5 Mabswid
.40909 .51503 m
.40909 0 L
s
P
p
2.5 Mabswid
.45455 .61803 m
.45455 0 L
s
P
p
2.5 Mabswid
.5 .54078 m
.5 0 L
s
P
p
2.5 Mabswid
.54545 .46353 m
.54545 0 L
s
P
p
2.5 Mabswid
.59091 .38627 m
.59091 0 L
s
P
p
2.5 Mabswid
.63636 .30902 m
.63636 0 L
s
P
p
2.5 Mabswid
.68182 .23176 m
.68182 0 L
s
P
p
2.5 Mabswid
.72727 .15451 m
.72727 0 L
s
P
p
2.5 Mabswid
.77273 .07725 m
.77273 0 L
s
P
p
2.5 Mabswid
.81818 0 m
.81818 0 L
s
P
p
2.5 Mabswid
.86364 0 m
.86364 0 L
s
P
p
2.5 Mabswid
.90909 0 m
.90909 0 L
s
P
p
2.5 Mabswid
.95455 0 m
.95455 0 L
s
P
P
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{398, 246},
  ImageMargins->{{33, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Create a Gaussian Fuzzy Set", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
FuzzyGaussian[mu,sigma,opts] returns a new fuzzy set whose membership grades \
represent a normalized Gaussian function with a mean of mu and a width of \
sigma.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
In this example, we create a Gaussian fuzzy set centered at 8 with a width of \
4. Note that we chose to specify our own universal space instead of accepting \
the default setting.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FS3 = FuzzyGaussian[8,3,UniversalSpace->{0,15}]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
FuzzySet[{{0, 0.000815987835072148}, 
 
   {1, 0.004320239474094068}, {2, 0.01831563888873418}, 
 
   {3, 0.06217652402211633}, {4, 0.1690133154060661}, 
 
   {5, 0.3678794411714423}, {6, 0.6411803884299547}, 
 
   {7, 0.89483931681437}, {8, 1.}, {9, 0.89483931681437}, 
 
   {10, 0.6411803884299547}, {11, 0.3678794411714423}, 
 
   {12, 0.1690133154060661}, {13, 0.06217652402211633}, 
 
   {14, 0.01831563888873418}, {15, 0.004320239474094068}}, 
 
  UniversalSpace -> {0, 15}]









\
\>", "\<\
FuzzySet[{{0, 0.000815988}, {1, 0.00432024}, {2, 0.0183156}, 
 
   {3, 0.0621765}, {4, 0.169013}, {5, 0.367879}, 
 
   {6, 0.64118}, {7, 0.894839}, {8, 1.}, {9, 0.894839}, 
 
   {10, 0.64118}, {11, 0.367879}, {12, 0.169013}, 
 
   {13, 0.0621765}, {14, 0.0183156}, {15, 0.00432024}}, 
 
  UniversalSpace -> {0, 15}]\
\>"], "Output",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["FuzzyPlot[FS3];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0588235 0.0588235 0 0.618034 [
[(1)] .11765 0 0 2 Msboxa
[(3)] .23529 0 0 2 Msboxa
[(5)] .35294 0 0 2 Msboxa
[(7)] .47059 0 0 2 Msboxa
[(9)] .58824 0 0 2 Msboxa
[(11)] .70588 0 0 2 Msboxa
[(13)] .82353 0 0 2 Msboxa
[(15)] .94118 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.11765 0 m
.11765 .00625 L
s
P
[(1)] .11765 0 0 2 Mshowa
p
.002 w
.23529 0 m
.23529 .00625 L
s
P
[(3)] .23529 0 0 2 Mshowa
p
.002 w
.35294 0 m
.35294 .00625 L
s
P
[(5)] .35294 0 0 2 Mshowa
p
.002 w
.47059 0 m
.47059 .00625 L
s
P
[(7)] .47059 0 0 2 Mshowa
p
.002 w
.58824 0 m
.58824 .00625 L
s
P
[(9)] .58824 0 0 2 Mshowa
p
.002 w
.70588 0 m
.70588 .00625 L
s
P
[(11)] .70588 0 0 2 Mshowa
p
.002 w
.82353 0 m
.82353 .00625 L
s
P
[(13)] .82353 0 0 2 Mshowa
p
.002 w
.94118 0 m
.94118 .00625 L
s
P
[(15)] .94118 0 0 2 Mshowa
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
p
p
2.5 Mabswid
.05882 0 m
.05882 0 L
s
P
p
2.5 Mabswid
.11765 .00267 m
.11765 0 L
s
P
p
2.5 Mabswid
.17647 .01132 m
.17647 0 L
s
P
p
2.5 Mabswid
.23529 .03843 m
.23529 0 L
s
P
p
2.5 Mabswid
.29412 .10446 m
.29412 0 L
s
P
p
2.5 Mabswid
.35294 .22736 m
.35294 0 L
s
P
p
2.5 Mabswid
.41176 .39627 m
.41176 0 L
s
P
p
2.5 Mabswid
.47059 .55304 m
.47059 0 L
s
P
p
2.5 Mabswid
.52941 .61803 m
.52941 0 L
s
P
p
2.5 Mabswid
.58824 .55304 m
.58824 0 L
s
P
p
2.5 Mabswid
.64706 .39627 m
.64706 0 L
s
P
p
2.5 Mabswid
.70588 .22736 m
.70588 0 L
s
P
p
2.5 Mabswid
.76471 .10446 m
.76471 0 L
s
P
p
2.5 Mabswid
.82353 .03843 m
.82353 0 L
s
P
p
2.5 Mabswid
.88235 .01132 m
.88235 0 L
s
P
p
2.5 Mabswid
.94118 .00267 m
.94118 0 L
s
P
P
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{398, 246},
  ImageMargins->{{33, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Create a Fuzzy Set from a Function", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
CreateFuzzySet[func,{a,b},opts] returns a fuzzy set with membership grades \
defined by func in the range a to b inclusive. If no range is given, the \
function is applied to all of the elements in the universal space. \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Note: The function you provide must return values between 0 and 1 over the \
range provided to create a valid fuzzy set.

This is an example of creating a fuzzy set using a piecewise function. The \
first definition defines the function to use to create the fuzzy set.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
MyFunc1[x_] := Which[x <= 5, 0,
                     x > 5 && x < 10, (x-5)/5,
                     x >= 10 && x <= 15, 10/x,
                     x > 15, 0.6]\
\>", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FS4 = CreateFuzzySet[MyFunc1]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
FuzzySet[{{6, 0.2}, {7, 0.4}, {8, 0.6}, {9, 0.8}, {10, 1.}, 
 
   {11, 0.909090909090909}, {12, 0.833333333333333}, 
 
   {13, 0.7692307692307693}, {14, 0.7142857142857144}, 
 
   {15, 0.6666666666666666}, {16, 0.6}, {17, 0.6}, 
 
   {18, 0.6}, {19, 0.6}, {20, 0.6}}, 
 
  UniversalSpace -> {0, 20}]









\
\>", "\<\
FuzzySet[{{6, 0.2}, {7, 0.4}, {8, 0.6}, {9, 0.8}, {10, 1.}, 
 
   {11, 0.909091}, {12, 0.833333}, {13, 0.769231}, 
 
   {14, 0.714286}, {15, 0.666667}, {16, 0.6}, {17, 0.6}, 
 
   {18, 0.6}, {19, 0.6}, {20, 0.6}}, 
 
  UniversalSpace -> {0, 20}]\
\>"], "Output",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["FuzzyPlot[FS4];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0454545 0.0454545 0 0.618034 [
[(1)] .09091 0 0 2 Msboxa
[(3)] .18182 0 0 2 Msboxa
[(5)] .27273 0 0 2 Msboxa
[(7)] .36364 0 0 2 Msboxa
[(9)] .45455 0 0 2 Msboxa
[(11)] .54545 0 0 2 Msboxa
[(13)] .63636 0 0 2 Msboxa
[(15)] .72727 0 0 2 Msboxa
[(17)] .81818 0 0 2 Msboxa
[(19)] .90909 0 0 2 Msboxa
[(21)] 1 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.09091 0 m
.09091 .00625 L
s
P
[(1)] .09091 0 0 2 Mshowa
p
.002 w
.18182 0 m
.18182 .00625 L
s
P
[(3)] .18182 0 0 2 Mshowa
p
.002 w
.27273 0 m
.27273 .00625 L
s
P
[(5)] .27273 0 0 2 Mshowa
p
.002 w
.36364 0 m
.36364 .00625 L
s
P
[(7)] .36364 0 0 2 Mshowa
p
.002 w
.45455 0 m
.45455 .00625 L
s
P
[(9)] .45455 0 0 2 Mshowa
p
.002 w
.54545 0 m
.54545 .00625 L
s
P
[(11)] .54545 0 0 2 Mshowa
p
.002 w
.63636 0 m
.63636 .00625 L
s
P
[(13)] .63636 0 0 2 Mshowa
p
.002 w
.72727 0 m
.72727 .00625 L
s
P
[(15)] .72727 0 0 2 Mshowa
p
.002 w
.81818 0 m
.81818 .00625 L
s
P
[(17)] .81818 0 0 2 Mshowa
p
.002 w
.90909 0 m
.90909 .00625 L
s
P
[(19)] .90909 0 0 2 Mshowa
p
.002 w
1 0 m
1 .00625 L
s
P
[(21)] 1 0 0 2 Mshowa
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
p
p
2.5 Mabswid
.04545 0 m
.04545 0 L
s
P
p
2.5 Mabswid
.09091 0 m
.09091 0 L
s
P
p
2.5 Mabswid
.13636 0 m
.13636 0 L
s
P
p
2.5 Mabswid
.18182 0 m
.18182 0 L
s
P
p
2.5 Mabswid
.22727 0 m
.22727 0 L
s
P
p
2.5 Mabswid
.27273 0 m
.27273 0 L
s
P
p
2.5 Mabswid
.31818 .12361 m
.31818 0 L
s
P
p
2.5 Mabswid
.36364 .24721 m
.36364 0 L
s
P
p
2.5 Mabswid
.40909 .37082 m
.40909 0 L
s
P
p
2.5 Mabswid
.45455 .49443 m
.45455 0 L
s
P
p
2.5 Mabswid
.5 .61803 m
.5 0 L
s
P
p
2.5 Mabswid
.54545 .56185 m
.54545 0 L
s
P
p
2.5 Mabswid
.59091 .51503 m
.59091 0 L
s
P
p
2.5 Mabswid
.63636 .47541 m
.63636 0 L
s
P
p
2.5 Mabswid
.68182 .44145 m
.68182 0 L
s
P
p
2.5 Mabswid
.72727 .41202 m
.72727 0 L
s
P
p
2.5 Mabswid
.77273 .37082 m
.77273 0 L
s
P
p
2.5 Mabswid
.81818 .37082 m
.81818 0 L
s
P
p
2.5 Mabswid
.86364 .37082 m
.86364 0 L
s
P
p
2.5 Mabswid
.90909 .37082 m
.90909 0 L
s
P
p
2.5 Mabswid
.95455 .37082 m
.95455 0 L
s
P
P
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{399, 246},
  ImageMargins->{{33, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]],

Cell["\<\
Note: For this example we did not specify a universal space, so the function \
used the default setting. You can change the default setting for an option \
with the SetOptions command. Let us do that now.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["SetOptions[FuzzySet,UniversalSpace->{2,23}]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
{UniversalSpace -> {2, 23}}









\
\>", "\<\
{UniversalSpace -> {2, 23}}\
\>"], "Output",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell["\<\
Now we reevaluate the previous function, and the same option we set is used \
this time.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["NewFS4 = CreateFuzzySet[MyFunc1]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
FuzzySet[{{6, 0.2}, {7, 0.4}, {8, 0.6}, {9, 0.8}, {10, 1.}, 
 
   {11, 0.909090909090909}, {12, 0.833333333333333}, 
 
   {13, 0.7692307692307693}, {14, 0.7142857142857144}, 
 
   {15, 0.6666666666666666}, {16, 0.6}, {17, 0.6}, 
 
   {18, 0.6}, {19, 0.6}, {20, 0.6}, {21, 0.6}, {22, 0.6}, 
 
   {23, 0.6}}, UniversalSpace -> {2, 23}]









\
\>", "\<\
FuzzySet[{{6, 0.2}, {7, 0.4}, {8, 0.6}, {9, 0.8}, {10, 1.}, 
 
   {11, 0.909091}, {12, 0.833333}, {13, 0.769231}, 
 
   {14, 0.714286}, {15, 0.666667}, {16, 0.6}, {17, 0.6}, 
 
   {18, 0.6}, {19, 0.6}, {20, 0.6}, {21, 0.6}, {22, 0.6}, 
 
   {23, 0.6}}, UniversalSpace -> {2, 23}]\
\>"], "Output",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["FuzzyPlot[NewFS4];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0434783 0.0434783 0 0.618034 [
[(3)] .08696 0 0 2 Msboxa
[(5)] .17391 0 0 2 Msboxa
[(7)] .26087 0 0 2 Msboxa
[(9)] .34783 0 0 2 Msboxa
[(11)] .43478 0 0 2 Msboxa
[(13)] .52174 0 0 2 Msboxa
[(15)] .6087 0 0 2 Msboxa
[(17)] .69565 0 0 2 Msboxa
[(19)] .78261 0 0 2 Msboxa
[(21)] .86957 0 0 2 Msboxa
[(23)] .95652 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.08696 0 m
.08696 .00625 L
s
P
[(3)] .08696 0 0 2 Mshowa
p
.002 w
.17391 0 m
.17391 .00625 L
s
P
[(5)] .17391 0 0 2 Mshowa
p
.002 w
.26087 0 m
.26087 .00625 L
s
P
[(7)] .26087 0 0 2 Mshowa
p
.002 w
.34783 0 m
.34783 .00625 L
s
P
[(9)] .34783 0 0 2 Mshowa
p
.002 w
.43478 0 m
.43478 .00625 L
s
P
[(11)] .43478 0 0 2 Mshowa
p
.002 w
.52174 0 m
.52174 .00625 L
s
P
[(13)] .52174 0 0 2 Mshowa
p
.002 w
.6087 0 m
.6087 .00625 L
s
P
[(15)] .6087 0 0 2 Mshowa
p
.002 w
.69565 0 m
.69565 .00625 L
s
P
[(17)] .69565 0 0 2 Mshowa
p
.002 w
.78261 0 m
.78261 .00625 L
s
P
[(19)] .78261 0 0 2 Mshowa
p
.002 w
.86957 0 m
.86957 .00625 L
s
P
[(21)] .86957 0 0 2 Mshowa
p
.002 w
.95652 0 m
.95652 .00625 L
s
P
[(23)] .95652 0 0 2 Mshowa
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
p
p
2.5 Mabswid
.04348 0 m
.04348 0 L
s
P
p
2.5 Mabswid
.08696 0 m
.08696 0 L
s
P
p
2.5 Mabswid
.13043 0 m
.13043 0 L
s
P
p
2.5 Mabswid
.17391 0 m
.17391 0 L
s
P
p
2.5 Mabswid
.21739 .12361 m
.21739 0 L
s
P
p
2.5 Mabswid
.26087 .24721 m
.26087 0 L
s
P
p
2.5 Mabswid
.30435 .37082 m
.30435 0 L
s
P
p
2.5 Mabswid
.34783 .49443 m
.34783 0 L
s
P
p
2.5 Mabswid
.3913 .61803 m
.3913 0 L
s
P
p
2.5 Mabswid
.43478 .56185 m
.43478 0 L
s
P
p
2.5 Mabswid
.47826 .51503 m
.47826 0 L
s
P
p
2.5 Mabswid
.52174 .47541 m
.52174 0 L
s
P
p
2.5 Mabswid
.56522 .44145 m
.56522 0 L
s
P
p
2.5 Mabswid
.6087 .41202 m
.6087 0 L
s
P
p
2.5 Mabswid
.65217 .37082 m
.65217 0 L
s
P
p
2.5 Mabswid
.69565 .37082 m
.69565 0 L
s
P
p
2.5 Mabswid
.73913 .37082 m
.73913 0 L
s
P
p
2.5 Mabswid
.78261 .37082 m
.78261 0 L
s
P
p
2.5 Mabswid
.82609 .37082 m
.82609 0 L
s
P
p
2.5 Mabswid
.86957 .37082 m
.86957 0 L
s
P
p
2.5 Mabswid
.91304 .37082 m
.91304 0 L
s
P
p
2.5 Mabswid
.95652 .37082 m
.95652 0 L
s
P
P
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{398, 246},
  ImageMargins->{{33, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]],

Cell["\<\
Let us put the default back to its original setting before our next \
example.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["SetOptions[FuzzySet,UniversalSpace->{0,20}]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
{UniversalSpace -> {0, 20}}









\
\>", "\<\
{UniversalSpace -> {0, 20}}\
\>"], "Output",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Create a Fuzzy Set Manually", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Fuzzy sets can also be created manually by entering a list of element and \
membership grade pairs surrounded by the FuzzySet head. Here is a simple \
example.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["\<\
FS5 = FuzzySet[{{1,.8},{2,.6},{3,.3},{4,.2}},
        UniversalSpace->{0,10}]\
\>", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
FuzzySet[{{1, 0.8}, {2, 0.6}, {3, 0.3}, {4, 0.2}}, 
 
  UniversalSpace -> {0, 10}]









\
\>", "\<\
FuzzySet[{{1, 0.8}, {2, 0.6}, {3, 0.3}, {4, 0.2}}, 
 
  UniversalSpace -> {0, 10}]\
\>"], "Output",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["FuzzyPlot[FS5];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0833333 0.0833333 0 0.618034 [
[(0)] .08333 0 0 2 Msboxa
[(1)] .16667 0 0 2 Msboxa
[(2)] .25 0 0 2 Msboxa
[(3)] .33333 0 0 2 Msboxa
[(4)] .41667 0 0 2 Msboxa
[(5)] .5 0 0 2 Msboxa
[(6)] .58333 0 0 2 Msboxa
[(7)] .66667 0 0 2 Msboxa
[(8)] .75 0 0 2 Msboxa
[(9)] .83333 0 0 2 Msboxa
[(10)] .91667 0 0 2 Msboxa
[(11)] 1 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.08333 0 m
.08333 .00625 L
s
P
[(0)] .08333 0 0 2 Mshowa
p
.002 w
.16667 0 m
.16667 .00625 L
s
P
[(1)] .16667 0 0 2 Mshowa
p
.002 w
.25 0 m
.25 .00625 L
s
P
[(2)] .25 0 0 2 Mshowa
p
.002 w
.33333 0 m
.33333 .00625 L
s
P
[(3)] .33333 0 0 2 Mshowa
p
.002 w
.41667 0 m
.41667 .00625 L
s
P
[(4)] .41667 0 0 2 Mshowa
p
.002 w
.5 0 m
.5 .00625 L
s
P
[(5)] .5 0 0 2 Mshowa
p
.002 w
.58333 0 m
.58333 .00625 L
s
P
[(6)] .58333 0 0 2 Mshowa
p
.002 w
.66667 0 m
.66667 .00625 L
s
P
[(7)] .66667 0 0 2 Mshowa
p
.002 w
.75 0 m
.75 .00625 L
s
P
[(8)] .75 0 0 2 Mshowa
p
.002 w
.83333 0 m
.83333 .00625 L
s
P
[(9)] .83333 0 0 2 Mshowa
p
.002 w
.91667 0 m
.91667 .00625 L
s
P
[(10)] .91667 0 0 2 Mshowa
p
.002 w
1 0 m
1 .00625 L
s
P
[(11)] 1 0 0 2 Mshowa
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
p
p
2.5 Mabswid
.08333 0 m
.08333 0 L
s
P
p
2.5 Mabswid
.16667 .49443 m
.16667 0 L
s
P
p
2.5 Mabswid
.25 .37082 m
.25 0 L
s
P
p
2.5 Mabswid
.33333 .18541 m
.33333 0 L
s
P
p
2.5 Mabswid
.41667 .12361 m
.41667 0 L
s
P
p
2.5 Mabswid
.5 0 m
.5 0 L
s
P
p
2.5 Mabswid
.58333 0 m
.58333 0 L
s
P
p
2.5 Mabswid
.66667 0 m
.66667 0 L
s
P
p
2.5 Mabswid
.75 0 m
.75 0 L
s
P
p
2.5 Mabswid
.83333 0 m
.83333 0 L
s
P
p
2.5 Mabswid
.91667 0 m
.91667 0 L
s
P
P
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{398, 246},
  ImageMargins->{{33, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Create a Collection of Fuzzy Sets", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
CreateFuzzySets[num,opts] returns a list of num overlapping fuzzy sets that \
span the universal space. The fuzzy sets can be either Triangular or \
Gaussian. The Type option specifies the shape of the new fuzzy sets.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
In this example, we divide the universal space into six triangular fuzzy \
sets. We use an extra option with the FuzzyPlot command to show a continuous \
representation of the fuzzy sets.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Var1 = CreateFuzzySets[6,Type->Triangular,
         UniversalSpace->{0,40}];\
\>", "Input",
  PageWidth->Infinity,
  PageBreakAbove->True,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzyPlot[Var1,PlotJoined->True];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0238095 0 0.618034 [
[(0)] .02381 0 0 2 Msboxa
[(10)] .2619 0 0 2 Msboxa
[(20)] .5 0 0 2 Msboxa
[(30)] .7381 0 0 2 Msboxa
[(40)] .97619 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.02381 0 m
.02381 .00625 L
s
P
[(0)] .02381 0 0 2 Mshowa
p
.002 w
.2619 0 m
.2619 .00625 L
s
P
[(10)] .2619 0 0 2 Mshowa
p
.002 w
.5 0 m
.5 .00625 L
s
P
[(20)] .5 0 0 2 Mshowa
p
.002 w
.7381 0 m
.7381 .00625 L
s
P
[(30)] .7381 0 0 2 Mshowa
p
.002 w
.97619 0 m
.97619 .00625 L
s
P
[(40)] .97619 0 0 2 Mshowa
p
.001 w
.07143 0 m
.07143 .00375 L
s
P
p
.001 w
.11905 0 m
.11905 .00375 L
s
P
p
.001 w
.16667 0 m
.16667 .00375 L
s
P
p
.001 w
.21429 0 m
.21429 .00375 L
s
P
p
.001 w
.30952 0 m
.30952 .00375 L
s
P
p
.001 w
.35714 0 m
.35714 .00375 L
s
P
p
.001 w
.40476 0 m
.40476 .00375 L
s
P
p
.001 w
.45238 0 m
.45238 .00375 L
s
P
p
.001 w
.54762 0 m
.54762 .00375 L
s
P
p
.001 w
.59524 0 m
.59524 .00375 L
s
P
p
.001 w
.64286 0 m
.64286 .00375 L
s
P
p
.001 w
.69048 0 m
.69048 .00375 L
s
P
p
.001 w
.78571 0 m
.78571 .00375 L
s
P
p
.001 w
.83333 0 m
.83333 .00375 L
s
P
p
.001 w
.88095 0 m
.88095 .00375 L
s
P
p
.001 w
.92857 0 m
.92857 .00375 L
s
P
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
1.02062 Mabswid
.02381 .61803 m
.04762 .54078 L
.07143 .46353 L
.09524 .38627 L
.11905 .30902 L
.14286 .23176 L
.16667 .15451 L
.19048 .07725 L
.21429 0 L
.2381 0 L
.2619 0 L
.28571 0 L
.30952 0 L
.33333 0 L
.35714 0 L
.38095 0 L
.40476 0 L
.42857 0 L
.45238 0 L
.47619 0 L
.5 0 L
.52381 0 L
.54762 0 L
.57143 0 L
.59524 0 L
.61905 0 L
.64286 0 L
.66667 0 L
.69048 0 L
.71429 0 L
.7381 0 L
.7619 0 L
.78571 0 L
.80952 0 L
.83333 0 L
.85714 0 L
.88095 0 L
.90476 0 L
.92857 0 L
.95238 0 L
.97619 0 L
s
P
p
.2 0 1 r
1.02062 Mabswid
.02381 0 m
.04762 .07725 L
.07143 .15451 L
.09524 .23176 L
.11905 .30902 L
.14286 .38627 L
.16667 .46353 L
.19048 .54078 L
.21429 .61803 L
.2381 .54078 L
.2619 .46353 L
.28571 .38627 L
.30952 .30902 L
.33333 .23176 L
.35714 .15451 L
.38095 .07725 L
.40476 0 L
.42857 0 L
.45238 0 L
.47619 0 L
.5 0 L
.52381 0 L
.54762 0 L
.57143 0 L
.59524 0 L
.61905 0 L
.64286 0 L
.66667 0 L
.69048 0 L
.71429 0 L
.7381 0 L
.7619 0 L
.78571 0 L
.80952 0 L
.83333 0 L
.85714 0 L
.88095 0 L
.90476 0 L
.92857 0 L
.95238 0 L
.97619 0 L
s
P
p
0 1 .4 r
1.02062 Mabswid
.02381 0 m
.04762 0 L
.07143 0 L
.09524 0 L
.11905 0 L
.14286 0 L
.16667 0 L
.19048 0 L
.21429 0 L
.2381 .07725 L
.2619 .15451 L
.28571 .23176 L
.30952 .30902 L
.33333 .38627 L
.35714 .46353 L
.38095 .54078 L
.40476 .61803 L
.42857 .54078 L
.45238 .46353 L
.47619 .38627 L
.5 .30902 L
.52381 .23176 L
.54762 .15451 L
.57143 .07725 L
.59524 0 L
.61905 0 L
.64286 0 L
.66667 0 L
.69048 0 L
.71429 0 L
.7381 0 L
.7619 0 L
.78571 0 L
.80952 0 L
.83333 0 L
.85714 0 L
.88095 0 L
.90476 0 L
.92857 0 L
.95238 0 L
.97619 0 L
s
P
p
1 .6 0 r
1.02062 Mabswid
.02381 0 m
.04762 0 L
.07143 0 L
.09524 0 L
.11905 0 L
.14286 0 L
.16667 0 L
.19048 0 L
.21429 0 L
.2381 0 L
.2619 0 L
.28571 0 L
.30952 0 L
.33333 0 L
.35714 0 L
.38095 0 L
.40476 0 L
.42857 .07725 L
.45238 .15451 L
.47619 .23176 L
.5 .30902 L
.52381 .38627 L
.54762 .46353 L
.57143 .54078 L
.59524 .61803 L
.61905 .54078 L
.64286 .46353 L
.66667 .38627 L
.69048 .30902 L
.71429 .23176 L
.7381 .15451 L
.7619 .07725 L
.78571 0 L
.80952 0 L
.83333 0 L
.85714 0 L
.88095 0 L
.90476 0 L
.92857 0 L
.95238 0 L
.97619 0 L
s
P
p
.8 0 1 r
1.02062 Mabswid
.02381 0 m
.04762 0 L
.07143 0 L
.09524 0 L
.11905 0 L
.14286 0 L
.16667 0 L
.19048 0 L
.21429 0 L
.2381 0 L
.2619 0 L
.28571 0 L
.30952 0 L
.33333 0 L
.35714 0 L
.38095 0 L
.40476 0 L
.42857 0 L
.45238 0 L
.47619 0 L
.5 0 L
.52381 0 L
.54762 0 L
.57143 0 L
.59524 0 L
.61905 .07725 L
.64286 .15451 L
.66667 .23176 L
.69048 .30902 L
.71429 .38627 L
.7381 .46353 L
.7619 .54078 L
.78571 .61803 L
.80952 .54078 L
.83333 .46353 L
.85714 .38627 L
.88095 .30902 L
.90476 .23176 L
.92857 .15451 L
.95238 .07725 L
.97619 0 L
s
P
p
0 1 1 r
1.02062 Mabswid
.02381 0 m
.04762 0 L
.07143 0 L
.09524 0 L
.11905 0 L
.14286 0 L
.16667 0 L
.19048 0 L
.21429 0 L
.2381 0 L
.2619 0 L
.28571 0 L
.30952 0 L
.33333 0 L
.35714 0 L
.38095 0 L
.40476 0 L
.42857 0 L
.45238 0 L
.47619 0 L
.5 0 L
.52381 0 L
.54762 0 L
.57143 0 L
.59524 0 L
.61905 0 L
.64286 0 L
.66667 0 L
.69048 0 L
.71429 0 L
.7381 0 L
.7619 0 L
.78571 0 L
.80952 .07725 L
.83333 .15451 L
.85714 .23176 L
.88095 .30902 L
.90476 .38627 L
.92857 .46353 L
.95238 .54078 L
.97619 .61803 L
s
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{399, 246},
  ImageMargins->{{33, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]],

Cell["\<\
As a final example of fuzzy set creation, we create a set of seven Gaussian \
fuzzy sets. When specifying the Gaussian type of fuzzy set, you should \
provide a width with the Type option. If no width is specified, a width of 1 \
is used. \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Var2 = {NB,NM,NS,ZO,PS,PM,PB} = 
       CreateFuzzySets[7,Type->Gaussian[4],
         UniversalSpace->{0,38}];\
\>", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzyPlot[Var2,PlotJoined->True];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.025 0.025 0 0.618034 [
[(0)] .025 0 0 2 Msboxa
[(5)] .15 0 0 2 Msboxa
[(10)] .275 0 0 2 Msboxa
[(15)] .4 0 0 2 Msboxa
[(20)] .525 0 0 2 Msboxa
[(25)] .65 0 0 2 Msboxa
[(30)] .775 0 0 2 Msboxa
[(35)] .9 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.025 0 m
.025 .00625 L
s
P
[(0)] .025 0 0 2 Mshowa
p
.002 w
.15 0 m
.15 .00625 L
s
P
[(5)] .15 0 0 2 Mshowa
p
.002 w
.275 0 m
.275 .00625 L
s
P
[(10)] .275 0 0 2 Mshowa
p
.002 w
.4 0 m
.4 .00625 L
s
P
[(15)] .4 0 0 2 Mshowa
p
.002 w
.525 0 m
.525 .00625 L
s
P
[(20)] .525 0 0 2 Mshowa
p
.002 w
.65 0 m
.65 .00625 L
s
P
[(25)] .65 0 0 2 Mshowa
p
.002 w
.775 0 m
.775 .00625 L
s
P
[(30)] .775 0 0 2 Mshowa
p
.002 w
.9 0 m
.9 .00625 L
s
P
[(35)] .9 0 0 2 Mshowa
p
.001 w
.05 0 m
.05 .00375 L
s
P
p
.001 w
.075 0 m
.075 .00375 L
s
P
p
.001 w
.1 0 m
.1 .00375 L
s
P
p
.001 w
.125 0 m
.125 .00375 L
s
P
p
.001 w
.175 0 m
.175 .00375 L
s
P
p
.001 w
.2 0 m
.2 .00375 L
s
P
p
.001 w
.225 0 m
.225 .00375 L
s
P
p
.001 w
.25 0 m
.25 .00375 L
s
P
p
.001 w
.3 0 m
.3 .00375 L
s
P
p
.001 w
.325 0 m
.325 .00375 L
s
P
p
.001 w
.35 0 m
.35 .00375 L
s
P
p
.001 w
.375 0 m
.375 .00375 L
s
P
p
.001 w
.425 0 m
.425 .00375 L
s
P
p
.001 w
.45 0 m
.45 .00375 L
s
P
p
.001 w
.475 0 m
.475 .00375 L
s
P
p
.001 w
.5 0 m
.5 .00375 L
s
P
p
.001 w
.55 0 m
.55 .00375 L
s
P
p
.001 w
.575 0 m
.575 .00375 L
s
P
p
.001 w
.6 0 m
.6 .00375 L
s
P
p
.001 w
.625 0 m
.625 .00375 L
s
P
p
.001 w
.675 0 m
.675 .00375 L
s
P
p
.001 w
.7 0 m
.7 .00375 L
s
P
p
.001 w
.725 0 m
.725 .00375 L
s
P
p
.001 w
.75 0 m
.75 .00375 L
s
P
p
.001 w
.8 0 m
.8 .00375 L
s
P
p
.001 w
.825 0 m
.825 .00375 L
s
P
p
.001 w
.85 0 m
.85 .00375 L
s
P
p
.001 w
.875 0 m
.875 .00375 L
s
P
p
.001 w
.925 0 m
.925 .00375 L
s
P
p
.001 w
.95 0 m
.95 .00375 L
s
P
p
.001 w
.975 0 m
.975 .00375 L
s
P
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
.94491 Mabswid
.025 .61803 m
.05 .58059 L
.075 .48133 L
.1 .35215 L
.125 .22736 L
.15 .12955 L
.175 .06514 L
.2 .02891 L
.225 .01132 L
.25 .00391 L
.275 .00119 L
.3 0 L
.325 0 L
.35 0 L
.375 0 L
.4 0 L
.425 0 L
.45 0 L
.475 0 L
.5 0 L
.525 0 L
.55 0 L
.575 0 L
.6 0 L
.625 0 L
.65 0 L
.675 0 L
.7 0 L
.725 0 L
.75 0 L
.775 0 L
.8 0 L
.825 0 L
.85 0 L
.875 0 L
.9 0 L
.925 0 L
.95 0 L
.975 0 L
s
P
p
.2 0 1 r
.94491 Mabswid
.025 .06514 m
.05 .12955 L
.075 .22736 L
.1 .35215 L
.125 .48133 L
.15 .58059 L
.175 .61803 L
.2 .58059 L
.225 .48133 L
.25 .35215 L
.275 .22736 L
.3 .12955 L
.325 .06514 L
.35 .02891 L
.375 .01132 L
.4 .00391 L
.425 .00119 L
.45 0 L
.475 0 L
.5 0 L
.525 0 L
.55 0 L
.575 0 L
.6 0 L
.625 0 L
.65 0 L
.675 0 L
.7 0 L
.725 0 L
.75 0 L
.775 0 L
.8 0 L
.825 0 L
.85 0 L
.875 0 L
.9 0 L
.925 0 L
.95 0 L
.975 0 L
s
P
p
0 1 .4 r
.94491 Mabswid
.025 0 m
.05 0 L
.075 .00119 L
.1 .00391 L
.125 .01132 L
.15 .02891 L
.175 .06514 L
.2 .12955 L
.225 .22736 L
.25 .35215 L
.275 .48133 L
.3 .58059 L
.325 .61803 L
.35 .58059 L
.375 .48133 L
.4 .35215 L
.425 .22736 L
.45 .12955 L
.475 .06514 L
.5 .02891 L
.525 .01132 L
.55 .00391 L
.575 .00119 L
.6 0 L
.625 0 L
.65 0 L
.675 0 L
.7 0 L
.725 0 L
.75 0 L
.775 0 L
.8 0 L
.825 0 L
.85 0 L
.875 0 L
.9 0 L
.925 0 L
.95 0 L
.975 0 L
s
P
p
1 .6 0 r
.94491 Mabswid
.025 0 m
.05 0 L
.075 0 L
.1 0 L
.125 0 L
.15 0 L
.175 0 L
.2 0 L
.225 .00119 L
.25 .00391 L
.275 .01132 L
.3 .02891 L
.325 .06514 L
.35 .12955 L
.375 .22736 L
.4 .35215 L
.425 .48133 L
.45 .58059 L
.475 .61803 L
.5 .58059 L
.525 .48133 L
.55 .35215 L
.575 .22736 L
.6 .12955 L
.625 .06514 L
.65 .02891 L
.675 .01132 L
.7 .00391 L
.725 .00119 L
.75 0 L
.775 0 L
.8 0 L
.825 0 L
.85 0 L
.875 0 L
.9 0 L
.925 0 L
.95 0 L
.975 0 L
s
P
p
.8 0 1 r
.94491 Mabswid
.025 0 m
.05 0 L
.075 0 L
.1 0 L
.125 0 L
.15 0 L
.175 0 L
.2 0 L
.225 0 L
.25 0 L
.275 0 L
.3 0 L
.325 0 L
.35 0 L
.375 .00119 L
.4 .00391 L
.425 .01132 L
.45 .02891 L
.475 .06514 L
.5 .12955 L
.525 .22736 L
.55 .35215 L
.575 .48133 L
.6 .58059 L
.625 .61803 L
.65 .58059 L
.675 .48133 L
.7 .35215 L
.725 .22736 L
.75 .12955 L
.775 .06514 L
.8 .02891 L
.825 .01132 L
.85 .00391 L
.875 .00119 L
.9 0 L
.925 0 L
.95 0 L
.975 0 L
s
P
p
0 1 1 r
.94491 Mabswid
.025 0 m
.05 0 L
.075 0 L
.1 0 L
.125 0 L
.15 0 L
.175 0 L
.2 0 L
.225 0 L
.25 0 L
.275 0 L
.3 0 L
.325 0 L
.35 0 L
.375 0 L
.4 0 L
.425 0 L
.45 0 L
.475 0 L
.5 0 L
.525 .00119 L
.55 .00391 L
.575 .01132 L
.6 .02891 L
.625 .06514 L
.65 .12955 L
.675 .22736 L
.7 .35215 L
.725 .48133 L
.75 .58059 L
.775 .61803 L
.8 .58059 L
.825 .48133 L
.85 .35215 L
.875 .22736 L
.9 .12955 L
.925 .06514 L
.95 .02891 L
.975 .01132 L
s
P
p
.8 1 0 r
.94491 Mabswid
.025 0 m
.05 0 L
.075 0 L
.1 0 L
.125 0 L
.15 0 L
.175 0 L
.2 0 L
.225 0 L
.25 0 L
.275 0 L
.3 0 L
.325 0 L
.35 0 L
.375 0 L
.4 0 L
.425 0 L
.45 0 L
.475 0 L
.5 0 L
.525 0 L
.55 0 L
.575 0 L
.6 0 L
.625 0 L
.65 0 L
.675 .00119 L
.7 .00391 L
.725 .01132 L
.75 .02891 L
.775 .06514 L
.8 .12955 L
.825 .22736 L
.85 .35215 L
.875 .48133 L
.9 .58059 L
.925 .61803 L
.95 .58059 L
.975 .48133 L
s
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{399, 246},
  ImageMargins->{{33, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]],

Cell["\<\
Note in the previous example, we assigned variable names to each of the new \
fuzzy sets. This enables us to reference each individual fuzzy set. This \
technique is important for the fuzzy inferencing commands that we will talk \
about later. To show that we indeed can access the individual fuzzy sets, we \
graph a couple of the fuzzy sets here.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzyPlot[NM,PS,PlotJoined->True];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.025 0.025 0 0.618034 [
[(0)] .025 0 0 2 Msboxa
[(5)] .15 0 0 2 Msboxa
[(10)] .275 0 0 2 Msboxa
[(15)] .4 0 0 2 Msboxa
[(20)] .525 0 0 2 Msboxa
[(25)] .65 0 0 2 Msboxa
[(30)] .775 0 0 2 Msboxa
[(35)] .9 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.025 0 m
.025 .00625 L
s
P
[(0)] .025 0 0 2 Mshowa
p
.002 w
.15 0 m
.15 .00625 L
s
P
[(5)] .15 0 0 2 Mshowa
p
.002 w
.275 0 m
.275 .00625 L
s
P
[(10)] .275 0 0 2 Mshowa
p
.002 w
.4 0 m
.4 .00625 L
s
P
[(15)] .4 0 0 2 Mshowa
p
.002 w
.525 0 m
.525 .00625 L
s
P
[(20)] .525 0 0 2 Mshowa
p
.002 w
.65 0 m
.65 .00625 L
s
P
[(25)] .65 0 0 2 Mshowa
p
.002 w
.775 0 m
.775 .00625 L
s
P
[(30)] .775 0 0 2 Mshowa
p
.002 w
.9 0 m
.9 .00625 L
s
P
[(35)] .9 0 0 2 Mshowa
p
.001 w
.05 0 m
.05 .00375 L
s
P
p
.001 w
.075 0 m
.075 .00375 L
s
P
p
.001 w
.1 0 m
.1 .00375 L
s
P
p
.001 w
.125 0 m
.125 .00375 L
s
P
p
.001 w
.175 0 m
.175 .00375 L
s
P
p
.001 w
.2 0 m
.2 .00375 L
s
P
p
.001 w
.225 0 m
.225 .00375 L
s
P
p
.001 w
.25 0 m
.25 .00375 L
s
P
p
.001 w
.3 0 m
.3 .00375 L
s
P
p
.001 w
.325 0 m
.325 .00375 L
s
P
p
.001 w
.35 0 m
.35 .00375 L
s
P
p
.001 w
.375 0 m
.375 .00375 L
s
P
p
.001 w
.425 0 m
.425 .00375 L
s
P
p
.001 w
.45 0 m
.45 .00375 L
s
P
p
.001 w
.475 0 m
.475 .00375 L
s
P
p
.001 w
.5 0 m
.5 .00375 L
s
P
p
.001 w
.55 0 m
.55 .00375 L
s
P
p
.001 w
.575 0 m
.575 .00375 L
s
P
p
.001 w
.6 0 m
.6 .00375 L
s
P
p
.001 w
.625 0 m
.625 .00375 L
s
P
p
.001 w
.675 0 m
.675 .00375 L
s
P
p
.001 w
.7 0 m
.7 .00375 L
s
P
p
.001 w
.725 0 m
.725 .00375 L
s
P
p
.001 w
.75 0 m
.75 .00375 L
s
P
p
.001 w
.8 0 m
.8 .00375 L
s
P
p
.001 w
.825 0 m
.825 .00375 L
s
P
p
.001 w
.85 0 m
.85 .00375 L
s
P
p
.001 w
.875 0 m
.875 .00375 L
s
P
p
.001 w
.925 0 m
.925 .00375 L
s
P
p
.001 w
.95 0 m
.95 .00375 L
s
P
p
.001 w
.975 0 m
.975 .00375 L
s
P
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
1.76777 Mabswid
.025 .06514 m
.05 .12955 L
.075 .22736 L
.1 .35215 L
.125 .48133 L
.15 .58059 L
.175 .61803 L
.2 .58059 L
.225 .48133 L
.25 .35215 L
.275 .22736 L
.3 .12955 L
.325 .06514 L
.35 .02891 L
.375 .01132 L
.4 .00391 L
.425 .00119 L
.45 0 L
.475 0 L
.5 0 L
.525 0 L
.55 0 L
.575 0 L
.6 0 L
.625 0 L
.65 0 L
.675 0 L
.7 0 L
.725 0 L
.75 0 L
.775 0 L
.8 0 L
.825 0 L
.85 0 L
.875 0 L
.9 0 L
.925 0 L
.95 0 L
.975 0 L
s
P
p
.2 0 1 r
1.76777 Mabswid
.025 0 m
.05 0 L
.075 0 L
.1 0 L
.125 0 L
.15 0 L
.175 0 L
.2 0 L
.225 0 L
.25 0 L
.275 0 L
.3 0 L
.325 0 L
.35 0 L
.375 .00119 L
.4 .00391 L
.425 .01132 L
.45 .02891 L
.475 .06514 L
.5 .12955 L
.525 .22736 L
.55 .35215 L
.575 .48133 L
.6 .58059 L
.625 .61803 L
.65 .58059 L
.675 .48133 L
.7 .35215 L
.725 .22736 L
.75 .12955 L
.775 .06514 L
.8 .02891 L
.825 .01132 L
.85 .00391 L
.875 .00119 L
.9 0 L
.925 0 L
.95 0 L
.975 0 L
s
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{399, 246},
  ImageMargins->{{33, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]]}, Open]]}, Open]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{496, 599},
WindowMargins->{{Automatic, 226}, {Automatic, 0}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False}
]



(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 85, 7, 70, "Title"],

Cell[CellGroupData[{
Cell[1847, 60, 67, 1, 70, "Subsection"],
Cell[1917, 63, 236, 5, 70, "Text"],
Cell[2156, 70, 143, 4, 70, "Text"],
Cell[2302, 76, 102, 2, 70, "Input"],
Cell[2407, 80, 304, 6, 70, "SmallText"]
}, Open  ]],
Cell[2723, 88, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[2796, 91, 85, 1, 70, "Subsection"],
Cell[2884, 94, 616, 10, 70, "Text"],
Cell[3503, 106, 200, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[3726, 112, 147, 5, 70, "Input"],
Cell[3876, 119, 530, 28, 70, "Output"]
}, Open  ]],
Cell[4418, 149, 204, 4, 70, "Text"],
Cell[4625, 155, 324, 6, 70, "Text"],

Cell[CellGroupData[{
Cell[4972, 163, 88, 2, 70, "Input"],
Cell[5063, 167, 4547, 486, 70, 4389, 481, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[9622, 655, 449, 8, 70, "Text"],

Cell[CellGroupData[{
Cell[10094, 665, 103, 2, 70, "Input"],
Cell[10200, 669, 695, 32, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10927, 703, 88, 2, 70, "Input"],
Cell[11018, 707, 4141, 440, 70, 3983, 435, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],
Cell[15180, 1149, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[15253, 1152, 82, 1, 70, "Subsection"],
Cell[15338, 1155, 218, 5, 70, "Text"],
Cell[15559, 1162, 237, 5, 70, "Text"],

Cell[CellGroupData[{
Cell[15819, 1169, 120, 2, 70, "Input"],
Cell[15942, 1173, 915, 42, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16889, 1217, 88, 2, 70, "Input"],
Cell[16980, 1221, 3697, 386, 70, 3539, 381, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],
Cell[20698, 1609, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[20771, 1612, 89, 1, 70, "Subsection"],
Cell[20863, 1615, 276, 5, 70, "Text"],
Cell[21142, 1622, 325, 7, 70, "Text"],
Cell[21470, 1631, 240, 7, 70, "Input"],

Cell[CellGroupData[{
Cell[21733, 1640, 102, 2, 70, "Input"],
Cell[21838, 1644, 664, 34, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22534, 1680, 88, 2, 70, "Input"],
Cell[22625, 1684, 4151, 440, 70, 3993, 435, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[26788, 2126, 261, 5, 70, "Text"],

Cell[CellGroupData[{
Cell[27072, 2133, 116, 2, 70, "Input"],
Cell[27191, 2137, 174, 16, 70, "Output"]
}, Open  ]],
Cell[27377, 2155, 145, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[27545, 2161, 105, 2, 70, "Input"],
Cell[27653, 2165, 732, 34, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28417, 2201, 91, 2, 70, "Input"],
Cell[28511, 2205, 4229, 446, 70, 4071, 441, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[32752, 2653, 135, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[32910, 2659, 116, 2, 70, "Input"],
Cell[33029, 2663, 174, 16, 70, "Output"]
}, Open  ]]
}, Open  ]],
Cell[33224, 2681, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[33297, 2684, 82, 1, 70, "Subsection"],
Cell[33382, 2687, 216, 5, 70, "Text"],

Cell[CellGroupData[{
Cell[33621, 2694, 158, 5, 70, "Input"],
Cell[33782, 2701, 284, 20, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[34098, 2723, 88, 2, 70, "Input"],
Cell[34189, 2727, 3728, 388, 70, 3570, 383, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],
Cell[37938, 3117, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[38011, 3120, 88, 1, 70, "Subsection"],
Cell[38102, 3123, 274, 5, 70, "Text"],
Cell[38379, 3130, 244, 5, 70, "Text"],
Cell[38626, 3137, 181, 6, 70, "Input",
  PageBreakAbove->True],

Cell[CellGroupData[{
Cell[38830, 3145, 106, 2, 70, "Input"],
Cell[38939, 3149, 6530, 633, 70, 6372, 628, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[45481, 3784, 296, 6, 70, "Text"],
Cell[45780, 3792, 191, 6, 70, "Input"],

Cell[CellGroupData[{
Cell[45994, 3800, 106, 2, 70, "Input"],
Cell[46103, 3804, 7032, 779, 70, 6874, 774, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[53147, 4585, 405, 7, 70, "Text"],

Cell[CellGroupData[{
Cell[53575, 4594, 107, 2, 70, "Input"],
Cell[53685, 4598, 4845, 559, 70, 4687, 554, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)
