(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     94328,       7211]*)
(*NotebookOutlinePosition[     95199,       7243]*)
(*  CellTagsIndexPosition[     95155,       7239]*)
(*WindowFrame->Normal*)



Notebook[{


Cell[CellGroupData[{Cell["\<\
Aggregation Operations
 
 
 
 \
\>", "Title",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Introduction", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
The Fuzzy Logic Pack provides a number of functions for aggregating two or \
more fuzzy sets or fuzzy relations. In this chapter, we will introduce these \
functions and demonstrate how to use them. \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
First we need to load the proper routines. This is done with the following \
command. \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Needs[\"FuzzyLogic`Master`\"]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
If the package loading command fails, verify that the directory containing \
the Fuzzy Logic directory is on Mathematica's $Path. You can use the command \
AppendTo[$Path, \"directory\"]. For convenience, this should be in your \
init.m file.\
\>", "SmallText",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
To use the various aggregation operations, we need a few fuzzy sets or fuzzy \
relations. For convenience, we demonstrate the aggregation operations in this \
chapter using a pair of fuzzy sets. Keep in mind, however, that the \
aggregation operations work with two or more fuzzy sets or fuzzy relations. \
\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
When using the aggregation operations, the fuzzy sets or fuzzy relations \
being combined must be defined on the same universal space. It does not make \
sense to combine items defined on different universal spaces.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
We create two fuzzy sets to use in our demonstrations with the FuzzyTrapezoid \
function that was described earlier in this manual.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FS1 = FuzzyTrapezoid[0,2,8,18,1]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
FuzzySet[{{1, 1/2}, {2, 1}, {3, 1}, {4, 1}, {5, 1}, {6, 1}, 
 
   {7, 1}, {8, 1}, {9, 9/10}, {10, 4/5}, {11, 7/10}, {12, 3/5}, 
 
   {13, 1/2}, {14, 2/5}, {15, 3/10}, {16, 1/5}, {17, 1/10}}, 
 
  UniversalSpace -> {0, 20}]











\
\>", "\<\
              1
FuzzySet[{{1, -}, {2, 1}, {3, 1}, {4, 1}, {5, 1}, {6, 1}, {7, 1}, 
              2
 
               9         4        7         3        1        2
   {8, 1}, {9, --}, {10, -}, {11, --}, {12, -}, {13, -}, {14, -}, 
               10        5        10        5        2        5
 
        3         1        1
   {15, --}, {16, -}, {17, --}}, UniversalSpace -> {0, 20}]
        10        5        10\
\>"], "Output",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["FS2 = FuzzyTrapezoid[3,15,15,19,.9]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
FuzzySet[{{4, 0.075}, {5, 0.15}, {6, 0.225}, {7, 0.3}, 
 
   {8, 0.375}, {9, 0.45}, {10, 0.525}, {11, 0.6}, {12, 0.675}, 
 
   {13, 0.75}, {14, 0.825}, {15, 0.9}, {16, 0.6750000000000003}, 
 
   {17, 0.4500000000000002}, {18, 0.2250000000000005}}, 
 
  UniversalSpace -> {0, 20}]











\
\>", "\<\
FuzzySet[{{4, 0.075}, {5, 0.15}, {6, 0.225}, {7, 0.3}, 
 
   {8, 0.375}, {9, 0.45}, {10, 0.525}, {11, 0.6}, {12, 0.675}, 
 
   {13, 0.75}, {14, 0.825}, {15, 0.9}, {16, 0.675}, {17, 0.45}, 
 
   {18, 0.225}}, UniversalSpace -> {0, 20}]\
\>"], "Output",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell["\<\
To look at these two fuzzy sets we use the FuzzyPlot command. On the graph, \
FS1 is represented by the trapezoidal fuzzy set with a height of 1. FS2 is \
the triangular fuzzy set with a height of 0.9.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzyPlot[FS1,FS2];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0454545 0.0454545 0 0.618034 [
[(1)] .09091 0 0 2 Msboxa
[(3)] .18182 0 0 2 Msboxa
[(5)] .27273 0 0 2 Msboxa
[(7)] .36364 0 0 2 Msboxa
[(9)] .45455 0 0 2 Msboxa
[(11)] .54545 0 0 2 Msboxa
[(13)] .63636 0 0 2 Msboxa
[(15)] .72727 0 0 2 Msboxa
[(17)] .81818 0 0 2 Msboxa
[(19)] .90909 0 0 2 Msboxa
[(21)] 1 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.09091 0 m
.09091 .00625 L
s
P
[(1)] .09091 0 0 2 Mshowa
p
.002 w
.18182 0 m
.18182 .00625 L
s
P
[(3)] .18182 0 0 2 Mshowa
p
.002 w
.27273 0 m
.27273 .00625 L
s
P
[(5)] .27273 0 0 2 Mshowa
p
.002 w
.36364 0 m
.36364 .00625 L
s
P
[(7)] .36364 0 0 2 Mshowa
p
.002 w
.45455 0 m
.45455 .00625 L
s
P
[(9)] .45455 0 0 2 Mshowa
p
.002 w
.54545 0 m
.54545 .00625 L
s
P
[(11)] .54545 0 0 2 Mshowa
p
.002 w
.63636 0 m
.63636 .00625 L
s
P
[(13)] .63636 0 0 2 Mshowa
p
.002 w
.72727 0 m
.72727 .00625 L
s
P
[(15)] .72727 0 0 2 Mshowa
p
.002 w
.81818 0 m
.81818 .00625 L
s
P
[(17)] .81818 0 0 2 Mshowa
p
.002 w
.90909 0 m
.90909 .00625 L
s
P
[(19)] .90909 0 0 2 Mshowa
p
.002 w
1 0 m
1 .00625 L
s
P
[(21)] 1 0 0 2 Mshowa
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
p
p
1.25 Mabswid
.04545 0 m
.04545 0 L
s
P
p
1.25 Mabswid
.09091 .30902 m
.09091 0 L
s
P
p
1.25 Mabswid
.13636 .61803 m
.13636 0 L
s
P
p
1.25 Mabswid
.18182 .61803 m
.18182 0 L
s
P
p
1.25 Mabswid
.22727 .61803 m
.22727 0 L
s
P
p
1.25 Mabswid
.27273 .61803 m
.27273 0 L
s
P
p
1.25 Mabswid
.31818 .61803 m
.31818 0 L
s
P
p
1.25 Mabswid
.36364 .61803 m
.36364 0 L
s
P
p
1.25 Mabswid
.40909 .61803 m
.40909 0 L
s
P
p
1.25 Mabswid
.45455 .55623 m
.45455 0 L
s
P
p
1.25 Mabswid
.5 .49443 m
.5 0 L
s
P
p
1.25 Mabswid
.54545 .43262 m
.54545 0 L
s
P
p
1.25 Mabswid
.59091 .37082 m
.59091 0 L
s
P
p
1.25 Mabswid
.63636 .30902 m
.63636 0 L
s
P
p
1.25 Mabswid
.68182 .24721 m
.68182 0 L
s
P
p
1.25 Mabswid
.72727 .18541 m
.72727 0 L
s
P
p
1.25 Mabswid
.77273 .12361 m
.77273 0 L
s
P
p
1.25 Mabswid
.81818 .0618 m
.81818 0 L
s
P
p
1.25 Mabswid
.86364 0 m
.86364 0 L
s
P
p
1.25 Mabswid
.90909 0 m
.90909 0 L
s
P
p
1.25 Mabswid
.95455 0 m
.95455 0 L
s
P
P
P
p
.2 0 1 r
p
p
1.25 Mabswid
.06061 0 m
.06061 0 L
s
P
p
1.25 Mabswid
.10606 0 m
.10606 0 L
s
P
p
1.25 Mabswid
.15152 0 m
.15152 0 L
s
P
p
1.25 Mabswid
.19697 0 m
.19697 0 L
s
P
p
1.25 Mabswid
.24242 .04635 m
.24242 0 L
s
P
p
1.25 Mabswid
.28788 .09271 m
.28788 0 L
s
P
p
1.25 Mabswid
.33333 .13906 m
.33333 0 L
s
P
p
1.25 Mabswid
.37879 .18541 m
.37879 0 L
s
P
p
1.25 Mabswid
.42424 .23176 m
.42424 0 L
s
P
p
1.25 Mabswid
.4697 .27812 m
.4697 0 L
s
P
p
1.25 Mabswid
.51515 .32447 m
.51515 0 L
s
P
p
1.25 Mabswid
.56061 .37082 m
.56061 0 L
s
P
p
1.25 Mabswid
.60606 .41717 m
.60606 0 L
s
P
p
1.25 Mabswid
.65152 .46353 m
.65152 0 L
s
P
p
1.25 Mabswid
.69697 .50988 m
.69697 0 L
s
P
p
1.25 Mabswid
.74242 .55623 m
.74242 0 L
s
P
p
1.25 Mabswid
.78788 .41717 m
.78788 0 L
s
P
p
1.25 Mabswid
.83333 .27812 m
.83333 0 L
s
P
p
1.25 Mabswid
.87879 .13906 m
.87879 0 L
s
P
p
1.25 Mabswid
.92424 0 m
.92424 0 L
s
P
p
1.25 Mabswid
.9697 0 m
.9697 0 L
s
P
P
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{398, 246},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Intersection (t-norm) Operations", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Intersections (Standard and Nonstandard)", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Intersection[A1,A2,...,An,opts] returns the intersection of A1, A2, ..., An, \
where the A's are either fuzzy sets or fuzzy relations. This function has a \
Type option for specifying what kind of intersection should be taken. The \
default setting is the Standard or Min intersection. Other valid types of \
intersections are shown in the following table.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
   Type\t\t\t\tParameter
    Hamacher[v]\t\t\tv in the range 0 to infinity
    Frank[s]\t\t\ts in the range 0 to infinity except 1
    Yager[w]\t\t\tw in the range 0 to infinity
    DuboisPrade[a]\t\ta in the range 0 to 1
    Dombi[alpha]\t\talpha in the range 0 to infinity\
\>", "Special3",
  CellFrame->True,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
For our first example, we use the default intersection to combine the two \
fuzzy sets which we created earlier. This produces the Standard or Min \
intersection of the two fuzzy sets.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["In1 = Intersection[FS1,FS2]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
FuzzySet[{{4, 0.075}, {5, 0.15}, {6, 0.225}, {7, 0.3}, 
 
   {8, 0.375}, {9, 0.45}, {10, 0.525}, {11, 0.6}, {12, 3/5}, 
 
   {13, 1/2}, {14, 2/5}, {15, 3/10}, {16, 1/5}, {17, 1/10}}, 
 
  UniversalSpace -> {0, 20}]











\
\>", "\<\
FuzzySet[{{4, 0.075}, {5, 0.15}, {6, 0.225}, {7, 0.3}, 
 
                                                       3
   {8, 0.375}, {9, 0.45}, {10, 0.525}, {11, 0.6}, {12, -}, 
                                                       5
 
        1        2        3         1        1
   {13, -}, {14, -}, {15, --}, {16, -}, {17, --}}, 
        2        5        10        5        10
 
  UniversalSpace -> {0, 20}]\
\>"], "Output",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell["\<\
We can plot the original fuzzy sets, FS1 and FS2, along with their \
intersection using the FuzzyPlot function. The PlotJoined option is set to \
True to produce a continuous plot of the fuzzy sets. For the standard case, \
the intersection takes the minimum of FS1 and FS2.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzyPlot[FS1,FS2,In1,PlotJoined->True];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0454545 0.0454545 0 0.618034 [
[(1)] .09091 0 0 2 Msboxa
[(3)] .18182 0 0 2 Msboxa
[(5)] .27273 0 0 2 Msboxa
[(7)] .36364 0 0 2 Msboxa
[(9)] .45455 0 0 2 Msboxa
[(11)] .54545 0 0 2 Msboxa
[(13)] .63636 0 0 2 Msboxa
[(15)] .72727 0 0 2 Msboxa
[(17)] .81818 0 0 2 Msboxa
[(19)] .90909 0 0 2 Msboxa
[(21)] 1 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.09091 0 m
.09091 .00625 L
s
P
[(1)] .09091 0 0 2 Mshowa
p
.002 w
.18182 0 m
.18182 .00625 L
s
P
[(3)] .18182 0 0 2 Mshowa
p
.002 w
.27273 0 m
.27273 .00625 L
s
P
[(5)] .27273 0 0 2 Mshowa
p
.002 w
.36364 0 m
.36364 .00625 L
s
P
[(7)] .36364 0 0 2 Mshowa
p
.002 w
.45455 0 m
.45455 .00625 L
s
P
[(9)] .45455 0 0 2 Mshowa
p
.002 w
.54545 0 m
.54545 .00625 L
s
P
[(11)] .54545 0 0 2 Mshowa
p
.002 w
.63636 0 m
.63636 .00625 L
s
P
[(13)] .63636 0 0 2 Mshowa
p
.002 w
.72727 0 m
.72727 .00625 L
s
P
[(15)] .72727 0 0 2 Mshowa
p
.002 w
.81818 0 m
.81818 .00625 L
s
P
[(17)] .81818 0 0 2 Mshowa
p
.002 w
.90909 0 m
.90909 .00625 L
s
P
[(19)] .90909 0 0 2 Mshowa
p
.002 w
1 0 m
1 .00625 L
s
P
[(21)] 1 0 0 2 Mshowa
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
1.44338 Mabswid
.04545 0 m
.09091 .30902 L
.13636 .61803 L
.18182 .61803 L
.22727 .61803 L
.27273 .61803 L
.31818 .61803 L
.36364 .61803 L
.40909 .61803 L
.45455 .55623 L
.5 .49443 L
.54545 .43262 L
.59091 .37082 L
.63636 .30902 L
.68182 .24721 L
.72727 .18541 L
.77273 .12361 L
.81818 .0618 L
.86364 0 L
.90909 0 L
.95455 0 L
s
P
p
.2 0 1 r
1.44338 Mabswid
.04545 0 m
.09091 0 L
.13636 0 L
.18182 0 L
.22727 .04635 L
.27273 .09271 L
.31818 .13906 L
.36364 .18541 L
.40909 .23176 L
.45455 .27812 L
.5 .32447 L
.54545 .37082 L
.59091 .41717 L
.63636 .46353 L
.68182 .50988 L
.72727 .55623 L
.77273 .41717 L
.81818 .27812 L
.86364 .13906 L
.90909 0 L
.95455 0 L
s
P
p
0 1 .4 r
1.44338 Mabswid
.04545 0 m
.09091 0 L
.13636 0 L
.18182 0 L
.22727 .04635 L
.27273 .09271 L
.31818 .13906 L
.36364 .18541 L
.40909 .23176 L
.45455 .27812 L
.5 .32447 L
.54545 .37082 L
.59091 .37082 L
.63636 .30902 L
.68182 .24721 L
.72727 .18541 L
.77273 .12361 L
.81818 .0618 L
.86364 0 L
.90909 0 L
.95455 0 L
s
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{398, 246},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]],

Cell["\<\
We now experiment with some of the nonstandard intersections by changing the \
Type option. Here we take the Hamacher intersection of the two fuzzy sets \
where the parameter w is set to 2.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["In2 = Intersection[FS1,FS2,Type->Hamacher[2]]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
FuzzySet[{{4, 0.075}, {5, 0.15}, {6, 0.225}, {7, 0.3}, 
 
   {8, 0.375}, {9, 0.3838862559241706}, 
 
   {10, 0.3835616438356165}, {11, 0.375}, 
 
   {12, 0.3584070796460177}, {13, 0.3333333333333333}, 
 
   {14, 0.2986425339366515}, {15, 0.2523364485981308}, 
 
   {16, 0.1071428571428572}, {17, 0.03010033444816055}}, 
 
  UniversalSpace -> {0, 20}]











\
\>", "\<\
FuzzySet[{{4, 0.075}, {5, 0.15}, {6, 0.225}, {7, 0.3}, 
 
   {8, 0.375}, {9, 0.383886}, {10, 0.383562}, {11, 0.375}, 
 
   {12, 0.358407}, {13, 0.333333}, {14, 0.298643}, 
 
   {15, 0.252336}, {16, 0.107143}, {17, 0.0301003}}, 
 
  UniversalSpace -> {0, 20}]\
\>"], "Output",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell["\<\
We compare this intersection with the Standard intersection by plotting the \
two results on the same graph. When we do this, we see that our Hamacher \
intersection returns values slightly less than the standard Min intersection. \
In general, this is true for all nonstandard intersections.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzyPlot[In1,In2];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0454545 0.0454545 0 0.618034 [
[(1)] .09091 0 0 2 Msboxa
[(3)] .18182 0 0 2 Msboxa
[(5)] .27273 0 0 2 Msboxa
[(7)] .36364 0 0 2 Msboxa
[(9)] .45455 0 0 2 Msboxa
[(11)] .54545 0 0 2 Msboxa
[(13)] .63636 0 0 2 Msboxa
[(15)] .72727 0 0 2 Msboxa
[(17)] .81818 0 0 2 Msboxa
[(19)] .90909 0 0 2 Msboxa
[(21)] 1 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.09091 0 m
.09091 .00625 L
s
P
[(1)] .09091 0 0 2 Mshowa
p
.002 w
.18182 0 m
.18182 .00625 L
s
P
[(3)] .18182 0 0 2 Mshowa
p
.002 w
.27273 0 m
.27273 .00625 L
s
P
[(5)] .27273 0 0 2 Mshowa
p
.002 w
.36364 0 m
.36364 .00625 L
s
P
[(7)] .36364 0 0 2 Mshowa
p
.002 w
.45455 0 m
.45455 .00625 L
s
P
[(9)] .45455 0 0 2 Mshowa
p
.002 w
.54545 0 m
.54545 .00625 L
s
P
[(11)] .54545 0 0 2 Mshowa
p
.002 w
.63636 0 m
.63636 .00625 L
s
P
[(13)] .63636 0 0 2 Mshowa
p
.002 w
.72727 0 m
.72727 .00625 L
s
P
[(15)] .72727 0 0 2 Mshowa
p
.002 w
.81818 0 m
.81818 .00625 L
s
P
[(17)] .81818 0 0 2 Mshowa
p
.002 w
.90909 0 m
.90909 .00625 L
s
P
[(19)] .90909 0 0 2 Mshowa
p
.002 w
1 0 m
1 .00625 L
s
P
[(21)] 1 0 0 2 Mshowa
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
p
p
1.25 Mabswid
.04545 0 m
.04545 0 L
s
P
p
1.25 Mabswid
.09091 0 m
.09091 0 L
s
P
p
1.25 Mabswid
.13636 0 m
.13636 0 L
s
P
p
1.25 Mabswid
.18182 0 m
.18182 0 L
s
P
p
1.25 Mabswid
.22727 .04635 m
.22727 0 L
s
P
p
1.25 Mabswid
.27273 .09271 m
.27273 0 L
s
P
p
1.25 Mabswid
.31818 .13906 m
.31818 0 L
s
P
p
1.25 Mabswid
.36364 .18541 m
.36364 0 L
s
P
p
1.25 Mabswid
.40909 .23176 m
.40909 0 L
s
P
p
1.25 Mabswid
.45455 .27812 m
.45455 0 L
s
P
p
1.25 Mabswid
.5 .32447 m
.5 0 L
s
P
p
1.25 Mabswid
.54545 .37082 m
.54545 0 L
s
P
p
1.25 Mabswid
.59091 .37082 m
.59091 0 L
s
P
p
1.25 Mabswid
.63636 .30902 m
.63636 0 L
s
P
p
1.25 Mabswid
.68182 .24721 m
.68182 0 L
s
P
p
1.25 Mabswid
.72727 .18541 m
.72727 0 L
s
P
p
1.25 Mabswid
.77273 .12361 m
.77273 0 L
s
P
p
1.25 Mabswid
.81818 .0618 m
.81818 0 L
s
P
p
1.25 Mabswid
.86364 0 m
.86364 0 L
s
P
p
1.25 Mabswid
.90909 0 m
.90909 0 L
s
P
p
1.25 Mabswid
.95455 0 m
.95455 0 L
s
P
P
P
p
.2 0 1 r
p
p
1.25 Mabswid
.06061 0 m
.06061 0 L
s
P
p
1.25 Mabswid
.10606 0 m
.10606 0 L
s
P
p
1.25 Mabswid
.15152 0 m
.15152 0 L
s
P
p
1.25 Mabswid
.19697 0 m
.19697 0 L
s
P
p
1.25 Mabswid
.24242 .04635 m
.24242 0 L
s
P
p
1.25 Mabswid
.28788 .09271 m
.28788 0 L
s
P
p
1.25 Mabswid
.33333 .13906 m
.33333 0 L
s
P
p
1.25 Mabswid
.37879 .18541 m
.37879 0 L
s
P
p
1.25 Mabswid
.42424 .23176 m
.42424 0 L
s
P
p
1.25 Mabswid
.4697 .23725 m
.4697 0 L
s
P
p
1.25 Mabswid
.51515 .23705 m
.51515 0 L
s
P
p
1.25 Mabswid
.56061 .23176 m
.56061 0 L
s
P
p
1.25 Mabswid
.60606 .22151 m
.60606 0 L
s
P
p
1.25 Mabswid
.65152 .20601 m
.65152 0 L
s
P
p
1.25 Mabswid
.69697 .18457 m
.69697 0 L
s
P
p
1.25 Mabswid
.74242 .15595 m
.74242 0 L
s
P
p
1.25 Mabswid
.78788 .06622 m
.78788 0 L
s
P
p
1.25 Mabswid
.83333 .0186 m
.83333 0 L
s
P
p
1.25 Mabswid
.87879 0 m
.87879 0 L
s
P
p
1.25 Mabswid
.92424 0 m
.92424 0 L
s
P
p
1.25 Mabswid
.9697 0 m
.9697 0 L
s
P
P
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{398, 246},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Products", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
There is a group of t-norm operators which are collectively called products. \
Each of these operations is simply a specific case of one of the \
intersections listed before, so we have not included explicit functions for \
these operations. If you desire to use one of the product operators, however, \
you may use the appropriate Intersection Type from the table below. \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
   Product Type\t\tEquivalent Intersection
    Drastic Product\t\tHamacher[infinity], Yager[0]
    Bounded Product\t\tYager[1]
    Einstein Product\t\tHamacher[2]
    Algebraic Product\t\tHamacher[1], DuboisPrade[1]
    Hamacher Product\t\tHamacher[0]\
\>", "Special3",
  CellFrame->True,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
As an example, if you wanted to find the bounded product of FS1 and FS2, you \
could use a Yager intersection like this.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["BP = Intersection[FS1,FS2,Type->Yager[1]]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
FuzzySet[{{4, 0.07499999999999996}, {5, 0.15}, {6, 0.225}, 
 
   {7, 0.3}, {8, 0.375}, {9, 0.35}, {10, 0.325}, {11, 0.3}, 
 
   {12, 0.2749999999999999}, {13, 0.25}, {14, 0.225}, 
 
   {15, 0.2000000000000001}}, UniversalSpace -> {0, 20}]











\
\>", "\<\
FuzzySet[{{4, 0.075}, {5, 0.15}, {6, 0.225}, {7, 0.3}, 
 
   {8, 0.375}, {9, 0.35}, {10, 0.325}, {11, 0.3}, {12, 0.275}, 
 
   {13, 0.25}, {14, 0.225}, {15, 0.2}}, 
 
  UniversalSpace -> {0, 20}]\
\>"], "Output",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Union (s-norm) Operations", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Unions (Standard and Nonstandard)", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Union[A1,A2,...,An,opts] returns the union of A1, A2, ..., An, where the A's \
can be fuzzy sets or fuzzy relations. This function has a Type option for \
specifying what type of union should be taken. The default is the Standard or \
Max union. Other valid union types are shown in the following table.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
   Type\t\t\t\tParameter
    Hamacher[v]\t\t\tv in the range 0 to infinity
    Frank[s]\t\t\ts in the range 0 to infinity except 1
    Yager[w]\t\t\tw in the range 0 to infinity
    DuboisPrade[a]\t\ta in the range 0 to 1
    Dombi[alpha]\t\talpha in the range 0 to infinity\
\>", "Special3",
  CellFrame->True,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
For our first Union example, we use the default Standard union to combine our \
two fuzzy sets.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Un1 = Union[FS1,FS2]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
FuzzySet[{{1, 1/2}, {2, 1}, {3, 1}, {4, 1}, {5, 1}, {6, 1}, 
 
   {7, 1}, {8, 1}, {9, 9/10}, {10, 4/5}, {11, 7/10}, 
 
   {12, 0.675}, {13, 0.75}, {14, 0.825}, {15, 0.9}, 
 
   {16, 0.6750000000000003}, {17, 0.4500000000000002}, 
 
   {18, 0.2250000000000005}}, UniversalSpace -> {0, 20}]











\
\>", "\<\
              1
FuzzySet[{{1, -}, {2, 1}, {3, 1}, {4, 1}, {5, 1}, {6, 1}, 
              2
 
                       9         4        7
   {7, 1}, {8, 1}, {9, --}, {10, -}, {11, --}, {12, 0.675}, 
                       10        5        10
 
   {13, 0.75}, {14, 0.825}, {15, 0.9}, {16, 0.675}, {17, 0.45}, 
 
   {18, 0.225}}, UniversalSpace -> {0, 20}]\
\>"], "Output",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell["\<\
We look at the results by plotting the original fuzzy sets along with the \
union. On the graph, since the union is graphed last, it covers the original \
fuzzy sets in certain areas. If you remember what our original fuzzy sets \
looked like, however, you can see that the standard union takes the maximum \
membership grade of the two fuzzy sets for each element.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzyPlot[FS1,FS2,Un1,PlotJoined->True];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0454545 0.0454545 0 0.618034 [
[(1)] .09091 0 0 2 Msboxa
[(3)] .18182 0 0 2 Msboxa
[(5)] .27273 0 0 2 Msboxa
[(7)] .36364 0 0 2 Msboxa
[(9)] .45455 0 0 2 Msboxa
[(11)] .54545 0 0 2 Msboxa
[(13)] .63636 0 0 2 Msboxa
[(15)] .72727 0 0 2 Msboxa
[(17)] .81818 0 0 2 Msboxa
[(19)] .90909 0 0 2 Msboxa
[(21)] 1 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.09091 0 m
.09091 .00625 L
s
P
[(1)] .09091 0 0 2 Mshowa
p
.002 w
.18182 0 m
.18182 .00625 L
s
P
[(3)] .18182 0 0 2 Mshowa
p
.002 w
.27273 0 m
.27273 .00625 L
s
P
[(5)] .27273 0 0 2 Mshowa
p
.002 w
.36364 0 m
.36364 .00625 L
s
P
[(7)] .36364 0 0 2 Mshowa
p
.002 w
.45455 0 m
.45455 .00625 L
s
P
[(9)] .45455 0 0 2 Mshowa
p
.002 w
.54545 0 m
.54545 .00625 L
s
P
[(11)] .54545 0 0 2 Mshowa
p
.002 w
.63636 0 m
.63636 .00625 L
s
P
[(13)] .63636 0 0 2 Mshowa
p
.002 w
.72727 0 m
.72727 .00625 L
s
P
[(15)] .72727 0 0 2 Mshowa
p
.002 w
.81818 0 m
.81818 .00625 L
s
P
[(17)] .81818 0 0 2 Mshowa
p
.002 w
.90909 0 m
.90909 .00625 L
s
P
[(19)] .90909 0 0 2 Mshowa
p
.002 w
1 0 m
1 .00625 L
s
P
[(21)] 1 0 0 2 Mshowa
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
1.44338 Mabswid
.04545 0 m
.09091 .30902 L
.13636 .61803 L
.18182 .61803 L
.22727 .61803 L
.27273 .61803 L
.31818 .61803 L
.36364 .61803 L
.40909 .61803 L
.45455 .55623 L
.5 .49443 L
.54545 .43262 L
.59091 .37082 L
.63636 .30902 L
.68182 .24721 L
.72727 .18541 L
.77273 .12361 L
.81818 .0618 L
.86364 0 L
.90909 0 L
.95455 0 L
s
P
p
.2 0 1 r
1.44338 Mabswid
.04545 0 m
.09091 0 L
.13636 0 L
.18182 0 L
.22727 .04635 L
.27273 .09271 L
.31818 .13906 L
.36364 .18541 L
.40909 .23176 L
.45455 .27812 L
.5 .32447 L
.54545 .37082 L
.59091 .41717 L
.63636 .46353 L
.68182 .50988 L
.72727 .55623 L
.77273 .41717 L
.81818 .27812 L
.86364 .13906 L
.90909 0 L
.95455 0 L
s
P
p
0 1 .4 r
1.44338 Mabswid
.04545 0 m
.09091 .30902 L
.13636 .61803 L
.18182 .61803 L
.22727 .61803 L
.27273 .61803 L
.31818 .61803 L
.36364 .61803 L
.40909 .61803 L
.45455 .55623 L
.5 .49443 L
.54545 .43262 L
.59091 .41717 L
.63636 .46353 L
.68182 .50988 L
.72727 .55623 L
.77273 .41717 L
.81818 .27812 L
.86364 .13906 L
.90909 0 L
.95455 0 L
s
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{398, 246},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]],

Cell["\<\
Now, let us look at a nonstandard union. This time we use the Frank union \
with parameter s set to 3. The formulas for all the aggregation operations \
can be found in the appendix.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Un2 = Union[FS1,FS2,Type->Frank[3]]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
FuzzySet[{{1, 0.5000000000000002}, {2, 1}, {3, 1}, {4, 1}, 
 
   {5, 1}, {6, 1}, {7, 1}, {8, 1}, {9, 0.957166049690985}, 
 
   {10, 0.926432195732478}, {11, 0.906881268836145}, 
 
   {12, 0.898144981851011}, {13, 0.900352425521412}, 
 
   {14, 0.914148206227034}, {15, 0.940785755270875}, 
 
   {16, 0.7596894665549068}, {17, 0.5168161320571554}, 
 
   {18, 0.2250000000000006}}, UniversalSpace -> {0, 20}]











\
\>", "\<\
FuzzySet[{{1, 0.5}, {2, 1}, {3, 1}, {4, 1}, {5, 1}, {6, 1}, 
 
   {7, 1}, {8, 1}, {9, 0.957166}, {10, 0.926432}, 
 
   {11, 0.906881}, {12, 0.898145}, {13, 0.900352}, 
 
   {14, 0.914148}, {15, 0.940786}, {16, 0.759689}, 
 
   {17, 0.516816}, {18, 0.225}}, UniversalSpace -> {0, 20}]\
\>"], "Output",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell["\<\
We compare this latest union with the Standard union from the first example \
by plotting the two results together.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzyPlot[Un1,Un2];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0454545 0.0454545 0 0.618034 [
[(1)] .09091 0 0 2 Msboxa
[(3)] .18182 0 0 2 Msboxa
[(5)] .27273 0 0 2 Msboxa
[(7)] .36364 0 0 2 Msboxa
[(9)] .45455 0 0 2 Msboxa
[(11)] .54545 0 0 2 Msboxa
[(13)] .63636 0 0 2 Msboxa
[(15)] .72727 0 0 2 Msboxa
[(17)] .81818 0 0 2 Msboxa
[(19)] .90909 0 0 2 Msboxa
[(21)] 1 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.09091 0 m
.09091 .00625 L
s
P
[(1)] .09091 0 0 2 Mshowa
p
.002 w
.18182 0 m
.18182 .00625 L
s
P
[(3)] .18182 0 0 2 Mshowa
p
.002 w
.27273 0 m
.27273 .00625 L
s
P
[(5)] .27273 0 0 2 Mshowa
p
.002 w
.36364 0 m
.36364 .00625 L
s
P
[(7)] .36364 0 0 2 Mshowa
p
.002 w
.45455 0 m
.45455 .00625 L
s
P
[(9)] .45455 0 0 2 Mshowa
p
.002 w
.54545 0 m
.54545 .00625 L
s
P
[(11)] .54545 0 0 2 Mshowa
p
.002 w
.63636 0 m
.63636 .00625 L
s
P
[(13)] .63636 0 0 2 Mshowa
p
.002 w
.72727 0 m
.72727 .00625 L
s
P
[(15)] .72727 0 0 2 Mshowa
p
.002 w
.81818 0 m
.81818 .00625 L
s
P
[(17)] .81818 0 0 2 Mshowa
p
.002 w
.90909 0 m
.90909 .00625 L
s
P
[(19)] .90909 0 0 2 Mshowa
p
.002 w
1 0 m
1 .00625 L
s
P
[(21)] 1 0 0 2 Mshowa
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
p
p
1.25 Mabswid
.04545 0 m
.04545 0 L
s
P
p
1.25 Mabswid
.09091 .30902 m
.09091 0 L
s
P
p
1.25 Mabswid
.13636 .61803 m
.13636 0 L
s
P
p
1.25 Mabswid
.18182 .61803 m
.18182 0 L
s
P
p
1.25 Mabswid
.22727 .61803 m
.22727 0 L
s
P
p
1.25 Mabswid
.27273 .61803 m
.27273 0 L
s
P
p
1.25 Mabswid
.31818 .61803 m
.31818 0 L
s
P
p
1.25 Mabswid
.36364 .61803 m
.36364 0 L
s
P
p
1.25 Mabswid
.40909 .61803 m
.40909 0 L
s
P
p
1.25 Mabswid
.45455 .55623 m
.45455 0 L
s
P
p
1.25 Mabswid
.5 .49443 m
.5 0 L
s
P
p
1.25 Mabswid
.54545 .43262 m
.54545 0 L
s
P
p
1.25 Mabswid
.59091 .41717 m
.59091 0 L
s
P
p
1.25 Mabswid
.63636 .46353 m
.63636 0 L
s
P
p
1.25 Mabswid
.68182 .50988 m
.68182 0 L
s
P
p
1.25 Mabswid
.72727 .55623 m
.72727 0 L
s
P
p
1.25 Mabswid
.77273 .41717 m
.77273 0 L
s
P
p
1.25 Mabswid
.81818 .27812 m
.81818 0 L
s
P
p
1.25 Mabswid
.86364 .13906 m
.86364 0 L
s
P
p
1.25 Mabswid
.90909 0 m
.90909 0 L
s
P
p
1.25 Mabswid
.95455 0 m
.95455 0 L
s
P
P
P
p
.2 0 1 r
p
p
1.25 Mabswid
.06061 0 m
.06061 0 L
s
P
p
1.25 Mabswid
.10606 .30902 m
.10606 0 L
s
P
p
1.25 Mabswid
.15152 .61803 m
.15152 0 L
s
P
p
1.25 Mabswid
.19697 .61803 m
.19697 0 L
s
P
p
1.25 Mabswid
.24242 .61803 m
.24242 0 L
s
P
p
1.25 Mabswid
.28788 .61803 m
.28788 0 L
s
P
p
1.25 Mabswid
.33333 .61803 m
.33333 0 L
s
P
p
1.25 Mabswid
.37879 .61803 m
.37879 0 L
s
P
p
1.25 Mabswid
.42424 .61803 m
.42424 0 L
s
P
p
1.25 Mabswid
.4697 .59156 m
.4697 0 L
s
P
p
1.25 Mabswid
.51515 .57257 m
.51515 0 L
s
P
p
1.25 Mabswid
.56061 .56048 m
.56061 0 L
s
P
p
1.25 Mabswid
.60606 .55508 m
.60606 0 L
s
P
p
1.25 Mabswid
.65152 .55645 m
.65152 0 L
s
P
p
1.25 Mabswid
.69697 .56497 m
.69697 0 L
s
P
p
1.25 Mabswid
.74242 .58144 m
.74242 0 L
s
P
p
1.25 Mabswid
.78788 .46951 m
.78788 0 L
s
P
p
1.25 Mabswid
.83333 .31941 m
.83333 0 L
s
P
p
1.25 Mabswid
.87879 .13906 m
.87879 0 L
s
P
p
1.25 Mabswid
.92424 0 m
.92424 0 L
s
P
p
1.25 Mabswid
.9697 0 m
.9697 0 L
s
P
P
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{398, 246},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]],

Cell["\<\
From the graph, you see that the Frank union returns membership grades \
greater than or equal to the membership grades returned by the Standard \
union. This condition is true for all of the nonstandard unions.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Sums", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
There is a group of s-norm operators which are collectively called sums. Each \
of these operations is simply a specific case of one of the unions listed \
before, so we do not include explicit functions for these operations. If you \
desire to use one one of these operators, however, you may use the \
appropriate Union Type from the following table. \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
   Sum Type\t\t\tEquivalent Union
    Drastic Sum\t\t\tHamacher[infinity], Yager[0]
    Bounded Sum\t\tYager[1]
    Einstein Sum\t\t\tHamacher[2]
    Algebraic Sum\t\tHamacher[1], DuboisPrade[1]
    Hamacher Sum\t\tHamacher[0]\
\>", "Special3",
  CellFrame->True,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
As an example, to find the drastic sum of FS1 and FS2, you would enter the \
following.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["DS = Union[FS1,FS2,Type->Hamacher[Infinity]]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
FuzzySet[{{1, 1/2}, {2, 1}, {3, 1}, {4, 1}, {5, 1}, {6, 1}, 
 
   {7, 1}, {8, 1}, {9, 1}, {10, 1}, {11, 1}, {12, 1}, {13, 1}, 
 
   {14, 1}, {15, 1}, {16, 1}, {17, 1}, {18, 0.2250000000000005}}\\
 
   , UniversalSpace -> {0, 20}]











\
\>", "\<\
              1
FuzzySet[{{1, -}, {2, 1}, {3, 1}, {4, 1}, {5, 1}, {6, 1}, 
              2
 
   {7, 1}, {8, 1}, {9, 1}, {10, 1}, {11, 1}, {12, 1}, {13, 1}, 
 
   {14, 1}, {15, 1}, {16, 1}, {17, 1}, {18, 0.225}}, 
 
  UniversalSpace -> {0, 20}]\
\>"], "Output",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Averaging Operations", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Averaging operators are aggregation operators that fall in the region between \
intersections and unions. In this section, we examine some of the common \
averaging operations.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Arithmetic Mean", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
ArithmeticMean[A1,A2,...,An] returns the arithmetic mean of A1, A2, ..., An, \
where the A's are fuzzy sets or fuzzy relations.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["AM = ArithmeticMean[FS1,FS2]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
FuzzySet[{{1, 1/4}, {2, 1/2}, {3, 1/2}, {4, 0.5375}, {5, 0.575}, 
 
   {6, 0.6125}, {7, 0.65}, {8, 0.6875}, {9, 0.675}, 
 
   {10, 0.6625000000000001}, {11, 0.65}, {12, 0.6375}, 
 
   {13, 0.625}, {14, 0.6125}, {15, 0.6}, 
 
   {16, 0.4375000000000001}, {17, 0.2750000000000001}, 
 
   {18, 0.1125000000000003}}, UniversalSpace -> {0, 20}]











\
\>", "\<\
              1       1       1
FuzzySet[{{1, -}, {2, -}, {3, -}, {4, 0.5375}, {5, 0.575}, 
              4       2       2
 
   {6, 0.6125}, {7, 0.65}, {8, 0.6875}, {9, 0.675}, 
 
   {10, 0.6625}, {11, 0.65}, {12, 0.6375}, {13, 0.625}, 
 
   {14, 0.6125}, {15, 0.6}, {16, 0.4375}, {17, 0.275}, 
 
   {18, 0.1125}}, UniversalSpace -> {0, 20}]\
\>"], "Output",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell["\<\
We look at how this averaging operation behave by plotting the original fuzzy \
sets with their average. The membership grades for the average fuzzy set \
falls between the membership grades of the two original fuzzy sets.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzyPlot[FS1,FS2,AM,PlotJoined->True];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0454545 0.0454545 0 0.618034 [
[(1)] .09091 0 0 2 Msboxa
[(3)] .18182 0 0 2 Msboxa
[(5)] .27273 0 0 2 Msboxa
[(7)] .36364 0 0 2 Msboxa
[(9)] .45455 0 0 2 Msboxa
[(11)] .54545 0 0 2 Msboxa
[(13)] .63636 0 0 2 Msboxa
[(15)] .72727 0 0 2 Msboxa
[(17)] .81818 0 0 2 Msboxa
[(19)] .90909 0 0 2 Msboxa
[(21)] 1 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.09091 0 m
.09091 .00625 L
s
P
[(1)] .09091 0 0 2 Mshowa
p
.002 w
.18182 0 m
.18182 .00625 L
s
P
[(3)] .18182 0 0 2 Mshowa
p
.002 w
.27273 0 m
.27273 .00625 L
s
P
[(5)] .27273 0 0 2 Mshowa
p
.002 w
.36364 0 m
.36364 .00625 L
s
P
[(7)] .36364 0 0 2 Mshowa
p
.002 w
.45455 0 m
.45455 .00625 L
s
P
[(9)] .45455 0 0 2 Mshowa
p
.002 w
.54545 0 m
.54545 .00625 L
s
P
[(11)] .54545 0 0 2 Mshowa
p
.002 w
.63636 0 m
.63636 .00625 L
s
P
[(13)] .63636 0 0 2 Mshowa
p
.002 w
.72727 0 m
.72727 .00625 L
s
P
[(15)] .72727 0 0 2 Mshowa
p
.002 w
.81818 0 m
.81818 .00625 L
s
P
[(17)] .81818 0 0 2 Mshowa
p
.002 w
.90909 0 m
.90909 .00625 L
s
P
[(19)] .90909 0 0 2 Mshowa
p
.002 w
1 0 m
1 .00625 L
s
P
[(21)] 1 0 0 2 Mshowa
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
1.44338 Mabswid
.04545 0 m
.09091 .30902 L
.13636 .61803 L
.18182 .61803 L
.22727 .61803 L
.27273 .61803 L
.31818 .61803 L
.36364 .61803 L
.40909 .61803 L
.45455 .55623 L
.5 .49443 L
.54545 .43262 L
.59091 .37082 L
.63636 .30902 L
.68182 .24721 L
.72727 .18541 L
.77273 .12361 L
.81818 .0618 L
.86364 0 L
.90909 0 L
.95455 0 L
s
P
p
.2 0 1 r
1.44338 Mabswid
.04545 0 m
.09091 0 L
.13636 0 L
.18182 0 L
.22727 .04635 L
.27273 .09271 L
.31818 .13906 L
.36364 .18541 L
.40909 .23176 L
.45455 .27812 L
.5 .32447 L
.54545 .37082 L
.59091 .41717 L
.63636 .46353 L
.68182 .50988 L
.72727 .55623 L
.77273 .41717 L
.81818 .27812 L
.86364 .13906 L
.90909 0 L
.95455 0 L
s
P
p
0 1 .4 r
1.44338 Mabswid
.04545 0 m
.09091 .15451 L
.13636 .30902 L
.18182 .30902 L
.22727 .33219 L
.27273 .35537 L
.31818 .37855 L
.36364 .40172 L
.40909 .4249 L
.45455 .41717 L
.5 .40945 L
.54545 .40172 L
.59091 .394 L
.63636 .38627 L
.68182 .37855 L
.72727 .37082 L
.77273 .27039 L
.81818 .16996 L
.86364 .06953 L
.90909 0 L
.95455 0 L
s
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{398, 246},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Geometric Mean", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
GeometricMean[A1,A2,..,An] returns the geometric mean of A1, A2, ..., An, \
where the A's are fuzzy sets or fuzzy relations.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["GM = GeometricMean[FS1,FS2]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
FuzzySet[{{4, 0.273861278752583}, {5, 0.3872983346207417}, 
 
   {6, 0.4743416490252569}, {7, 0.5477225575051661}, 
 
   {8, 0.6123724356957946}, {9, 0.6363961030678928}, 
 
   {10, 0.6480740698407861}, {11, 0.6480740698407861}, 
 
   {12, 0.6363961030678928}, {13, 0.6123724356957946}, 
 
   {14, 0.5744562646538029}, {15, 0.5196152422706632}, 
 
   {16, 0.3674234614174768}, {17, 0.2121320343559643}}, 
 
  UniversalSpace -> {0, 20}]











\
\>", "\<\
FuzzySet[{{4, 0.273861}, {5, 0.387298}, {6, 0.474342}, 
 
   {7, 0.547723}, {8, 0.612372}, {9, 0.636396}, {10, 0.648074}, 
 
   {11, 0.648074}, {12, 0.636396}, {13, 0.612372}, 
 
   {14, 0.574456}, {15, 0.519615}, {16, 0.367423}, 
 
   {17, 0.212132}}, UniversalSpace -> {0, 20}]\
\>"], "Output",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["FuzzyPlot[FS1,FS2,GM,PlotJoined->True];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0454545 0.0454545 0 0.618034 [
[(1)] .09091 0 0 2 Msboxa
[(3)] .18182 0 0 2 Msboxa
[(5)] .27273 0 0 2 Msboxa
[(7)] .36364 0 0 2 Msboxa
[(9)] .45455 0 0 2 Msboxa
[(11)] .54545 0 0 2 Msboxa
[(13)] .63636 0 0 2 Msboxa
[(15)] .72727 0 0 2 Msboxa
[(17)] .81818 0 0 2 Msboxa
[(19)] .90909 0 0 2 Msboxa
[(21)] 1 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.09091 0 m
.09091 .00625 L
s
P
[(1)] .09091 0 0 2 Mshowa
p
.002 w
.18182 0 m
.18182 .00625 L
s
P
[(3)] .18182 0 0 2 Mshowa
p
.002 w
.27273 0 m
.27273 .00625 L
s
P
[(5)] .27273 0 0 2 Mshowa
p
.002 w
.36364 0 m
.36364 .00625 L
s
P
[(7)] .36364 0 0 2 Mshowa
p
.002 w
.45455 0 m
.45455 .00625 L
s
P
[(9)] .45455 0 0 2 Mshowa
p
.002 w
.54545 0 m
.54545 .00625 L
s
P
[(11)] .54545 0 0 2 Mshowa
p
.002 w
.63636 0 m
.63636 .00625 L
s
P
[(13)] .63636 0 0 2 Mshowa
p
.002 w
.72727 0 m
.72727 .00625 L
s
P
[(15)] .72727 0 0 2 Mshowa
p
.002 w
.81818 0 m
.81818 .00625 L
s
P
[(17)] .81818 0 0 2 Mshowa
p
.002 w
.90909 0 m
.90909 .00625 L
s
P
[(19)] .90909 0 0 2 Mshowa
p
.002 w
1 0 m
1 .00625 L
s
P
[(21)] 1 0 0 2 Mshowa
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
1.44338 Mabswid
.04545 0 m
.09091 .30902 L
.13636 .61803 L
.18182 .61803 L
.22727 .61803 L
.27273 .61803 L
.31818 .61803 L
.36364 .61803 L
.40909 .61803 L
.45455 .55623 L
.5 .49443 L
.54545 .43262 L
.59091 .37082 L
.63636 .30902 L
.68182 .24721 L
.72727 .18541 L
.77273 .12361 L
.81818 .0618 L
.86364 0 L
.90909 0 L
.95455 0 L
s
P
p
.2 0 1 r
1.44338 Mabswid
.04545 0 m
.09091 0 L
.13636 0 L
.18182 0 L
.22727 .04635 L
.27273 .09271 L
.31818 .13906 L
.36364 .18541 L
.40909 .23176 L
.45455 .27812 L
.5 .32447 L
.54545 .37082 L
.59091 .41717 L
.63636 .46353 L
.68182 .50988 L
.72727 .55623 L
.77273 .41717 L
.81818 .27812 L
.86364 .13906 L
.90909 0 L
.95455 0 L
s
P
p
0 1 .4 r
1.44338 Mabswid
.04545 0 m
.09091 0 L
.13636 0 L
.18182 0 L
.22727 .16926 L
.27273 .23936 L
.31818 .29316 L
.36364 .33851 L
.40909 .37847 L
.45455 .39331 L
.5 .40053 L
.54545 .40053 L
.59091 .39331 L
.63636 .37847 L
.68182 .35503 L
.72727 .32114 L
.77273 .22708 L
.81818 .1311 L
.86364 0 L
.90909 0 L
.95455 0 L
s
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{398, 246},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Harmonic Mean", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
HarmonicMean[A1,A2,...,An] returns the harmonic mean of A1, A2, ..., An, \
where the A's are fuzzy sets or fuzzy relations.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["HM = HarmonicMean[FS1,FS2]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
FuzzySet[{{4, 0.1395348837209302}, {5, 0.2608695652173913}, 
 
   {6, 0.3673469387755102}, {7, 0.4615384615384615}, 
 
   {8, 0.5454545454545455}, {9, 0.6}, {10, 0.6339622641509434}, 
 
   {11, 0.6461538461538461}, {12, 0.6352941176470588}, 
 
   {13, 0.6000000000000001}, {14, 0.5387755102040817}, 
 
   {15, 0.45}, {16, 0.3085714285714286}, 
 
   {17, 0.1636363636363636}}, UniversalSpace -> {0, 20}]











\
\>", "\<\
FuzzySet[{{4, 0.139535}, {5, 0.26087}, {6, 0.367347}, 
 
   {7, 0.461538}, {8, 0.545455}, {9, 0.6}, {10, 0.633962}, 
 
   {11, 0.646154}, {12, 0.635294}, {13, 0.6}, {14, 0.538776}, 
 
   {15, 0.45}, {16, 0.308571}, {17, 0.163636}}, 
 
  UniversalSpace -> {0, 20}]\
\>"], "Output",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["FuzzyPlot[FS1,FS2,HM,PlotJoined->True];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0454545 0.0454545 0 0.618034 [
[(1)] .09091 0 0 2 Msboxa
[(3)] .18182 0 0 2 Msboxa
[(5)] .27273 0 0 2 Msboxa
[(7)] .36364 0 0 2 Msboxa
[(9)] .45455 0 0 2 Msboxa
[(11)] .54545 0 0 2 Msboxa
[(13)] .63636 0 0 2 Msboxa
[(15)] .72727 0 0 2 Msboxa
[(17)] .81818 0 0 2 Msboxa
[(19)] .90909 0 0 2 Msboxa
[(21)] 1 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.09091 0 m
.09091 .00625 L
s
P
[(1)] .09091 0 0 2 Mshowa
p
.002 w
.18182 0 m
.18182 .00625 L
s
P
[(3)] .18182 0 0 2 Mshowa
p
.002 w
.27273 0 m
.27273 .00625 L
s
P
[(5)] .27273 0 0 2 Mshowa
p
.002 w
.36364 0 m
.36364 .00625 L
s
P
[(7)] .36364 0 0 2 Mshowa
p
.002 w
.45455 0 m
.45455 .00625 L
s
P
[(9)] .45455 0 0 2 Mshowa
p
.002 w
.54545 0 m
.54545 .00625 L
s
P
[(11)] .54545 0 0 2 Mshowa
p
.002 w
.63636 0 m
.63636 .00625 L
s
P
[(13)] .63636 0 0 2 Mshowa
p
.002 w
.72727 0 m
.72727 .00625 L
s
P
[(15)] .72727 0 0 2 Mshowa
p
.002 w
.81818 0 m
.81818 .00625 L
s
P
[(17)] .81818 0 0 2 Mshowa
p
.002 w
.90909 0 m
.90909 .00625 L
s
P
[(19)] .90909 0 0 2 Mshowa
p
.002 w
1 0 m
1 .00625 L
s
P
[(21)] 1 0 0 2 Mshowa
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
1.44338 Mabswid
.04545 0 m
.09091 .30902 L
.13636 .61803 L
.18182 .61803 L
.22727 .61803 L
.27273 .61803 L
.31818 .61803 L
.36364 .61803 L
.40909 .61803 L
.45455 .55623 L
.5 .49443 L
.54545 .43262 L
.59091 .37082 L
.63636 .30902 L
.68182 .24721 L
.72727 .18541 L
.77273 .12361 L
.81818 .0618 L
.86364 0 L
.90909 0 L
.95455 0 L
s
P
p
.2 0 1 r
1.44338 Mabswid
.04545 0 m
.09091 0 L
.13636 0 L
.18182 0 L
.22727 .04635 L
.27273 .09271 L
.31818 .13906 L
.36364 .18541 L
.40909 .23176 L
.45455 .27812 L
.5 .32447 L
.54545 .37082 L
.59091 .41717 L
.63636 .46353 L
.68182 .50988 L
.72727 .55623 L
.77273 .41717 L
.81818 .27812 L
.86364 .13906 L
.90909 0 L
.95455 0 L
s
P
p
0 1 .4 r
1.44338 Mabswid
.04545 0 m
.09091 0 L
.13636 0 L
.18182 0 L
.22727 .08624 L
.27273 .16123 L
.31818 .22703 L
.36364 .28525 L
.40909 .33711 L
.45455 .37082 L
.5 .39181 L
.54545 .39935 L
.59091 .39263 L
.63636 .37082 L
.68182 .33298 L
.72727 .27812 L
.77273 .19071 L
.81818 .10113 L
.86364 0 L
.90909 0 L
.95455 0 L
s
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{398, 246},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]],

Cell["\<\
Now, we compare the various averaging operations by plotting the all results \
of the averaging operations on the same graph.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzyPlot[AM,GM,HM,PlotJoined->True];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0454545 0.0454545 0 0.618034 [
[(1)] .09091 0 0 2 Msboxa
[(3)] .18182 0 0 2 Msboxa
[(5)] .27273 0 0 2 Msboxa
[(7)] .36364 0 0 2 Msboxa
[(9)] .45455 0 0 2 Msboxa
[(11)] .54545 0 0 2 Msboxa
[(13)] .63636 0 0 2 Msboxa
[(15)] .72727 0 0 2 Msboxa
[(17)] .81818 0 0 2 Msboxa
[(19)] .90909 0 0 2 Msboxa
[(21)] 1 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.09091 0 m
.09091 .00625 L
s
P
[(1)] .09091 0 0 2 Mshowa
p
.002 w
.18182 0 m
.18182 .00625 L
s
P
[(3)] .18182 0 0 2 Mshowa
p
.002 w
.27273 0 m
.27273 .00625 L
s
P
[(5)] .27273 0 0 2 Mshowa
p
.002 w
.36364 0 m
.36364 .00625 L
s
P
[(7)] .36364 0 0 2 Mshowa
p
.002 w
.45455 0 m
.45455 .00625 L
s
P
[(9)] .45455 0 0 2 Mshowa
p
.002 w
.54545 0 m
.54545 .00625 L
s
P
[(11)] .54545 0 0 2 Mshowa
p
.002 w
.63636 0 m
.63636 .00625 L
s
P
[(13)] .63636 0 0 2 Mshowa
p
.002 w
.72727 0 m
.72727 .00625 L
s
P
[(15)] .72727 0 0 2 Mshowa
p
.002 w
.81818 0 m
.81818 .00625 L
s
P
[(17)] .81818 0 0 2 Mshowa
p
.002 w
.90909 0 m
.90909 .00625 L
s
P
[(19)] .90909 0 0 2 Mshowa
p
.002 w
1 0 m
1 .00625 L
s
P
[(21)] 1 0 0 2 Mshowa
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
1.44338 Mabswid
.04545 0 m
.09091 .15451 L
.13636 .30902 L
.18182 .30902 L
.22727 .33219 L
.27273 .35537 L
.31818 .37855 L
.36364 .40172 L
.40909 .4249 L
.45455 .41717 L
.5 .40945 L
.54545 .40172 L
.59091 .394 L
.63636 .38627 L
.68182 .37855 L
.72727 .37082 L
.77273 .27039 L
.81818 .16996 L
.86364 .06953 L
.90909 0 L
.95455 0 L
s
P
p
.2 0 1 r
1.44338 Mabswid
.04545 0 m
.09091 0 L
.13636 0 L
.18182 0 L
.22727 .16926 L
.27273 .23936 L
.31818 .29316 L
.36364 .33851 L
.40909 .37847 L
.45455 .39331 L
.5 .40053 L
.54545 .40053 L
.59091 .39331 L
.63636 .37847 L
.68182 .35503 L
.72727 .32114 L
.77273 .22708 L
.81818 .1311 L
.86364 0 L
.90909 0 L
.95455 0 L
s
P
p
0 1 .4 r
1.44338 Mabswid
.04545 0 m
.09091 0 L
.13636 0 L
.18182 0 L
.22727 .08624 L
.27273 .16123 L
.31818 .22703 L
.36364 .28525 L
.40909 .33711 L
.45455 .37082 L
.5 .39181 L
.54545 .39935 L
.59091 .39263 L
.63636 .37082 L
.68182 .33298 L
.72727 .27812 L
.77273 .19071 L
.81818 .10113 L
.86364 0 L
.90909 0 L
.95455 0 L
s
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{399, 246},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Generalized Mean", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
GeneralizedMean[A1,A2,...,An,alpha] returns the generalized mean of A1, A2, \
..., An, where the A's are fuzzy sets or fuzzy relations. This function takes \
a parameter alpha.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
This function is a general averaging function which encompasses the full \
range of averaging operations. The averaging operations shown earlier are \
specific cases of the generalized mean. This function provides you with a \
great deal of flexibility when choosing how to average fuzzy sets. Here is an \
example where the parameter alpha is 2.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["GenM = GeneralizedMean[FS1,FS2,2]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
FuzzySet[{{1, 0.3535533905932738}, {2, 0.7071067811865476}, 
 
   {3, 0.7071067811865476}, {4, 0.7090927301841418}, 
 
   {5, 0.7150174823037547}, {6, 0.7247844507162112}, 
 
   {7, 0.7382411530116701}, {8, 0.7551903733496608}, 
 
   {9, 0.7115124735378854}, {10, 0.6766184301362179}, 
 
   {11, 0.6519202405202649}, {12, 0.63860198872224}, 
 
   {13, 0.6373774391990981}, {14, 0.648315123994497}, 
 
   {15, 0.670820393249937}, {16, 0.4978076937934972}, 
 
   {17, 0.3259601202601325}, {18, 0.1590990257669736}}, 
 
  UniversalSpace -> {0, 20}]











\
\>", "\<\
FuzzySet[{{1, 0.353553}, {2, 0.707107}, {3, 0.707107}, 
 
   {4, 0.709093}, {5, 0.715017}, {6, 0.724784}, {7, 0.738241}, 
 
   {8, 0.75519}, {9, 0.711512}, {10, 0.676618}, {11, 0.65192}, 
 
   {12, 0.638602}, {13, 0.637377}, {14, 0.648315}, 
 
   {15, 0.67082}, {16, 0.497808}, {17, 0.32596}, {18, 0.159099}}\\
 
   , UniversalSpace -> {0, 20}]\
\>"], "Output",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["FuzzyPlot[FS1,FS2,GenM,PlotJoined->True];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0454545 0.0454545 0 0.618034 [
[(1)] .09091 0 0 2 Msboxa
[(3)] .18182 0 0 2 Msboxa
[(5)] .27273 0 0 2 Msboxa
[(7)] .36364 0 0 2 Msboxa
[(9)] .45455 0 0 2 Msboxa
[(11)] .54545 0 0 2 Msboxa
[(13)] .63636 0 0 2 Msboxa
[(15)] .72727 0 0 2 Msboxa
[(17)] .81818 0 0 2 Msboxa
[(19)] .90909 0 0 2 Msboxa
[(21)] 1 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.09091 0 m
.09091 .00625 L
s
P
[(1)] .09091 0 0 2 Mshowa
p
.002 w
.18182 0 m
.18182 .00625 L
s
P
[(3)] .18182 0 0 2 Mshowa
p
.002 w
.27273 0 m
.27273 .00625 L
s
P
[(5)] .27273 0 0 2 Mshowa
p
.002 w
.36364 0 m
.36364 .00625 L
s
P
[(7)] .36364 0 0 2 Mshowa
p
.002 w
.45455 0 m
.45455 .00625 L
s
P
[(9)] .45455 0 0 2 Mshowa
p
.002 w
.54545 0 m
.54545 .00625 L
s
P
[(11)] .54545 0 0 2 Mshowa
p
.002 w
.63636 0 m
.63636 .00625 L
s
P
[(13)] .63636 0 0 2 Mshowa
p
.002 w
.72727 0 m
.72727 .00625 L
s
P
[(15)] .72727 0 0 2 Mshowa
p
.002 w
.81818 0 m
.81818 .00625 L
s
P
[(17)] .81818 0 0 2 Mshowa
p
.002 w
.90909 0 m
.90909 .00625 L
s
P
[(19)] .90909 0 0 2 Mshowa
p
.002 w
1 0 m
1 .00625 L
s
P
[(21)] 1 0 0 2 Mshowa
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
1.44338 Mabswid
.04545 0 m
.09091 .30902 L
.13636 .61803 L
.18182 .61803 L
.22727 .61803 L
.27273 .61803 L
.31818 .61803 L
.36364 .61803 L
.40909 .61803 L
.45455 .55623 L
.5 .49443 L
.54545 .43262 L
.59091 .37082 L
.63636 .30902 L
.68182 .24721 L
.72727 .18541 L
.77273 .12361 L
.81818 .0618 L
.86364 0 L
.90909 0 L
.95455 0 L
s
P
p
.2 0 1 r
1.44338 Mabswid
.04545 0 m
.09091 0 L
.13636 0 L
.18182 0 L
.22727 .04635 L
.27273 .09271 L
.31818 .13906 L
.36364 .18541 L
.40909 .23176 L
.45455 .27812 L
.5 .32447 L
.54545 .37082 L
.59091 .41717 L
.63636 .46353 L
.68182 .50988 L
.72727 .55623 L
.77273 .41717 L
.81818 .27812 L
.86364 .13906 L
.90909 0 L
.95455 0 L
s
P
p
0 1 .4 r
1.44338 Mabswid
.04545 0 m
.09091 .21851 L
.13636 .43702 L
.18182 .43702 L
.22727 .43824 L
.27273 .44191 L
.31818 .44794 L
.36364 .45626 L
.40909 .46673 L
.45455 .43974 L
.5 .41817 L
.54545 .40291 L
.59091 .39468 L
.63636 .39392 L
.68182 .40068 L
.72727 .41459 L
.77273 .30766 L
.81818 .20145 L
.86364 .09833 L
.90909 0 L
.95455 0 L
s
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{398, 246},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Difference Operations", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["General Difference", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Difference[A,B] returns the general difference between A and B, where A and B \
are fuzzy sets or fuzzy relations.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Diff = Difference[FS1,FS2]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
FuzzySet[{{1, 1/2}, {2, 1}, {3, 1}, {4, 0.925}, {5, 0.85}, 
 
   {6, 0.775}, {7, 0.7}, {8, 0.625}, {9, 0.55}, {10, 0.475}, 
 
   {11, 0.4}, {12, 0.3250000000000001}, {13, 0.25}, {14, 0.175}, 
 
   {15, 0.1}, {16, 1/5}, {17, 1/10}}, UniversalSpace -> {0, 20}]











\
\>", "\<\
              1
FuzzySet[{{1, -}, {2, 1}, {3, 1}, {4, 0.925}, {5, 0.85}, 
              2
 
   {6, 0.775}, {7, 0.7}, {8, 0.625}, {9, 0.55}, {10, 0.475}, 
 
   {11, 0.4}, {12, 0.325}, {13, 0.25}, {14, 0.175}, {15, 0.1}, 
 
        1        1
   {16, -}, {17, --}}, UniversalSpace -> {0, 20}]
        5        10\
\>"], "Output",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell["\<\
To get a feel of what kind of result the differences produce, we plot the \
original fuzzy sets along with the difference on the same plot.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzyPlot[FS1,FS2,Diff,PlotJoined->True];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0454545 0.0454545 0 0.618034 [
[(1)] .09091 0 0 2 Msboxa
[(3)] .18182 0 0 2 Msboxa
[(5)] .27273 0 0 2 Msboxa
[(7)] .36364 0 0 2 Msboxa
[(9)] .45455 0 0 2 Msboxa
[(11)] .54545 0 0 2 Msboxa
[(13)] .63636 0 0 2 Msboxa
[(15)] .72727 0 0 2 Msboxa
[(17)] .81818 0 0 2 Msboxa
[(19)] .90909 0 0 2 Msboxa
[(21)] 1 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.09091 0 m
.09091 .00625 L
s
P
[(1)] .09091 0 0 2 Mshowa
p
.002 w
.18182 0 m
.18182 .00625 L
s
P
[(3)] .18182 0 0 2 Mshowa
p
.002 w
.27273 0 m
.27273 .00625 L
s
P
[(5)] .27273 0 0 2 Mshowa
p
.002 w
.36364 0 m
.36364 .00625 L
s
P
[(7)] .36364 0 0 2 Mshowa
p
.002 w
.45455 0 m
.45455 .00625 L
s
P
[(9)] .45455 0 0 2 Mshowa
p
.002 w
.54545 0 m
.54545 .00625 L
s
P
[(11)] .54545 0 0 2 Mshowa
p
.002 w
.63636 0 m
.63636 .00625 L
s
P
[(13)] .63636 0 0 2 Mshowa
p
.002 w
.72727 0 m
.72727 .00625 L
s
P
[(15)] .72727 0 0 2 Mshowa
p
.002 w
.81818 0 m
.81818 .00625 L
s
P
[(17)] .81818 0 0 2 Mshowa
p
.002 w
.90909 0 m
.90909 .00625 L
s
P
[(19)] .90909 0 0 2 Mshowa
p
.002 w
1 0 m
1 .00625 L
s
P
[(21)] 1 0 0 2 Mshowa
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
1.44338 Mabswid
.04545 0 m
.09091 .30902 L
.13636 .61803 L
.18182 .61803 L
.22727 .61803 L
.27273 .61803 L
.31818 .61803 L
.36364 .61803 L
.40909 .61803 L
.45455 .55623 L
.5 .49443 L
.54545 .43262 L
.59091 .37082 L
.63636 .30902 L
.68182 .24721 L
.72727 .18541 L
.77273 .12361 L
.81818 .0618 L
.86364 0 L
.90909 0 L
.95455 0 L
s
P
p
.2 0 1 r
1.44338 Mabswid
.04545 0 m
.09091 0 L
.13636 0 L
.18182 0 L
.22727 .04635 L
.27273 .09271 L
.31818 .13906 L
.36364 .18541 L
.40909 .23176 L
.45455 .27812 L
.5 .32447 L
.54545 .37082 L
.59091 .41717 L
.63636 .46353 L
.68182 .50988 L
.72727 .55623 L
.77273 .41717 L
.81818 .27812 L
.86364 .13906 L
.90909 0 L
.95455 0 L
s
P
p
0 1 .4 r
1.44338 Mabswid
.04545 0 m
.09091 .30902 L
.13636 .61803 L
.18182 .61803 L
.22727 .57168 L
.27273 .52533 L
.31818 .47898 L
.36364 .43262 L
.40909 .38627 L
.45455 .33992 L
.5 .29357 L
.54545 .24721 L
.59091 .20086 L
.63636 .15451 L
.68182 .10816 L
.72727 .0618 L
.77273 .12361 L
.81818 .0618 L
.86364 0 L
.90909 0 L
.95455 0 L
s
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{397, 245},
  ImageMargins->{{35, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Absolute Difference", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
AbsoluteDifference[A,B] returns the absolute difference between A and B, \
where A and B are fuzzy sets or fuzzy relations.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["AD = AbsoluteDifference[FS1,FS2]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
FuzzySet[{{1, 1/2}, {2, 1}, {3, 1}, {4, 0.925}, {5, 0.85}, 
 
   {6, 0.775}, {7, 0.7}, {8, 0.625}, {9, 0.4500000000000001}, 
 
   {10, 0.275}, {11, 0.1}, {12, 0.07499999999999996}, 
 
   {13, 0.25}, {14, 0.425}, {15, 0.6000000000000001}, 
 
   {16, 0.4750000000000003}, {17, 0.3500000000000002}, 
 
   {18, 0.2250000000000005}}, UniversalSpace -> {0, 20}]











\
\>", "\<\
              1
FuzzySet[{{1, -}, {2, 1}, {3, 1}, {4, 0.925}, {5, 0.85}, 
              2
 
   {6, 0.775}, {7, 0.7}, {8, 0.625}, {9, 0.45}, {10, 0.275}, 
 
   {11, 0.1}, {12, 0.075}, {13, 0.25}, {14, 0.425}, {15, 0.6}, 
 
   {16, 0.475}, {17, 0.35}, {18, 0.225}}, 
 
  UniversalSpace -> {0, 20}]\
\>"], "Output",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell["We again look at the results with the FuzzyPlot function.", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzyPlot[FS1,FS2,AD,PlotJoined->True];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0454545 0.0454545 0 0.618034 [
[(1)] .09091 0 0 2 Msboxa
[(3)] .18182 0 0 2 Msboxa
[(5)] .27273 0 0 2 Msboxa
[(7)] .36364 0 0 2 Msboxa
[(9)] .45455 0 0 2 Msboxa
[(11)] .54545 0 0 2 Msboxa
[(13)] .63636 0 0 2 Msboxa
[(15)] .72727 0 0 2 Msboxa
[(17)] .81818 0 0 2 Msboxa
[(19)] .90909 0 0 2 Msboxa
[(21)] 1 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.09091 0 m
.09091 .00625 L
s
P
[(1)] .09091 0 0 2 Mshowa
p
.002 w
.18182 0 m
.18182 .00625 L
s
P
[(3)] .18182 0 0 2 Mshowa
p
.002 w
.27273 0 m
.27273 .00625 L
s
P
[(5)] .27273 0 0 2 Mshowa
p
.002 w
.36364 0 m
.36364 .00625 L
s
P
[(7)] .36364 0 0 2 Mshowa
p
.002 w
.45455 0 m
.45455 .00625 L
s
P
[(9)] .45455 0 0 2 Mshowa
p
.002 w
.54545 0 m
.54545 .00625 L
s
P
[(11)] .54545 0 0 2 Mshowa
p
.002 w
.63636 0 m
.63636 .00625 L
s
P
[(13)] .63636 0 0 2 Mshowa
p
.002 w
.72727 0 m
.72727 .00625 L
s
P
[(15)] .72727 0 0 2 Mshowa
p
.002 w
.81818 0 m
.81818 .00625 L
s
P
[(17)] .81818 0 0 2 Mshowa
p
.002 w
.90909 0 m
.90909 .00625 L
s
P
[(19)] .90909 0 0 2 Mshowa
p
.002 w
1 0 m
1 .00625 L
s
P
[(21)] 1 0 0 2 Mshowa
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
1.44338 Mabswid
.04545 0 m
.09091 .30902 L
.13636 .61803 L
.18182 .61803 L
.22727 .61803 L
.27273 .61803 L
.31818 .61803 L
.36364 .61803 L
.40909 .61803 L
.45455 .55623 L
.5 .49443 L
.54545 .43262 L
.59091 .37082 L
.63636 .30902 L
.68182 .24721 L
.72727 .18541 L
.77273 .12361 L
.81818 .0618 L
.86364 0 L
.90909 0 L
.95455 0 L
s
P
p
.2 0 1 r
1.44338 Mabswid
.04545 0 m
.09091 0 L
.13636 0 L
.18182 0 L
.22727 .04635 L
.27273 .09271 L
.31818 .13906 L
.36364 .18541 L
.40909 .23176 L
.45455 .27812 L
.5 .32447 L
.54545 .37082 L
.59091 .41717 L
.63636 .46353 L
.68182 .50988 L
.72727 .55623 L
.77273 .41717 L
.81818 .27812 L
.86364 .13906 L
.90909 0 L
.95455 0 L
s
P
p
0 1 .4 r
1.44338 Mabswid
.04545 0 m
.09091 .30902 L
.13636 .61803 L
.18182 .61803 L
.22727 .57168 L
.27273 .52533 L
.31818 .47898 L
.36364 .43262 L
.40909 .38627 L
.45455 .27812 L
.5 .16996 L
.54545 .0618 L
.59091 .04635 L
.63636 .15451 L
.68182 .26266 L
.72727 .37082 L
.77273 .29357 L
.81818 .21631 L
.86364 .13906 L
.90909 0 L
.95455 0 L
s
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{398, 246},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Symmetric Difference", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
SymmetricDifference[A,B] returns the symmetric difference between A and B, \
where A and B are fuzzy sets or fuzzy relations.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["SD = SymmetricDifference[FS1,FS2]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
FuzzySet[{{1, 1/2}, {2, 1}, {3, 1}, {4, 0.925}, {5, 0.85}, 
 
   {6, 0.775}, {7, 0.7}, {8, 0.625}, {9, 0.55}, {10, 0.475}, 
 
   {11, 0.4}, {12, 2/5}, {13, 1/2}, {14, 3/5}, {15, 7/10}, 
 
   {16, 0.6750000000000003}, {17, 0.4500000000000002}, 
 
   {18, 0.2250000000000005}}, UniversalSpace -> {0, 20}]











\
\>", "\<\
              1
FuzzySet[{{1, -}, {2, 1}, {3, 1}, {4, 0.925}, {5, 0.85}, 
              2
 
   {6, 0.775}, {7, 0.7}, {8, 0.625}, {9, 0.55}, {10, 0.475}, 
 
                   2        1        3        7
   {11, 0.4}, {12, -}, {13, -}, {14, -}, {15, --}, {16, 0.675}, 
                   5        2        5        10
 
   {17, 0.45}, {18, 0.225}}, UniversalSpace -> {0, 20}]\
\>"], "Output",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["FuzzyPlot[FS1,FS2,SD,PlotJoined->True];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0454545 0.0454545 0 0.618034 [
[(1)] .09091 0 0 2 Msboxa
[(3)] .18182 0 0 2 Msboxa
[(5)] .27273 0 0 2 Msboxa
[(7)] .36364 0 0 2 Msboxa
[(9)] .45455 0 0 2 Msboxa
[(11)] .54545 0 0 2 Msboxa
[(13)] .63636 0 0 2 Msboxa
[(15)] .72727 0 0 2 Msboxa
[(17)] .81818 0 0 2 Msboxa
[(19)] .90909 0 0 2 Msboxa
[(21)] 1 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.09091 0 m
.09091 .00625 L
s
P
[(1)] .09091 0 0 2 Mshowa
p
.002 w
.18182 0 m
.18182 .00625 L
s
P
[(3)] .18182 0 0 2 Mshowa
p
.002 w
.27273 0 m
.27273 .00625 L
s
P
[(5)] .27273 0 0 2 Mshowa
p
.002 w
.36364 0 m
.36364 .00625 L
s
P
[(7)] .36364 0 0 2 Mshowa
p
.002 w
.45455 0 m
.45455 .00625 L
s
P
[(9)] .45455 0 0 2 Mshowa
p
.002 w
.54545 0 m
.54545 .00625 L
s
P
[(11)] .54545 0 0 2 Mshowa
p
.002 w
.63636 0 m
.63636 .00625 L
s
P
[(13)] .63636 0 0 2 Mshowa
p
.002 w
.72727 0 m
.72727 .00625 L
s
P
[(15)] .72727 0 0 2 Mshowa
p
.002 w
.81818 0 m
.81818 .00625 L
s
P
[(17)] .81818 0 0 2 Mshowa
p
.002 w
.90909 0 m
.90909 .00625 L
s
P
[(19)] .90909 0 0 2 Mshowa
p
.002 w
1 0 m
1 .00625 L
s
P
[(21)] 1 0 0 2 Mshowa
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
1.44338 Mabswid
.04545 0 m
.09091 .30902 L
.13636 .61803 L
.18182 .61803 L
.22727 .61803 L
.27273 .61803 L
.31818 .61803 L
.36364 .61803 L
.40909 .61803 L
.45455 .55623 L
.5 .49443 L
.54545 .43262 L
.59091 .37082 L
.63636 .30902 L
.68182 .24721 L
.72727 .18541 L
.77273 .12361 L
.81818 .0618 L
.86364 0 L
.90909 0 L
.95455 0 L
s
P
p
.2 0 1 r
1.44338 Mabswid
.04545 0 m
.09091 0 L
.13636 0 L
.18182 0 L
.22727 .04635 L
.27273 .09271 L
.31818 .13906 L
.36364 .18541 L
.40909 .23176 L
.45455 .27812 L
.5 .32447 L
.54545 .37082 L
.59091 .41717 L
.63636 .46353 L
.68182 .50988 L
.72727 .55623 L
.77273 .41717 L
.81818 .27812 L
.86364 .13906 L
.90909 0 L
.95455 0 L
s
P
p
0 1 .4 r
1.44338 Mabswid
.04545 0 m
.09091 .30902 L
.13636 .61803 L
.18182 .61803 L
.22727 .57168 L
.27273 .52533 L
.31818 .47898 L
.36364 .43262 L
.40909 .38627 L
.45455 .33992 L
.5 .29357 L
.54545 .24721 L
.59091 .24721 L
.63636 .30902 L
.68182 .37082 L
.72727 .43262 L
.77273 .41717 L
.81818 .27812 L
.86364 .13906 L
.90909 0 L
.95455 0 L
s
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{398, 246},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Additional Aggregators", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["User-defined Aggregator", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
GeneralAggregator[fun,A1,A2,..,An] uses the function fun to combine the \
membership grades of A1, A2, ..., An, where the A's are either fuzzy sets or \
fuzzy relations.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Here we demonstrate this function by first creating a function for combining \
the membership grades of the elements and then calling GeneralAggregator with \
this function and our two fuzzy sets.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["MyAgg[x_,y_] := Max[x,y]/2", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["GA = GeneralAggregator[MyAgg,FS1,FS2]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
FuzzySet[{{1, 1/4}, {2, 1/2}, {3, 1/2}, {4, 1/2}, {5, 1/2}, 
 
   {6, 1/2}, {7, 1/2}, {8, 1/2}, {9, 9/20}, {10, 2/5}, 
 
   {11, 7/20}, {12, 0.3375}, {13, 0.375}, {14, 0.4125}, 
 
   {15, 0.45}, {16, 0.3375000000000001}, 
 
   {17, 0.2250000000000001}, {18, 0.1125000000000003}}, 
 
  UniversalSpace -> {0, 20}]











\
\>", "\<\
              1       1       1       1       1       1
FuzzySet[{{1, -}, {2, -}, {3, -}, {4, -}, {5, -}, {6, -}, 
              4       2       2       2       2       2
 
       1       1       9         2        7
   {7, -}, {8, -}, {9, --}, {10, -}, {11, --}, {12, 0.3375}, 
       2       2       20        5        20
 
   {13, 0.375}, {14, 0.4125}, {15, 0.45}, {16, 0.3375}, 
 
   {17, 0.225}, {18, 0.1125}}, UniversalSpace -> {0, 20}]\
\>"], "Output",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell["\<\
To see how our new aggregator behaves, we look at a plot of the results from \
the previous calculation.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzyPlot[FS1,FS2,GA,PlotJoined->True];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0454545 0.0454545 0 0.618034 [
[(1)] .09091 0 0 2 Msboxa
[(3)] .18182 0 0 2 Msboxa
[(5)] .27273 0 0 2 Msboxa
[(7)] .36364 0 0 2 Msboxa
[(9)] .45455 0 0 2 Msboxa
[(11)] .54545 0 0 2 Msboxa
[(13)] .63636 0 0 2 Msboxa
[(15)] .72727 0 0 2 Msboxa
[(17)] .81818 0 0 2 Msboxa
[(19)] .90909 0 0 2 Msboxa
[(21)] 1 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.09091 0 m
.09091 .00625 L
s
P
[(1)] .09091 0 0 2 Mshowa
p
.002 w
.18182 0 m
.18182 .00625 L
s
P
[(3)] .18182 0 0 2 Mshowa
p
.002 w
.27273 0 m
.27273 .00625 L
s
P
[(5)] .27273 0 0 2 Mshowa
p
.002 w
.36364 0 m
.36364 .00625 L
s
P
[(7)] .36364 0 0 2 Mshowa
p
.002 w
.45455 0 m
.45455 .00625 L
s
P
[(9)] .45455 0 0 2 Mshowa
p
.002 w
.54545 0 m
.54545 .00625 L
s
P
[(11)] .54545 0 0 2 Mshowa
p
.002 w
.63636 0 m
.63636 .00625 L
s
P
[(13)] .63636 0 0 2 Mshowa
p
.002 w
.72727 0 m
.72727 .00625 L
s
P
[(15)] .72727 0 0 2 Mshowa
p
.002 w
.81818 0 m
.81818 .00625 L
s
P
[(17)] .81818 0 0 2 Mshowa
p
.002 w
.90909 0 m
.90909 .00625 L
s
P
[(19)] .90909 0 0 2 Mshowa
p
.002 w
1 0 m
1 .00625 L
s
P
[(21)] 1 0 0 2 Mshowa
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
1.44338 Mabswid
.04545 0 m
.09091 .30902 L
.13636 .61803 L
.18182 .61803 L
.22727 .61803 L
.27273 .61803 L
.31818 .61803 L
.36364 .61803 L
.40909 .61803 L
.45455 .55623 L
.5 .49443 L
.54545 .43262 L
.59091 .37082 L
.63636 .30902 L
.68182 .24721 L
.72727 .18541 L
.77273 .12361 L
.81818 .0618 L
.86364 0 L
.90909 0 L
.95455 0 L
s
P
p
.2 0 1 r
1.44338 Mabswid
.04545 0 m
.09091 0 L
.13636 0 L
.18182 0 L
.22727 .04635 L
.27273 .09271 L
.31818 .13906 L
.36364 .18541 L
.40909 .23176 L
.45455 .27812 L
.5 .32447 L
.54545 .37082 L
.59091 .41717 L
.63636 .46353 L
.68182 .50988 L
.72727 .55623 L
.77273 .41717 L
.81818 .27812 L
.86364 .13906 L
.90909 0 L
.95455 0 L
s
P
p
0 1 .4 r
1.44338 Mabswid
.04545 0 m
.09091 .15451 L
.13636 .30902 L
.18182 .30902 L
.22727 .30902 L
.27273 .30902 L
.31818 .30902 L
.36364 .30902 L
.40909 .30902 L
.45455 .27812 L
.5 .24721 L
.54545 .21631 L
.59091 .20859 L
.63636 .23176 L
.68182 .25494 L
.72727 .27812 L
.77273 .20859 L
.81818 .13906 L
.86364 .06953 L
.90909 0 L
.95455 0 L
s
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{398, 246},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]]}, Open]]}, Open]]}, Open]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{496, 599},
WindowMargins->{{Automatic, 190}, {23, Automatic}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False}
]



(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 88, 7, 70, "Title"],

Cell[CellGroupData[{
Cell[1850, 60, 67, 1, 70, "Subsection"],
Cell[1920, 63, 256, 5, 70, "Text"],
Cell[2179, 70, 143, 4, 70, "Text"],
Cell[2325, 76, 102, 2, 70, "Input"],
Cell[2430, 80, 304, 6, 70, "SmallText"],
Cell[2737, 88, 364, 7, 70, "Text"],
Cell[3104, 97, 272, 5, 70, "Text"],
Cell[3379, 104, 188, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[3590, 110, 105, 2, 70, "Input"],
Cell[3698, 114, 760, 34, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4490, 150, 108, 2, 70, "Input"],
Cell[4601, 154, 635, 32, 70, "Output"]
}, Open  ]],
Cell[5248, 188, 258, 5, 70, "Text"],

Cell[CellGroupData[{
Cell[5529, 195, 92, 2, 70, "Input"],
Cell[5624, 199, 5130, 571, 70, 4972, 566, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],
Cell[10775, 772, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[10848, 775, 87, 1, 70, "Subsection"],
Cell[10938, 778, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[11011, 781, 98, 1, 70, "Subsubsection"],
Cell[11112, 784, 413, 7, 70, "Text"],
Cell[11528, 793, 354, 9, 70, "Special3"],
Cell[11885, 804, 241, 5, 70, "Text"],

Cell[CellGroupData[{
Cell[12149, 811, 100, 2, 70, "Input"],
Cell[12252, 815, 747, 34, 70, "Output"]
}, Open  ]],
Cell[13011, 851, 331, 6, 70, "Text"],

Cell[CellGroupData[{
Cell[13365, 859, 113, 2, 70, "Input"],
Cell[13481, 863, 4229, 387, 70, 4071, 382, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[17722, 1252, 246, 5, 70, "Text"],

Cell[CellGroupData[{
Cell[17991, 1259, 118, 2, 70, "Input"],
Cell[18112, 1263, 730, 38, 70, "Output"]
}, Open  ]],
Cell[18854, 1303, 349, 6, 70, "Text"],

Cell[CellGroupData[{
Cell[19226, 1311, 92, 2, 70, "Input"],
Cell[19321, 1315, 5109, 571, 70, 4951, 566, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],
Cell[24451, 1888, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[24524, 1891, 66, 1, 70, "Subsubsection"],
Cell[24593, 1894, 429, 7, 70, "Text"],
Cell[25025, 1903, 331, 9, 70, "Special3"],
Cell[25359, 1914, 177, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[25559, 1920, 114, 2, 70, "Input"],
Cell[25676, 1924, 555, 30, 70, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[26261, 1956, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[26334, 1959, 80, 1, 70, "Subsection"],
Cell[26417, 1962, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[26490, 1965, 91, 1, 70, "Subsubsection"],
Cell[26584, 1968, 360, 6, 70, "Text"],
Cell[26947, 1976, 354, 9, 70, "Special3"],
Cell[27304, 1987, 152, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[27479, 1993, 93, 2, 70, "Input"],
Cell[27575, 1997, 765, 36, 70, "Output"]
}, Open  ]],
Cell[28352, 2035, 422, 7, 70, "Text"],

Cell[CellGroupData[{
Cell[28797, 2044, 113, 2, 70, "Input"],
Cell[28913, 2048, 4250, 387, 70, 4092, 382, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[33175, 2437, 239, 5, 70, "Text"],

Cell[CellGroupData[{
Cell[33437, 2444, 108, 2, 70, "Input"],
Cell[33548, 2448, 811, 38, 70, "Output"]
}, Open  ]],
Cell[34371, 2488, 172, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[34566, 2494, 92, 2, 70, "Input"],
Cell[34661, 2498, 5151, 571, 70, 4993, 566, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[39824, 3071, 268, 5, 70, "Text"]
}, Open  ]],
Cell[40104, 3078, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[40177, 3081, 62, 1, 70, "Subsubsection"],
Cell[40242, 3084, 410, 7, 70, "Text"],
Cell[40655, 3093, 306, 9, 70, "Special3"],
Cell[40964, 3104, 144, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[41131, 3110, 117, 2, 70, "Input"],
Cell[41251, 3114, 594, 32, 70, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[41875, 3148, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[41948, 3151, 75, 1, 70, "Subsection"],
Cell[42026, 3154, 233, 5, 70, "Text"],
Cell[42262, 3161, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[42335, 3164, 73, 1, 70, "Subsubsection"],
Cell[42411, 3167, 184, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[42618, 3173, 101, 2, 70, "Input"],
Cell[42722, 3177, 803, 38, 70, "Output"]
}, Open  ]],
Cell[43537, 3217, 279, 5, 70, "Text"],

Cell[CellGroupData[{
Cell[43839, 3224, 112, 2, 70, "Input"],
Cell[43954, 3228, 4247, 387, 70, 4089, 382, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],
Cell[48222, 3617, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[48295, 3620, 72, 1, 70, "Subsubsection"],
Cell[48370, 3623, 181, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[48574, 3629, 100, 2, 70, "Input"],
Cell[48677, 3633, 836, 40, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[49545, 3675, 112, 2, 70, "Input"],
Cell[49660, 3679, 4229, 387, 70, 4071, 382, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],
Cell[53910, 4068, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[53983, 4071, 71, 1, 70, "Subsubsection"],
Cell[54057, 4074, 180, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[54260, 4080, 99, 2, 70, "Input"],
Cell[54362, 4084, 787, 38, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[55181, 4124, 112, 2, 70, "Input"],
Cell[55296, 4128, 4230, 387, 70, 4072, 382, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[59538, 4517, 182, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[59743, 4523, 110, 2, 70, "Input"],
Cell[59856, 4527, 4227, 387, 70, 4069, 382, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],
Cell[64104, 4916, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[64177, 4919, 74, 1, 70, "Subsubsection"],
Cell[64254, 4922, 233, 5, 70, "Text"],
Cell[64490, 4929, 403, 7, 70, "Text"],

Cell[CellGroupData[{
Cell[64916, 4938, 106, 2, 70, "Input"],
Cell[65025, 4942, 1011, 46, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[66068, 4990, 114, 2, 70, "Input"],
Cell[66185, 4994, 4250, 387, 70, 4092, 382, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[70465, 5383, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[70538, 5386, 76, 1, 70, "Subsection"],
Cell[70617, 5389, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[70690, 5392, 76, 1, 70, "Subsubsection"],
Cell[70769, 5395, 171, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[70963, 5401, 99, 2, 70, "Input"],
Cell[71065, 5405, 690, 34, 70, "Output"]
}, Open  ]],
Cell[71767, 5441, 196, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[71986, 5447, 114, 2, 70, "Input"],
Cell[72103, 5451, 4243, 387, 70, 4085, 382, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],
Cell[76367, 5840, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[76440, 5843, 77, 1, 70, "Subsubsection"],
Cell[76520, 5846, 180, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[76723, 5852, 105, 2, 70, "Input"],
Cell[76831, 5856, 772, 38, 70, "Output"]
}, Open  ]],
Cell[77615, 5896, 106, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[77744, 5899, 112, 2, 70, "Input"],
Cell[77859, 5903, 4249, 387, 70, 4091, 382, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],
Cell[82129, 6292, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[82202, 6295, 78, 1, 70, "Subsubsection"],
Cell[82283, 6298, 182, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[82488, 6304, 106, 2, 70, "Input"],
Cell[82597, 6308, 799, 36, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[83428, 6346, 112, 2, 70, "Input"],
Cell[83543, 6350, 4250, 387, 70, 4092, 382, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[87823, 6739, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[87896, 6742, 77, 1, 70, "Subsection"],
Cell[87976, 6745, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[88049, 6748, 81, 1, 70, "Subsubsection"],
Cell[88133, 6751, 226, 5, 70, "Text"],
Cell[88362, 6758, 253, 5, 70, "Text"],
Cell[88618, 6765, 99, 2, 70, "Input"],

Cell[CellGroupData[{
Cell[88740, 6769, 110, 2, 70, "Input"],
Cell[88853, 6773, 875, 38, 70, "Output"]
}, Open  ]],
Cell[89740, 6813, 161, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[89924, 6819, 112, 2, 70, "Input"],
Cell[90039, 6823, 4250, 387, 70, 4092, 382, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)
