(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     80397,       6581]*)
(*NotebookOutlinePosition[     81266,       6613]*)
(*  CellTagsIndexPosition[     81222,       6609]*)
(*WindowFrame->Normal*)



Notebook[{


Cell[CellGroupData[{Cell["\<\
Compositions
 
 
 
 \
\>", "Title",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Introduction", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
The Fuzzy Logic Pack provides a few different ways to perform compositions \
between two fuzzy relations. In this chapter, we introduce and demonstrate \
these functions and the options associated with them. \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
First we need to load the proper routines. This is done with the following \
command. \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Needs[\"FuzzyLogic`Master`\"]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
If the package loading command fails, verify that the directory containing \
the Fuzzy Logic directory is on Mathematica's $Path. You can use the command \
AppendTo[$Path, \"directory\"]. For convenience, this should be in your \
init.m file.\
\>", "SmallText",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
To demonstrate the various composition functions, we must first create some \
fuzzy relations. We use the FuzzyTrapezoid function here to create two fuzzy \
relations. We must be careful to create two fuzzy relations which can be \
combined by a composition operation. To take the composition of two fuzzy \
relations, the second range of the first fuzzy relation's universal space \
must be the same as the first range in the second fuzzy relation's universal \
space.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Rel1 = FuzzyTrapezoid[{0,2,5,8},{1,3,5,7},1,
       UniversalSpace->{{0,8},{1,7}}];\
\>", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Rel2 = FuzzyTrapezoid[{1,2,2,7},{2,4,6,8},0.9,
       UniversalSpace->{{1,7},{2,8}}];\
\>", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Note that in the fuzzy relations we created here, the second range of the \
universal space of Rel1, {1,7}, is the same as the first range of the \
universal space for Rel2. This is a necessary condition to perform a \
composition of two fuzzy relations.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
We can view the two fuzzy relations we created using one of the Fuzzy Logic \
Pack's plotting functions. Here we use the FuzzySurfacePlot function to look \
at the fuzzy relations.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzySurfacePlot[Rel1];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .70801 
MathPictureStart
%% Graphics3D
/Times-Bold findfont 10  scalefont  setfont
% Scaling calculations
0.0260223 1.04089 -0.0958739 1.04089 [
[(0)] .06597 .20303 -0.14121 1 Msboxa
[(1)] .14046 .18276 -0.12003 1 Msboxa
[(2)] .21815 .16161 -0.09768 1 Msboxa
[(3)] .29924 .13955 -0.07404 1 Msboxa
[(4)] .38398 .1165 -0.049 1 Msboxa
[(5)] .47259 .0924 -0.02244 1 Msboxa
[(6)] .56537 .06718 .00579 1 Msboxa
[(7)] .66261 .04076 .03584 1 Msboxa
[(8)] .76464 .01304 .06791 1 Msboxa
[(V )] .38716 .05152 -0.049 1 Msboxa
[(1)] .77808 .02262 -1 .27075 Msboxa
[(2)] .8189 .10134 -1 .24991 Msboxa
[(3)] .8545 .17002 -1 .23205 Msboxa
[(4)] .88584 .23047 -1 .21657 Msboxa
[(5)] .91362 .28407 -1 .20303 Msboxa
[(6)] .93843 .33194 -1 .19109 Msboxa
[(7)] .96071 .37494 -1 .18047 Msboxa
[( W)] .94942 .2167 -1 .21657 Msboxa
[(0)] .05159 .21932 1 -0.27075 Msboxa
[(0.25)] .04255 .28277 1 -0.25347 Msboxa
[(0.5)] .03317 .34863 1 -0.23545 Msboxa
[(0.75)] .02342 .41704 1 -0.21663 Msboxa
[(1)] .0133 .48815 1 -0.19696 Msboxa
[(Grade    )] -0.03018 .36368 1 -0.23542 Msboxa
[ 0 0 0 0 ]
[ 1 .70801 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.06415 .21592 m
.76552 .02602 L
s
P
p
.002 w
.06415 .21592 m
.06324 .22236 L
s
P
[(0)] .06597 .20303 -0.14121 1 Mshowa
p
.002 w
.13891 .19568 m
.13814 .20213 L
s
P
[(1)] .14046 .18276 -0.12003 1 Mshowa
p
.002 w
.21689 .17456 m
.21625 .18104 L
s
P
[(2)] .21815 .16161 -0.09768 1 Mshowa
p
.002 w
.29828 .15253 m
.2978 .15901 L
s
P
[(3)] .29924 .13955 -0.07404 1 Mshowa
p
.002 w
.38334 .1295 m
.38302 .136 L
s
P
[(4)] .38398 .1165 -0.049 1 Mshowa
p
.002 w
.4723 .10541 m
.47215 .11192 L
s
P
[(5)] .47259 .0924 -0.02244 1 Mshowa
p
.002 w
.56545 .08019 m
.56548 .0867 L
s
P
[(6)] .56537 .06718 .00579 1 Mshowa
p
.002 w
.66308 .05376 m
.66331 .06026 L
s
P
[(7)] .66261 .04076 .03584 1 Mshowa
p
.002 w
.76552 .02602 m
.76597 .03251 L
s
P
[(8)] .76464 .01304 .06791 1 Mshowa
[(V )] .38716 .05152 -0.049 1 Mshowa
P
p
p
.002 w
.76552 .02602 m
.94791 .37725 L
s
P
p
.002 w
.76552 .02602 m
.75925 .02772 L
s
P
[(1)] .77808 .02262 -1 .27075 Mshowa
p
.002 w
.80628 .1045 m
.79996 .10608 L
s
P
[(2)] .8189 .10134 -1 .24991 Mshowa
p
.002 w
.84183 .17296 m
.83549 .17444 L
s
P
[(3)] .8545 .17002 -1 .23205 Mshowa
p
.002 w
.87312 .23322 m
.86676 .2346 L
s
P
[(4)] .88584 .23047 -1 .21657 Mshowa
p
.002 w
.90087 .28666 m
.89449 .28796 L
s
P
[(5)] .91362 .28407 -1 .20303 Mshowa
p
.002 w
.92565 .33438 m
.91926 .3356 L
s
P
[(6)] .93843 .33194 -1 .19109 Mshowa
p
.002 w
.94791 .37725 m
.94151 .37841 L
s
P
[(7)] .96071 .37494 -1 .18047 Mshowa
[( W)] .94942 .2167 -1 .21657 Mshowa
P
p
p
.002 w
.06415 .21592 m
.02602 .48592 L
s
P
p
.002 w
.06415 .21592 m
.07043 .21422 L
s
P
[(0)] .05159 .21932 1 -0.27075 Mshowa
p
.002 w
.05516 .27958 m
.06147 .27798 L
s
P
[(0.25)] .04255 .28277 1 -0.25347 Mshowa
p
.002 w
.04583 .34565 m
.05216 .34416 L
s
P
[(0.5)] .03317 .34863 1 -0.23545 Mshowa
p
.002 w
.03614 .41429 m
.0425 .41291 L
s
P
[(0.75)] .02342 .41704 1 -0.21663 Mshowa
p
.002 w
.02606 .48563 m
.03245 .48437 L
s
P
[(1)] .0133 .48815 1 -0.19696 Mshowa
p
.001 w
.06238 .22846 m
.06615 .22745 L
s
P
p
.001 w
.06059 .2411 m
.06437 .2401 L
s
P
p
.001 w
.0588 .25383 m
.06257 .25285 L
s
P
p
.001 w
.05699 .26665 m
.06077 .26568 L
s
P
p
.001 w
.05332 .29259 m
.05711 .29165 L
s
P
p
.001 w
.05147 .30571 m
.05526 .30477 L
s
P
p
.001 w
.0496 .31892 m
.0534 .318 L
s
P
p
.001 w
.04772 .33224 m
.05152 .33133 L
s
P
p
.001 w
.04392 .35917 m
.04772 .35829 L
s
P
p
.001 w
.042 .37279 m
.0458 .37192 L
s
P
p
.001 w
.04006 .38652 m
.04387 .38566 L
s
P
p
.001 w
.03811 .40035 m
.04192 .39951 L
s
P
p
.001 w
.03415 .42833 m
.03797 .42752 L
s
P
p
.001 w
.03216 .44249 m
.03598 .44169 L
s
P
p
.001 w
.03014 .45676 m
.03396 .45597 L
s
P
p
.001 w
.02811 .47114 m
.03194 .47037 L
s
P
[(Grade    )] -0.03018 .36368 1 -0.23542 Mshowa
P
0 0 m
1 0 L
1 .70801 L
0 .70801 L
closepath
clip
newpath
p
.002 w
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.40498 .68199 L
s
.40498 .68199 m
.41257 .47386 L
s
.41257 .47386 m
.06415 .21592 L
s
.76552 .02602 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.76552 .02602 m
.06415 .21592 L
s
.41257 .47386 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.40498 .68199 L
s
.40498 .68199 m
.41257 .47386 L
s
p
.4 g
.06415 .21592 m
.41257 .47386 L
s
P
p
.4 g
.21689 .17456 m
.53392 .45196 L
s
P
p
.4 g
.38334 .1295 m
.66306 .42866 L
s
P
p
.4 g
.56545 .08019 m
.80076 .40381 L
s
P
p
.4 g
.76552 .02602 m
.94791 .37725 L
s
P
p
.4 g
.13893 .27128 m
.80628 .1045 L
s
P
p
.4 g
.26533 .36485 m
.87312 .23322 L
s
P
p
.4 g
.36808 .44092 m
.92565 .33438 L
s
P
P
p
.002 w
.42653 .5355 m .47231 .46308 L .41257 .47386 L p
.823 .354 0 r
F P
1 0 0 r
s
P
p
.002 w
.41257 .47386 m .36808 .44092 L .42653 .5355 L p
.823 .354 0 r
F P
1 0 0 r
s
P
p
.002 w
.49227 .52471 m .53392 .45196 L .47231 .46308 L p
.4 0 .133 r
F P
1 0 0 r
s
P
p
.002 w
.47231 .46308 m .42653 .5355 L .49227 .52471 L p
.4 0 .133 r
F P
1 0 0 r
s
P
p
.002 w
.56025 .51356 m .59747 .44049 L .53392 .45196 L p
.4 0 .133 r
F P
1 0 0 r
s
P
p
.002 w
.53392 .45196 m .49227 .52471 L .56025 .51356 L p
.4 0 .133 r
F P
1 0 0 r
s
P
p
.002 w
.37833 .50245 m .42653 .5355 L .36808 .44092 L p
.823 .354 0 r
F P
1 0 0 r
s
P
p
.002 w
.36808 .44092 m .31922 .40476 L .37833 .50245 L p
.823 .354 0 r
F P
1 0 0 r
s
P
p
.002 w
.63059 .50202 m .66306 .42866 L .59747 .44049 L p
.4 0 .133 r
F P
1 0 0 r
s
P
p
.002 w
.59747 .44049 m .56025 .51356 L .63059 .50202 L p
.4 0 .133 r
F P
1 0 0 r
s
P
p
.002 w
.70342 .49007 m .73079 .41643 L .66306 .42866 L p
.4 0 .133 r
F P
1 0 0 r
s
P
p
.002 w
.66306 .42866 m .63059 .50202 L .70342 .49007 L p
.4 0 .133 r
F P
1 0 0 r
s
P
p
.002 w
.77887 .47769 m .80076 .40381 L .73079 .41643 L p
.4 0 .133 r
F P
1 0 0 r
s
P
p
.002 w
.73079 .41643 m .70342 .49007 L .77887 .47769 L p
.4 0 .133 r
F P
1 0 0 r
s
P
p
.002 w
.44342 .61004 m .49227 .52471 L .42653 .5355 L p
.823 .354 0 r
F P
1 0 0 r
s
P
p
.002 w
.42653 .5355 m .37833 .50245 L .44342 .61004 L p
.823 .354 0 r
F P
1 0 0 r
s
P
p
.002 w
.3249 .46582 m .37833 .50245 L .31922 .40476 L p
.823 .354 0 r
F P
1 0 0 r
s
P
p
.002 w
.31922 .40476 m .26533 .36485 L .3249 .46582 L p
.823 .354 0 r
F P
1 0 0 r
s
P
p
.002 w
.87309 .39075 m .80076 .40381 L p
.83502 .41785 L .155 0 .058 r
F P
1 0 0 r
s
P
p
.002 w
.80076 .40381 m .77887 .47769 L .85375 .42553 L p
.155 0 .058 r
F P
1 0 0 r
s
P
p
.002 w
.7482 .47964 m .8248 .38281 L p
.79355 .44737 L .825 .986 .713 r
F P
1 0 0 r
s
P
p
.002 w
.77887 .47769 m .7482 .47964 L p
.79355 .44737 L .825 .986 .713 r
F P
1 0 0 r
s
P
p
.002 w
.85375 .42553 m .87309 .39075 L p
.83502 .41785 L .155 0 .058 r
F P
1 0 0 r
s
P
p
.002 w
.51648 .59949 m .56025 .51356 L .49227 .52471 L p
.4 0 .133 r
F P
1 0 0 r
s
P
p
.002 w
.49227 .52471 m .44342 .61004 L .51648 .59949 L p
.4 0 .133 r
F P
1 0 0 r
s
P
p
.002 w
.92565 .33438 m .94791 .37725 L .87309 .39075 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.87309 .39075 m .85375 .42553 L .92565 .33438 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.5923 .58854 m .63059 .50202 L .56025 .51356 L p
.4 0 .133 r
F P
1 0 0 r
s
P
p
.002 w
.56025 .51356 m .51648 .59949 L .5923 .58854 L p
.4 0 .133 r
F P
1 0 0 r
s
P
p
.002 w
.39085 .57759 m .44342 .61004 L .37833 .50245 L p
.823 .354 0 r
F P
1 0 0 r
s
P
p
.002 w
.37833 .50245 m .3249 .46582 L .39085 .57759 L p
.823 .354 0 r
F P
1 0 0 r
s
P
p
.002 w
.67105 .57716 m .70342 .49007 L .63059 .50202 L p
.4 0 .133 r
F P
1 0 0 r
s
P
p
.002 w
.63059 .50202 m .5923 .58854 L .67105 .57716 L p
.4 0 .133 r
F P
1 0 0 r
s
P
p
.002 w
.26534 .42499 m .3249 .46582 L .26533 .36485 L p
.823 .354 0 r
F P
1 0 0 r
s
P
p
.002 w
.26533 .36485 m .20556 .32061 L .26534 .42499 L p
.823 .354 0 r
F P
1 0 0 r
s
P
p
.002 w
.7482 .47964 m .77887 .47769 L .70342 .49007 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.70342 .49007 m .67105 .57716 L .7482 .47964 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.8248 .38281 m .85375 .42553 L .77887 .47769 L p
.825 .986 .713 r
F P
1 0 0 r
s
P
p
.002 w
.90087 .28666 m .92565 .33438 L .85375 .42553 L p
.905 .946 .82 r
F P
1 0 0 r
s
P
p
.002 w
.85375 .42553 m .8248 .38281 L .90087 .28666 L p
.905 .946 .82 r
F P
1 0 0 r
s
P
p
.002 w
.46713 .56579 m .51648 .59949 L .44342 .61004 L p
.467 .815 .998 r
F P
1 0 0 r
s
P
p
.002 w
.44342 .61004 m .39085 .57759 L .46713 .56579 L p
.467 .815 .998 r
F P
1 0 0 r
s
P
p
.002 w
.33191 .54121 m .39085 .57759 L .3249 .46582 L p
.823 .354 0 r
F P
1 0 0 r
s
P
p
.002 w
.3249 .46582 m .26534 .42499 L .33191 .54121 L p
.823 .354 0 r
F P
1 0 0 r
s
P
p
.002 w
.19854 .37919 m .26534 .42499 L .20556 .32061 L p
.823 .354 0 r
F P
1 0 0 r
s
P
p
.002 w
.20556 .32061 m .13893 .27128 L .19854 .37919 L p
.823 .354 0 r
F P
1 0 0 r
s
P
p
.002 w
.54647 .55351 m .5923 .58854 L .51648 .59949 L p
.467 .815 .998 r
F P
1 0 0 r
s
P
p
.002 w
.51648 .59949 m .46713 .56579 L .54647 .55351 L p
.467 .815 .998 r
F P
1 0 0 r
s
P
p
.002 w
.62905 .54073 m .67105 .57716 L .5923 .58854 L p
.467 .815 .998 r
F P
1 0 0 r
s
P
p
.002 w
.5923 .58854 m .54647 .55351 L .62905 .54073 L p
.467 .815 .998 r
F P
1 0 0 r
s
P
p
.002 w
.87312 .23322 m .90087 .28666 L .8248 .38281 L p
.905 .946 .82 r
F P
1 0 0 r
s
P
p
.002 w
.8248 .38281 m .79237 .33496 L .87312 .23322 L p
.905 .946 .82 r
F P
1 0 0 r
s
P
p
.002 w
.79237 .33496 m .8248 .38281 L .7482 .47964 L p
.905 .946 .82 r
F P
1 0 0 r
s
P
p
.002 w
.7482 .47964 m .71102 .43746 L .79237 .33496 L p
.905 .946 .82 r
F P
1 0 0 r
s
P
p
.002 w
.71102 .43746 m .7482 .47964 L .67105 .57716 L p
.905 .946 .82 r
F P
1 0 0 r
s
P
p
.002 w
.41168 .52792 m .46713 .56579 L .39085 .57759 L p
.467 .815 .998 r
F P
1 0 0 r
s
P
p
.002 w
.39085 .57759 m .33191 .54121 L .41168 .52792 L p
.467 .815 .998 r
F P
1 0 0 r
s
P
p
.002 w
.67105 .57716 m .62905 .54073 L .71102 .43746 L p
.905 .946 .82 r
F P
1 0 0 r
s
P
p
.002 w
.27583 .36245 m .33191 .54121 L .26534 .42499 L p
.523 .816 .999 r
F P
1 0 0 r
s
P
p
.002 w
.26534 .42499 m .19854 .37919 L .27583 .36245 L p
.523 .816 .999 r
F P
1 0 0 r
s
P
p
.002 w
.13891 .19568 m .19854 .37919 L .13893 .27128 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.13893 .27128 m .06415 .21592 L .13891 .19568 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.49484 .51406 m .54647 .55351 L .46713 .56579 L p
.467 .815 .998 r
F P
1 0 0 r
s
P
p
.002 w
.46713 .56579 m .41168 .52792 L .49484 .51406 L p
.467 .815 .998 r
F P
1 0 0 r
s
P
p
.002 w
.58163 .4996 m .62905 .54073 L .54647 .55351 L p
.467 .815 .998 r
F P
1 0 0 r
s
P
p
.002 w
.54647 .55351 m .49484 .51406 L .58163 .4996 L p
.467 .815 .998 r
F P
1 0 0 r
s
P
p
.002 w
.84183 .17296 m .87312 .23322 L .79237 .33496 L p
.905 .946 .82 r
F P
1 0 0 r
s
P
p
.002 w
.79237 .33496 m .75579 .28098 L .84183 .17296 L p
.905 .946 .82 r
F P
1 0 0 r
s
P
p
.002 w
.75579 .28098 m .79237 .33496 L .71102 .43746 L p
.905 .946 .82 r
F P
1 0 0 r
s
P
p
.002 w
.71102 .43746 m .66906 .38985 L .75579 .28098 L p
.905 .946 .82 r
F P
1 0 0 r
s
P
p
.002 w
.66906 .38985 m .71102 .43746 L .62905 .54073 L p
.905 .946 .82 r
F P
1 0 0 r
s
P
p
.002 w
.35642 .34499 m .41168 .52792 L .33191 .54121 L p
.577 .557 .795 r
F P
1 0 0 r
s
P
p
.002 w
.33191 .54121 m .27583 .36245 L .35642 .34499 L p
.577 .557 .795 r
F P
1 0 0 r
s
P
p
.002 w
.62905 .54073 m .58163 .4996 L .66906 .38985 L p
.905 .946 .82 r
F P
1 0 0 r
s
P
p
.002 w
.21689 .17456 m .27583 .36245 L .19854 .37919 L p
.577 .557 .795 r
F P
1 0 0 r
s
P
p
.002 w
.19854 .37919 m .13891 .19568 L .21689 .17456 L p
.577 .557 .795 r
F P
1 0 0 r
s
P
p
.002 w
.44054 .32677 m .49484 .51406 L .41168 .52792 L p
.577 .557 .795 r
F P
1 0 0 r
s
P
p
.002 w
.41168 .52792 m .35642 .34499 L .44054 .32677 L p
.577 .557 .795 r
F P
1 0 0 r
s
P
p
.002 w
.29828 .15253 m .35642 .34499 L .27583 .36245 L p
.577 .557 .795 r
F P
1 0 0 r
s
P
p
.002 w
.27583 .36245 m .21689 .17456 L .29828 .15253 L p
.577 .557 .795 r
F P
1 0 0 r
s
P
p
.002 w
.52842 .30774 m .58163 .4996 L .49484 .51406 L p
.577 .557 .795 r
F P
1 0 0 r
s
P
p
.002 w
.49484 .51406 m .44054 .32677 L .52842 .30774 L p
.577 .557 .795 r
F P
1 0 0 r
s
P
p
.002 w
.38334 .1295 m .44054 .32677 L .35642 .34499 L p
.577 .557 .795 r
F P
1 0 0 r
s
P
p
.002 w
.35642 .34499 m .29828 .15253 L .38334 .1295 L p
.577 .557 .795 r
F P
1 0 0 r
s
P
p
.002 w
.80628 .1045 m .84183 .17296 L .75579 .28098 L p
.905 .946 .82 r
F P
1 0 0 r
s
P
p
.002 w
.75579 .28098 m .7142 .21961 L .80628 .1045 L p
.905 .946 .82 r
F P
1 0 0 r
s
P
p
.002 w
.7142 .21961 m .75579 .28098 L .66906 .38985 L p
.77 .808 .884 r
F P
1 0 0 r
s
P
p
.002 w
.66906 .38985 m .62032 .28783 L .7142 .21961 L p
.77 .808 .884 r
F P
1 0 0 r
s
P
p
.002 w
.62032 .28783 m .66906 .38985 L .58163 .4996 L p
.577 .557 .795 r
F P
1 0 0 r
s
P
p
.002 w
.58163 .4996 m .52842 .30774 L .62032 .28783 L p
.577 .557 .795 r
F P
1 0 0 r
s
P
p
.002 w
.4723 .10541 m .52842 .30774 L .44054 .32677 L p
.577 .557 .795 r
F P
1 0 0 r
s
P
p
.002 w
.44054 .32677 m .38334 .1295 L .4723 .10541 L p
.577 .557 .795 r
F P
1 0 0 r
s
P
p
.002 w
.56545 .08019 m .62032 .28783 L .52842 .30774 L p
.577 .557 .795 r
F P
1 0 0 r
s
P
p
.002 w
.52842 .30774 m .4723 .10541 L .56545 .08019 L p
.577 .557 .795 r
F P
1 0 0 r
s
P
p
.002 w
.66308 .05376 m .7142 .21961 L .62032 .28783 L p
.577 .557 .795 r
F P
1 0 0 r
s
P
p
.002 w
.62032 .28783 m .56545 .08019 L .66308 .05376 L p
.577 .557 .795 r
F P
1 0 0 r
s
P
p
.002 w
.76552 .02602 m .80628 .1045 L .7142 .21961 L p
.587 .619 .852 r
F P
1 0 0 r
s
P
p
.002 w
.7142 .21961 m .66308 .05376 L .76552 .02602 L p
.587 .619 .852 r
F P
1 0 0 r
s
P
p
.002 w
.76552 .02602 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.76552 .02602 m
.06415 .21592 L
s
P
p
p
.002 w
.06415 .21592 m
.76552 .02602 L
s
P
p
.002 w
.06415 .21592 m
.06324 .22236 L
s
P
[(0)] .06597 .20303 -0.14121 1 Mshowa
p
.002 w
.13891 .19568 m
.13814 .20213 L
s
P
[(1)] .14046 .18276 -0.12003 1 Mshowa
p
.002 w
.21689 .17456 m
.21625 .18104 L
s
P
[(2)] .21815 .16161 -0.09768 1 Mshowa
p
.002 w
.29828 .15253 m
.2978 .15901 L
s
P
[(3)] .29924 .13955 -0.07404 1 Mshowa
p
.002 w
.38334 .1295 m
.38302 .136 L
s
P
[(4)] .38398 .1165 -0.049 1 Mshowa
p
.002 w
.4723 .10541 m
.47215 .11192 L
s
P
[(5)] .47259 .0924 -0.02244 1 Mshowa
p
.002 w
.56545 .08019 m
.56548 .0867 L
s
P
[(6)] .56537 .06718 .00579 1 Mshowa
p
.002 w
.66308 .05376 m
.66331 .06026 L
s
P
[(7)] .66261 .04076 .03584 1 Mshowa
p
.002 w
.76552 .02602 m
.76597 .03251 L
s
P
[(8)] .76464 .01304 .06791 1 Mshowa
[(V )] .38716 .05152 -0.049 1 Mshowa
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{398, 281},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]],

Cell[CellGroupData[{Cell["FuzzySurfacePlot[Rel2];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .70801 
MathPictureStart
%% Graphics3D
/Times-Bold findfont 10  scalefont  setfont
% Scaling calculations
0.0260223 1.04089 -0.0958739 1.04089 [
[(1)] .06597 .20303 -0.14121 1 Msboxa
[(2)] .16599 .17581 -0.11272 1 Msboxa
[(3)] .27182 .14701 -0.08207 1 Msboxa
[(4)] .38398 .1165 -0.049 1 Msboxa
[(5)] .50304 .08413 -0.01322 1 Msboxa
[(6)] .62968 .0497 .02561 1 Msboxa
[(7)] .76464 .01304 .06791 1 Msboxa
[(V )] .38716 .05152 -0.049 1 Msboxa
[(2)] .77808 .02262 -1 .27075 Msboxa
[(3)] .8189 .10134 -1 .24991 Msboxa
[(4)] .8545 .17002 -1 .23205 Msboxa
[(5)] .88584 .23047 -1 .21657 Msboxa
[(6)] .91362 .28407 -1 .20303 Msboxa
[(7)] .93843 .33194 -1 .19109 Msboxa
[(8)] .96071 .37494 -1 .18047 Msboxa
[( W)] .94942 .2167 -1 .21657 Msboxa
[(0)] .05159 .21932 1 -0.27075 Msboxa
[(0.25)] .04255 .28277 1 -0.25347 Msboxa
[(0.5)] .03317 .34863 1 -0.23545 Msboxa
[(0.75)] .02342 .41704 1 -0.21663 Msboxa
[(1)] .0133 .48815 1 -0.19696 Msboxa
[(Grade    )] -0.03018 .36368 1 -0.23542 Msboxa
[ 0 0 0 0 ]
[ 1 .70801 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.06415 .21592 m
.76552 .02602 L
s
P
p
.002 w
.06415 .21592 m
.06324 .22236 L
s
P
[(1)] .06597 .20303 -0.14121 1 Mshowa
p
.002 w
.16454 .18874 m
.16381 .1952 L
s
P
[(2)] .16599 .17581 -0.11272 1 Mshowa
p
.002 w
.27076 .15998 m
.27022 .16646 L
s
P
[(3)] .27182 .14701 -0.08207 1 Mshowa
p
.002 w
.38334 .1295 m
.38302 .136 L
s
P
[(4)] .38398 .1165 -0.049 1 Mshowa
p
.002 w
.50287 .09714 m
.50278 .10364 L
s
P
[(5)] .50304 .08413 -0.01322 1 Mshowa
p
.002 w
.63002 .06271 m
.63018 .06921 L
s
P
[(6)] .62968 .0497 .02561 1 Mshowa
p
.002 w
.76552 .02602 m
.76597 .03251 L
s
P
[(7)] .76464 .01304 .06791 1 Mshowa
[(V )] .38716 .05152 -0.049 1 Mshowa
P
p
p
.002 w
.76552 .02602 m
.94791 .37725 L
s
P
p
.002 w
.76552 .02602 m
.75925 .02772 L
s
P
[(2)] .77808 .02262 -1 .27075 Mshowa
p
.002 w
.80628 .1045 m
.79996 .10608 L
s
P
[(3)] .8189 .10134 -1 .24991 Mshowa
p
.002 w
.84183 .17296 m
.83549 .17444 L
s
P
[(4)] .8545 .17002 -1 .23205 Mshowa
p
.002 w
.87312 .23322 m
.86676 .2346 L
s
P
[(5)] .88584 .23047 -1 .21657 Mshowa
p
.002 w
.90087 .28666 m
.89449 .28796 L
s
P
[(6)] .91362 .28407 -1 .20303 Mshowa
p
.002 w
.92565 .33438 m
.91926 .3356 L
s
P
[(7)] .93843 .33194 -1 .19109 Mshowa
p
.002 w
.94791 .37725 m
.94151 .37841 L
s
P
[(8)] .96071 .37494 -1 .18047 Mshowa
[( W)] .94942 .2167 -1 .21657 Mshowa
P
p
p
.002 w
.06415 .21592 m
.02602 .48592 L
s
P
p
.002 w
.06415 .21592 m
.07043 .21422 L
s
P
[(0)] .05159 .21932 1 -0.27075 Mshowa
p
.002 w
.05516 .27958 m
.06147 .27798 L
s
P
[(0.25)] .04255 .28277 1 -0.25347 Mshowa
p
.002 w
.04583 .34565 m
.05216 .34416 L
s
P
[(0.5)] .03317 .34863 1 -0.23545 Mshowa
p
.002 w
.03614 .41429 m
.0425 .41291 L
s
P
[(0.75)] .02342 .41704 1 -0.21663 Mshowa
p
.002 w
.02606 .48563 m
.03245 .48437 L
s
P
[(1)] .0133 .48815 1 -0.19696 Mshowa
p
.001 w
.06238 .22846 m
.06615 .22745 L
s
P
p
.001 w
.06059 .2411 m
.06437 .2401 L
s
P
p
.001 w
.0588 .25383 m
.06257 .25285 L
s
P
p
.001 w
.05699 .26665 m
.06077 .26568 L
s
P
p
.001 w
.05332 .29259 m
.05711 .29165 L
s
P
p
.001 w
.05147 .30571 m
.05526 .30477 L
s
P
p
.001 w
.0496 .31892 m
.0534 .318 L
s
P
p
.001 w
.04772 .33224 m
.05152 .33133 L
s
P
p
.001 w
.04392 .35917 m
.04772 .35829 L
s
P
p
.001 w
.042 .37279 m
.0458 .37192 L
s
P
p
.001 w
.04006 .38652 m
.04387 .38566 L
s
P
p
.001 w
.03811 .40035 m
.04192 .39951 L
s
P
p
.001 w
.03415 .42833 m
.03797 .42752 L
s
P
p
.001 w
.03216 .44249 m
.03598 .44169 L
s
P
p
.001 w
.03014 .45676 m
.03396 .45597 L
s
P
p
.001 w
.02811 .47114 m
.03194 .47037 L
s
P
[(Grade    )] -0.03018 .36368 1 -0.23542 Mshowa
P
0 0 m
1 0 L
1 .70801 L
0 .70801 L
closepath
clip
newpath
p
.002 w
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.40498 .68199 L
s
.40498 .68199 m
.41257 .47386 L
s
.41257 .47386 m
.06415 .21592 L
s
.76552 .02602 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.76552 .02602 m
.06415 .21592 L
s
.41257 .47386 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.40498 .68199 L
s
.40498 .68199 m
.41257 .47386 L
s
p
.4 g
.16454 .18874 m
.49264 .45941 L
s
P
p
.4 g
.38334 .1295 m
.66306 .42866 L
s
P
p
.4 g
.63002 .06271 m
.84871 .39515 L
s
P
p
.4 g
.06415 .21592 m
.76552 .02602 L
s
P
p
.4 g
.20556 .32061 m
.84183 .17296 L
s
P
p
.4 g
.31922 .40476 m
.90087 .28666 L
s
P
p
.4 g
.41257 .47386 m
.94791 .37725 L
s
P
P
p
.002 w
.44849 .52097 m .49264 .45941 L .41257 .47386 L p
.609 .077 0 r
F P
1 0 0 r
s
P
p
.002 w
.41257 .47386 m .36808 .44092 L .44849 .52097 L p
.609 .077 0 r
F P
1 0 0 r
s
P
p
.002 w
.53736 .50615 m .57606 .44436 L .49264 .45941 L p
.365 0 .062 r
F P
1 0 0 r
s
P
p
.002 w
.49264 .45941 m .44849 .52097 L .53736 .50615 L p
.365 0 .062 r
F P
1 0 0 r
s
P
p
.002 w
.63033 .49063 m .66306 .42866 L .57606 .44436 L p
.365 0 .062 r
F P
1 0 0 r
s
P
p
.002 w
.57606 .44436 m .53736 .50615 L .63033 .49063 L p
.365 0 .062 r
F P
1 0 0 r
s
P
p
.002 w
.39714 .59259 m .44849 .52097 L .36808 .44092 L p
.902 .488 .129 r
F P
1 0 0 r
s
P
p
.002 w
.36808 .44092 m .31922 .40476 L .39714 .59259 L p
.902 .488 .129 r
F P
1 0 0 r
s
P
p
.002 w
.75386 .41227 m .66306 .42866 L p
.71297 .44829 L .242 0 .008 r
F P
1 0 0 r
s
P
p
.002 w
.66306 .42866 m .63033 .49063 L .72668 .45368 L p
.242 0 .008 r
F P
1 0 0 r
s
P
p
.002 w
.59093 .4749 m .69158 .41377 L p
.6419 .47612 L .713 .967 .937 r
F P
1 0 0 r
s
P
p
.002 w
.63033 .49063 m .61771 .48559 L p
.6419 .47612 L .713 .967 .937 r
F P
1 0 0 r
s
P
p
.002 w
.61771 .48559 m .59093 .4749 L p
.6419 .47612 L .713 .967 .937 r
F P
1 0 0 r
s
P
p
.002 w
.72668 .45368 m .73618 .43921 L p
.71297 .44829 L .242 0 .008 r
F P
1 0 0 r
s
P
p
.002 w
.73618 .43921 m .75386 .41227 L p
.71297 .44829 L .242 0 .008 r
F P
1 0 0 r
s
P
p
.002 w
.82493 .39477 m .84871 .39515 L .75386 .41227 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.75386 .41227 m .72668 .45368 L .82493 .39477 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.49281 .53448 m .53736 .50615 L .44849 .52097 L p
.051 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.44849 .52097 m .39714 .59259 L .49281 .53448 L p
.051 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.34299 .55979 m .39714 .59259 L .31922 .40476 L p
.902 .488 .129 r
F P
1 0 0 r
s
P
p
.002 w
.31922 .40476 m .26533 .36485 L .34299 .55979 L p
.902 .488 .129 r
F P
1 0 0 r
s
P
p
.002 w
.92565 .33438 m .94791 .37725 L .84871 .39515 L p
.548 .925 .799 r
F P
1 0 0 r
s
P
p
.002 w
.84871 .39515 m .82493 .39477 L .92565 .33438 L p
.548 .925 .799 r
F P
1 0 0 r
s
P
p
.002 w
.59093 .4749 m .63033 .49063 L .53736 .50615 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.53736 .50615 m .49281 .53448 L .59093 .4749 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.69158 .41377 m .72668 .45368 L .63033 .49063 L p
.713 .967 .937 r
F P
1 0 0 r
s
P
p
.002 w
.28241 .5231 m .34299 .55979 L .26533 .36485 L p
.902 .488 .129 r
F P
1 0 0 r
s
P
p
.002 w
.26533 .36485 m .20556 .32061 L .28241 .5231 L p
.902 .488 .129 r
F P
1 0 0 r
s
P
p
.002 w
.79485 .35105 m .82493 .39477 L .72668 .45368 L p
.755 .908 .944 r
F P
1 0 0 r
s
P
p
.002 w
.72668 .45368 m .69158 .41377 L .79485 .35105 L p
.755 .908 .944 r
F P
1 0 0 r
s
P
p
.002 w
.90087 .28666 m .92565 .33438 L .82493 .39477 L p
.755 .908 .944 r
F P
1 0 0 r
s
P
p
.002 w
.82493 .39477 m .79485 .35105 L .90087 .28666 L p
.755 .908 .944 r
F P
1 0 0 r
s
P
p
.002 w
.44338 .49795 m .49281 .53448 L .39714 .59259 L p
.755 .908 .944 r
F P
1 0 0 r
s
P
p
.002 w
.39714 .59259 m .34299 .55979 L .44338 .49795 L p
.755 .908 .944 r
F P
1 0 0 r
s
P
p
.002 w
.54647 .43445 m .59093 .4749 L .49281 .53448 L p
.755 .908 .944 r
F P
1 0 0 r
s
P
p
.002 w
.49281 .53448 m .44338 .49795 L .54647 .43445 L p
.755 .908 .944 r
F P
1 0 0 r
s
P
p
.002 w
.65238 .3692 m .69158 .41377 L .59093 .4749 L p
.755 .908 .944 r
F P
1 0 0 r
s
P
p
.002 w
.59093 .4749 m .54647 .43445 L .65238 .3692 L p
.755 .908 .944 r
F P
1 0 0 r
s
P
p
.002 w
.22513 .36062 m .28241 .5231 L .20556 .32061 L p
.609 .077 0 r
F P
1 0 0 r
s
P
p
.002 w
.20556 .32061 m .13893 .27128 L .22513 .36062 L p
.609 .077 0 r
F P
1 0 0 r
s
P
p
.002 w
.76122 .30215 m .79485 .35105 L .69158 .41377 L p
.755 .908 .944 r
F P
1 0 0 r
s
P
p
.002 w
.69158 .41377 m .65238 .3692 L .76122 .30215 L p
.755 .908 .944 r
F P
1 0 0 r
s
P
p
.002 w
.87312 .23322 m .90087 .28666 L .79485 .35105 L p
.755 .908 .944 r
F P
1 0 0 r
s
P
p
.002 w
.79485 .35105 m .76122 .30215 L .87312 .23322 L p
.755 .908 .944 r
F P
1 0 0 r
s
P
p
.002 w
.38799 .45702 m .44338 .49795 L .34299 .55979 L p
.755 .908 .944 r
F P
1 0 0 r
s
P
p
.002 w
.34299 .55979 m .28241 .5231 L .38799 .45702 L p
.755 .908 .944 r
F P
1 0 0 r
s
P
p
.002 w
.49658 .38906 m .54647 .43445 L .44338 .49795 L p
.755 .908 .944 r
F P
1 0 0 r
s
P
p
.002 w
.44338 .49795 m .38799 .45702 L .49658 .38906 L p
.755 .908 .944 r
F P
1 0 0 r
s
P
p
.002 w
.60833 .31911 m .65238 .3692 L .54647 .43445 L p
.755 .908 .944 r
F P
1 0 0 r
s
P
p
.002 w
.54647 .43445 m .49658 .38906 L .60833 .31911 L p
.755 .908 .944 r
F P
1 0 0 r
s
P
p
.002 w
.16454 .18874 m .22513 .36062 L .13893 .27128 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.13893 .27128 m .06415 .21592 L .16454 .18874 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.72336 .24711 m .76122 .30215 L .65238 .3692 L p
.755 .908 .944 r
F P
1 0 0 r
s
P
p
.002 w
.65238 .3692 m .60833 .31911 L .72336 .24711 L p
.755 .908 .944 r
F P
1 0 0 r
s
P
p
.002 w
.84183 .17296 m .87312 .23322 L .76122 .30215 L p
.755 .908 .944 r
F P
1 0 0 r
s
P
p
.002 w
.76122 .30215 m .72336 .24711 L .84183 .17296 L p
.755 .908 .944 r
F P
1 0 0 r
s
P
p
.002 w
.32999 .33754 m .38799 .45702 L .28241 .5231 L p
.58 .573 .81 r
F P
1 0 0 r
s
P
p
.002 w
.28241 .5231 m .22513 .36062 L .32999 .33754 L p
.58 .573 .81 r
F P
1 0 0 r
s
P
p
.002 w
.44095 .31313 m .49658 .38906 L .38799 .45702 L p
.585 .65 .881 r
F P
1 0 0 r
s
P
p
.002 w
.38799 .45702 m .32999 .33754 L .44095 .31313 L p
.585 .65 .881 r
F P
1 0 0 r
s
P
p
.002 w
.27076 .15998 m .32999 .33754 L .22513 .36062 L p
.58 .573 .81 r
F P
1 0 0 r
s
P
p
.002 w
.22513 .36062 m .16454 .18874 L .27076 .15998 L p
.58 .573 .81 r
F P
1 0 0 r
s
P
p
.002 w
.55846 .26241 m .60833 .31911 L .49658 .38906 L p
.674 .809 .948 r
F P
1 0 0 r
s
P
p
.002 w
.49658 .38906 m .44095 .31313 L .55846 .26241 L p
.674 .809 .948 r
F P
1 0 0 r
s
P
p
.002 w
.68042 .1847 m .72336 .24711 L .60833 .31911 L p
.755 .908 .944 r
F P
1 0 0 r
s
P
p
.002 w
.60833 .31911 m .55846 .26241 L .68042 .1847 L p
.755 .908 .944 r
F P
1 0 0 r
s
P
p
.002 w
.38334 .1295 m .44095 .31313 L .32999 .33754 L p
.58 .573 .81 r
F P
1 0 0 r
s
P
p
.002 w
.32999 .33754 m .27076 .15998 L .38334 .1295 L p
.58 .573 .81 r
F P
1 0 0 r
s
P
p
.002 w
.80628 .1045 m .84183 .17296 L .72336 .24711 L p
.755 .908 .944 r
F P
1 0 0 r
s
P
p
.002 w
.72336 .24711 m .68042 .1847 L .80628 .1045 L p
.755 .908 .944 r
F P
1 0 0 r
s
P
p
.002 w
.50287 .09714 m .55846 .26241 L .44095 .31313 L p
.58 .573 .81 r
F P
1 0 0 r
s
P
p
.002 w
.44095 .31313 m .38334 .1295 L .50287 .09714 L p
.58 .573 .81 r
F P
1 0 0 r
s
P
p
.002 w
.63002 .06271 m .68042 .1847 L .55846 .26241 L p
.585 .608 .842 r
F P
1 0 0 r
s
P
p
.002 w
.55846 .26241 m .50287 .09714 L .63002 .06271 L p
.585 .608 .842 r
F P
1 0 0 r
s
P
p
.002 w
.76552 .02602 m .80628 .1045 L .68042 .1847 L p
.59 .698 .917 r
F P
1 0 0 r
s
P
p
.002 w
.68042 .1847 m .63002 .06271 L .76552 .02602 L p
.59 .698 .917 r
F P
1 0 0 r
s
P
p
.002 w
.76552 .02602 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.76552 .02602 m
.06415 .21592 L
s
P
p
p
.002 w
.06415 .21592 m
.76552 .02602 L
s
P
p
.002 w
.06415 .21592 m
.06324 .22236 L
s
P
[(1)] .06597 .20303 -0.14121 1 Mshowa
p
.002 w
.16454 .18874 m
.16381 .1952 L
s
P
[(2)] .16599 .17581 -0.11272 1 Mshowa
p
.002 w
.27076 .15998 m
.27022 .16646 L
s
P
[(3)] .27182 .14701 -0.08207 1 Mshowa
p
.002 w
.38334 .1295 m
.38302 .136 L
s
P
[(4)] .38398 .1165 -0.049 1 Mshowa
p
.002 w
.50287 .09714 m
.50278 .10364 L
s
P
[(5)] .50304 .08413 -0.01322 1 Mshowa
p
.002 w
.63002 .06271 m
.63018 .06921 L
s
P
[(6)] .62968 .0497 .02561 1 Mshowa
p
.002 w
.76552 .02602 m
.76597 .03251 L
s
P
[(7)] .76464 .01304 .06791 1 Mshowa
[(V )] .38716 .05152 -0.049 1 Mshowa
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{398, 281},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Compositions", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Composition[A,B,opts] returns a fuzzy relation which is the result of \
performing a composition between fuzzy relations A and B. There is a Type \
option with this funtion which defaults to a MaxMin composition. Other types \
available are MaxProduct and MaxStar[func], which allows you to define your \
own function for combining the relations.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["MaxMin", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
The MaxMin composition performs an operation similar to matrix \
multiplication. The membership grades of the new fuzzy relation created by \
this operation are found by combining the membership grades from each row of \
the first fuzzy relation with the membership grades of each column of the \
second fuzzy relation. In the MaxMin composition, the membership grades are \
combined by finding the maximum of the minimums of the corresponding \
membership grades in the rows of the first fuzzy relation and the columns of \
the second fuzzy relation. Let us see how this function performs.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Comp1 = Composition[Rel1,Rel2];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzySurfacePlot[Comp1];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .70801 
MathPictureStart
%% Graphics3D
/Times-Bold findfont 10  scalefont  setfont
% Scaling calculations
0.0260223 1.04089 -0.0958739 1.04089 [
[(0)] .06597 .20303 -0.14121 1 Msboxa
[(1)] .14046 .18276 -0.12003 1 Msboxa
[(2)] .21815 .16161 -0.09768 1 Msboxa
[(3)] .29924 .13955 -0.07404 1 Msboxa
[(4)] .38398 .1165 -0.049 1 Msboxa
[(5)] .47259 .0924 -0.02244 1 Msboxa
[(6)] .56537 .06718 .00579 1 Msboxa
[(7)] .66261 .04076 .03584 1 Msboxa
[(8)] .76464 .01304 .06791 1 Msboxa
[(V )] .38716 .05152 -0.049 1 Msboxa
[(2)] .77808 .02262 -1 .27075 Msboxa
[(3)] .8189 .10134 -1 .24991 Msboxa
[(4)] .8545 .17002 -1 .23205 Msboxa
[(5)] .88584 .23047 -1 .21657 Msboxa
[(6)] .91362 .28407 -1 .20303 Msboxa
[(7)] .93843 .33194 -1 .19109 Msboxa
[(8)] .96071 .37494 -1 .18047 Msboxa
[( W)] .94942 .2167 -1 .21657 Msboxa
[(0)] .05159 .21932 1 -0.27075 Msboxa
[(0.25)] .04255 .28277 1 -0.25347 Msboxa
[(0.5)] .03317 .34863 1 -0.23545 Msboxa
[(0.75)] .02342 .41704 1 -0.21663 Msboxa
[(1)] .0133 .48815 1 -0.19696 Msboxa
[(Grade    )] -0.03018 .36368 1 -0.23542 Msboxa
[ 0 0 0 0 ]
[ 1 .70801 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.06415 .21592 m
.76552 .02602 L
s
P
p
.002 w
.06415 .21592 m
.06324 .22236 L
s
P
[(0)] .06597 .20303 -0.14121 1 Mshowa
p
.002 w
.13891 .19568 m
.13814 .20213 L
s
P
[(1)] .14046 .18276 -0.12003 1 Mshowa
p
.002 w
.21689 .17456 m
.21625 .18104 L
s
P
[(2)] .21815 .16161 -0.09768 1 Mshowa
p
.002 w
.29828 .15253 m
.2978 .15901 L
s
P
[(3)] .29924 .13955 -0.07404 1 Mshowa
p
.002 w
.38334 .1295 m
.38302 .136 L
s
P
[(4)] .38398 .1165 -0.049 1 Mshowa
p
.002 w
.4723 .10541 m
.47215 .11192 L
s
P
[(5)] .47259 .0924 -0.02244 1 Mshowa
p
.002 w
.56545 .08019 m
.56548 .0867 L
s
P
[(6)] .56537 .06718 .00579 1 Mshowa
p
.002 w
.66308 .05376 m
.66331 .06026 L
s
P
[(7)] .66261 .04076 .03584 1 Mshowa
p
.002 w
.76552 .02602 m
.76597 .03251 L
s
P
[(8)] .76464 .01304 .06791 1 Mshowa
[(V )] .38716 .05152 -0.049 1 Mshowa
P
p
p
.002 w
.76552 .02602 m
.94791 .37725 L
s
P
p
.002 w
.76552 .02602 m
.75925 .02772 L
s
P
[(2)] .77808 .02262 -1 .27075 Mshowa
p
.002 w
.80628 .1045 m
.79996 .10608 L
s
P
[(3)] .8189 .10134 -1 .24991 Mshowa
p
.002 w
.84183 .17296 m
.83549 .17444 L
s
P
[(4)] .8545 .17002 -1 .23205 Mshowa
p
.002 w
.87312 .23322 m
.86676 .2346 L
s
P
[(5)] .88584 .23047 -1 .21657 Mshowa
p
.002 w
.90087 .28666 m
.89449 .28796 L
s
P
[(6)] .91362 .28407 -1 .20303 Mshowa
p
.002 w
.92565 .33438 m
.91926 .3356 L
s
P
[(7)] .93843 .33194 -1 .19109 Mshowa
p
.002 w
.94791 .37725 m
.94151 .37841 L
s
P
[(8)] .96071 .37494 -1 .18047 Mshowa
[( W)] .94942 .2167 -1 .21657 Mshowa
P
p
p
.002 w
.06415 .21592 m
.02602 .48592 L
s
P
p
.002 w
.06415 .21592 m
.07043 .21422 L
s
P
[(0)] .05159 .21932 1 -0.27075 Mshowa
p
.002 w
.05516 .27958 m
.06147 .27798 L
s
P
[(0.25)] .04255 .28277 1 -0.25347 Mshowa
p
.002 w
.04583 .34565 m
.05216 .34416 L
s
P
[(0.5)] .03317 .34863 1 -0.23545 Mshowa
p
.002 w
.03614 .41429 m
.0425 .41291 L
s
P
[(0.75)] .02342 .41704 1 -0.21663 Mshowa
p
.002 w
.02606 .48563 m
.03245 .48437 L
s
P
[(1)] .0133 .48815 1 -0.19696 Mshowa
p
.001 w
.06238 .22846 m
.06615 .22745 L
s
P
p
.001 w
.06059 .2411 m
.06437 .2401 L
s
P
p
.001 w
.0588 .25383 m
.06257 .25285 L
s
P
p
.001 w
.05699 .26665 m
.06077 .26568 L
s
P
p
.001 w
.05332 .29259 m
.05711 .29165 L
s
P
p
.001 w
.05147 .30571 m
.05526 .30477 L
s
P
p
.001 w
.0496 .31892 m
.0534 .318 L
s
P
p
.001 w
.04772 .33224 m
.05152 .33133 L
s
P
p
.001 w
.04392 .35917 m
.04772 .35829 L
s
P
p
.001 w
.042 .37279 m
.0458 .37192 L
s
P
p
.001 w
.04006 .38652 m
.04387 .38566 L
s
P
p
.001 w
.03811 .40035 m
.04192 .39951 L
s
P
p
.001 w
.03415 .42833 m
.03797 .42752 L
s
P
p
.001 w
.03216 .44249 m
.03598 .44169 L
s
P
p
.001 w
.03014 .45676 m
.03396 .45597 L
s
P
p
.001 w
.02811 .47114 m
.03194 .47037 L
s
P
[(Grade    )] -0.03018 .36368 1 -0.23542 Mshowa
P
0 0 m
1 0 L
1 .70801 L
0 .70801 L
closepath
clip
newpath
p
.002 w
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.40498 .68199 L
s
.40498 .68199 m
.41257 .47386 L
s
.41257 .47386 m
.06415 .21592 L
s
.76552 .02602 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.76552 .02602 m
.06415 .21592 L
s
.41257 .47386 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.40498 .68199 L
s
.40498 .68199 m
.41257 .47386 L
s
p
.4 g
.06415 .21592 m
.41257 .47386 L
s
P
p
.4 g
.21689 .17456 m
.53392 .45196 L
s
P
p
.4 g
.38334 .1295 m
.66306 .42866 L
s
P
p
.4 g
.56545 .08019 m
.80076 .40381 L
s
P
p
.4 g
.76552 .02602 m
.94791 .37725 L
s
P
p
.4 g
.06415 .21592 m
.76552 .02602 L
s
P
p
.4 g
.20556 .32061 m
.84183 .17296 L
s
P
p
.4 g
.31922 .40476 m
.90087 .28666 L
s
P
p
.4 g
.41257 .47386 m
.94791 .37725 L
s
P
P
p
.002 w
.42688 .52458 m .47231 .46308 L .41257 .47386 L p
.78 .291 0 r
F P
1 0 0 r
s
P
p
.002 w
.41257 .47386 m .36808 .44092 L .42688 .52458 L p
.78 .291 0 r
F P
1 0 0 r
s
P
p
.002 w
.49243 .51364 m .53392 .45196 L .47231 .46308 L p
.365 0 .062 r
F P
1 0 0 r
s
P
p
.002 w
.47231 .46308 m .42688 .52458 L .49243 .51364 L p
.365 0 .062 r
F P
1 0 0 r
s
P
p
.002 w
.56021 .50233 m .59747 .44049 L .53392 .45196 L p
.365 0 .062 r
F P
1 0 0 r
s
P
p
.002 w
.53392 .45196 m .49243 .51364 L .56021 .50233 L p
.365 0 .062 r
F P
1 0 0 r
s
P
p
.002 w
.37833 .50245 m .42688 .52458 L .36808 .44092 L p
.823 .354 0 r
F P
1 0 0 r
s
P
p
.002 w
.36808 .44092 m .31922 .40476 L .37833 .50245 L p
.823 .354 0 r
F P
1 0 0 r
s
P
p
.002 w
.63033 .49063 m .66306 .42866 L .59747 .44049 L p
.365 0 .062 r
F P
1 0 0 r
s
P
p
.002 w
.59747 .44049 m .56021 .50233 L .63033 .49063 L p
.365 0 .062 r
F P
1 0 0 r
s
P
p
.002 w
.70293 .47852 m .73079 .41643 L .66306 .42866 L p
.365 0 .062 r
F P
1 0 0 r
s
P
p
.002 w
.66306 .42866 m .63033 .49063 L .70293 .47852 L p
.365 0 .062 r
F P
1 0 0 r
s
P
p
.002 w
.77813 .46597 m .80076 .40381 L .73079 .41643 L p
.365 0 .062 r
F P
1 0 0 r
s
P
p
.002 w
.73079 .41643 m .70293 .47852 L .77813 .46597 L p
.365 0 .062 r
F P
1 0 0 r
s
P
p
.002 w
.44526 .54217 m .49243 .51364 L .42688 .52458 L p
.428 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.42688 .52458 m .37833 .50245 L .44526 .54217 L p
.428 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.3249 .46582 m .37833 .50245 L .31922 .40476 L p
.823 .354 0 r
F P
1 0 0 r
s
P
p
.002 w
.31922 .40476 m .26533 .36485 L .3249 .46582 L p
.823 .354 0 r
F P
1 0 0 r
s
P
p
.002 w
.85114 .39471 m .80076 .40381 L p
.82706 .41458 L .172 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.80076 .40381 m .77813 .46597 L .85375 .42553 L p
.172 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.7482 .47964 m .77813 .46597 L .70293 .47852 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.7482 .47964 m .8248 .38281 L p
.78965 .44545 L .752 .951 .636 r
F P
1 0 0 r
s
P
p
.002 w
.77813 .46597 m .7482 .47964 L p
.78965 .44545 L .752 .951 .636 r
F P
1 0 0 r
s
P
p
.002 w
.85375 .42553 m .87309 .39075 L .85114 .39471 L p
.172 0 0 r
F P
1 0 0 r
s
P
p
.82706 .41458 m .85375 .42553 L .85114 .39471 L .172 0 0 r
F
P
p
.002 w
.51702 .53057 m .56021 .50233 L .49243 .51364 L p
.124 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.49243 .51364 m .44526 .54217 L .51702 .53057 L p
.124 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.92565 .33438 m .94791 .37725 L .87309 .39075 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.87309 .39075 m .85375 .42553 L .92565 .33438 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.59146 .51854 m .63033 .49063 L .56021 .50233 L p
.124 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.56021 .50233 m .51702 .53057 L .59146 .51854 L p
.124 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.66871 .50606 m .70293 .47852 L .63033 .49063 L p
.124 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.63033 .49063 m .59146 .51854 L .66871 .50606 L p
.124 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.39378 .50653 m .44526 .54217 L .37833 .50245 L p
0 .233 .658 r
F P
1 0 0 r
s
P
p
.002 w
.37833 .50245 m .3249 .46582 L .39378 .50653 L p
0 .233 .658 r
F P
1 0 0 r
s
P
p
.002 w
.26534 .42499 m .3249 .46582 L .26533 .36485 L p
.823 .354 0 r
F P
1 0 0 r
s
P
p
.002 w
.26533 .36485 m .20556 .32061 L .26534 .42499 L p
.823 .354 0 r
F P
1 0 0 r
s
P
p
.002 w
.70293 .47852 m .66871 .50606 L .7482 .47964 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.46865 .49358 m .51702 .53057 L .44526 .54217 L p
.501 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.44526 .54217 m .39378 .50653 L .46865 .49358 L p
.501 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.8248 .38281 m .85375 .42553 L .77813 .46597 L p
.752 .951 .636 r
F P
1 0 0 r
s
P
p
.002 w
.90087 .28666 m .92565 .33438 L .85375 .42553 L p
.905 .946 .82 r
F P
1 0 0 r
s
P
p
.002 w
.85375 .42553 m .8248 .38281 L .90087 .28666 L p
.905 .946 .82 r
F P
1 0 0 r
s
P
p
.002 w
.54647 .48012 m .59146 .51854 L .51702 .53057 L p
.501 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.51702 .53057 m .46865 .49358 L .54647 .48012 L p
.501 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.33619 .46666 m .39378 .50653 L .3249 .46582 L p
0 .233 .658 r
F P
1 0 0 r
s
P
p
.002 w
.3249 .46582 m .26534 .42499 L .33619 .46666 L p
0 .233 .658 r
F P
1 0 0 r
s
P
p
.002 w
.19981 .36619 m .26534 .42499 L .20556 .32061 L p
.78 .291 0 r
F P
1 0 0 r
s
P
p
.002 w
.20556 .32061 m .13893 .27128 L .19981 .36619 L p
.78 .291 0 r
F P
1 0 0 r
s
P
p
.002 w
.62741 .46613 m .66871 .50606 L .59146 .51854 L p
.501 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.59146 .51854 m .54647 .48012 L .62741 .46613 L p
.501 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.41442 .45211 m .46865 .49358 L .39378 .50653 L p
.501 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.39378 .50653 m .33619 .46666 L .41442 .45211 L p
.501 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.71102 .43746 m .7482 .47964 L .66871 .50606 L p
.617 .874 .99 r
F P
1 0 0 r
s
P
p
.002 w
.66871 .50606 m .62741 .46613 L .71102 .43746 L p
.617 .874 .99 r
F P
1 0 0 r
s
P
p
.002 w
.87312 .23322 m .90087 .28666 L .8248 .38281 L p
.905 .946 .82 r
F P
1 0 0 r
s
P
p
.002 w
.8248 .38281 m .79237 .33496 L .87312 .23322 L p
.905 .946 .82 r
F P
1 0 0 r
s
P
p
.002 w
.79237 .33496 m .8248 .38281 L .7482 .47964 L p
.905 .946 .82 r
F P
1 0 0 r
s
P
p
.002 w
.7482 .47964 m .71102 .43746 L .79237 .33496 L p
.905 .946 .82 r
F P
1 0 0 r
s
P
p
.002 w
.49592 .43695 m .54647 .48012 L .46865 .49358 L p
.501 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.46865 .49358 m .41442 .45211 L .49592 .43695 L p
.501 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.27683 .34924 m .33619 .46666 L .26534 .42499 L p
.553 .785 .985 r
F P
1 0 0 r
s
P
p
.002 w
.26534 .42499 m .19981 .36619 L .27683 .34924 L p
.553 .785 .985 r
F P
1 0 0 r
s
P
p
.002 w
.13891 .19568 m .19981 .36619 L .13893 .27128 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.13893 .27128 m .06415 .21592 L .13891 .19568 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.58089 .42115 m .62741 .46613 L .54647 .48012 L p
.501 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.54647 .48012 m .49592 .43695 L .58089 .42115 L p
.501 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.35714 .33157 m .41442 .45211 L .33619 .46666 L p
.585 .65 .881 r
F P
1 0 0 r
s
P
p
.002 w
.33619 .46666 m .27683 .34924 L .35714 .33157 L p
.585 .65 .881 r
F P
1 0 0 r
s
P
p
.002 w
.66906 .38985 m .71102 .43746 L .62741 .46613 L p
.617 .874 .99 r
F P
1 0 0 r
s
P
p
.002 w
.62741 .46613 m .58089 .42115 L .66906 .38985 L p
.617 .874 .99 r
F P
1 0 0 r
s
P
p
.002 w
.84183 .17296 m .87312 .23322 L .79237 .33496 L p
.905 .946 .82 r
F P
1 0 0 r
s
P
p
.002 w
.79237 .33496 m .75579 .28098 L .84183 .17296 L p
.905 .946 .82 r
F P
1 0 0 r
s
P
p
.002 w
.75579 .28098 m .79237 .33496 L .71102 .43746 L p
.905 .946 .82 r
F P
1 0 0 r
s
P
p
.002 w
.71102 .43746 m .66906 .38985 L .75579 .28098 L p
.905 .946 .82 r
F P
1 0 0 r
s
P
p
.002 w
.44095 .31313 m .49592 .43695 L .41442 .45211 L p
.585 .65 .881 r
F P
1 0 0 r
s
P
p
.002 w
.41442 .45211 m .35714 .33157 L .44095 .31313 L p
.585 .65 .881 r
F P
1 0 0 r
s
P
p
.002 w
.21689 .17456 m .27683 .34924 L .19981 .36619 L p
.58 .573 .81 r
F P
1 0 0 r
s
P
p
.002 w
.19981 .36619 m .13891 .19568 L .21689 .17456 L p
.58 .573 .81 r
F P
1 0 0 r
s
P
p
.002 w
.52849 .29386 m .58089 .42115 L .49592 .43695 L p
.585 .65 .881 r
F P
1 0 0 r
s
P
p
.002 w
.49592 .43695 m .44095 .31313 L .52849 .29386 L p
.585 .65 .881 r
F P
1 0 0 r
s
P
p
.002 w
.29828 .15253 m .35714 .33157 L .27683 .34924 L p
.58 .573 .81 r
F P
1 0 0 r
s
P
p
.002 w
.27683 .34924 m .21689 .17456 L .29828 .15253 L p
.58 .573 .81 r
F P
1 0 0 r
s
P
p
.002 w
.62002 .27372 m .66906 .38985 L .58089 .42115 L p
.585 .65 .881 r
F P
1 0 0 r
s
P
p
.002 w
.58089 .42115 m .52849 .29386 L .62002 .27372 L p
.585 .65 .881 r
F P
1 0 0 r
s
P
p
.002 w
.38334 .1295 m .44095 .31313 L .35714 .33157 L p
.58 .573 .81 r
F P
1 0 0 r
s
P
p
.002 w
.35714 .33157 m .29828 .15253 L .38334 .1295 L p
.58 .573 .81 r
F P
1 0 0 r
s
P
p
.002 w
.80628 .1045 m .84183 .17296 L .75579 .28098 L p
.905 .946 .82 r
F P
1 0 0 r
s
P
p
.002 w
.75579 .28098 m .7142 .21961 L .80628 .1045 L p
.905 .946 .82 r
F P
1 0 0 r
s
P
p
.002 w
.7142 .21961 m .75579 .28098 L .66906 .38985 L p
.715 .752 .881 r
F P
1 0 0 r
s
P
p
.002 w
.66906 .38985 m .62002 .27372 L .7142 .21961 L p
.715 .752 .881 r
F P
1 0 0 r
s
P
p
.002 w
.4723 .10541 m .52849 .29386 L .44095 .31313 L p
.58 .573 .81 r
F P
1 0 0 r
s
P
p
.002 w
.44095 .31313 m .38334 .1295 L .4723 .10541 L p
.58 .573 .81 r
F P
1 0 0 r
s
P
p
.002 w
.56545 .08019 m .62002 .27372 L .52849 .29386 L p
.58 .573 .81 r
F P
1 0 0 r
s
P
p
.002 w
.52849 .29386 m .4723 .10541 L .56545 .08019 L p
.58 .573 .81 r
F P
1 0 0 r
s
P
p
.002 w
.66308 .05376 m .7142 .21961 L .62002 .27372 L p
.58 .573 .81 r
F P
1 0 0 r
s
P
p
.002 w
.62002 .27372 m .56545 .08019 L .66308 .05376 L p
.58 .573 .81 r
F P
1 0 0 r
s
P
p
.002 w
.76552 .02602 m .80628 .1045 L .7142 .21961 L p
.587 .619 .852 r
F P
1 0 0 r
s
P
p
.002 w
.7142 .21961 m .66308 .05376 L .76552 .02602 L p
.587 .619 .852 r
F P
1 0 0 r
s
P
p
.002 w
.76552 .02602 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.76552 .02602 m
.06415 .21592 L
s
P
p
p
.002 w
.06415 .21592 m
.76552 .02602 L
s
P
p
.002 w
.06415 .21592 m
.06324 .22236 L
s
P
[(0)] .06597 .20303 -0.14121 1 Mshowa
p
.002 w
.13891 .19568 m
.13814 .20213 L
s
P
[(1)] .14046 .18276 -0.12003 1 Mshowa
p
.002 w
.21689 .17456 m
.21625 .18104 L
s
P
[(2)] .21815 .16161 -0.09768 1 Mshowa
p
.002 w
.29828 .15253 m
.2978 .15901 L
s
P
[(3)] .29924 .13955 -0.07404 1 Mshowa
p
.002 w
.38334 .1295 m
.38302 .136 L
s
P
[(4)] .38398 .1165 -0.049 1 Mshowa
p
.002 w
.4723 .10541 m
.47215 .11192 L
s
P
[(5)] .47259 .0924 -0.02244 1 Mshowa
p
.002 w
.56545 .08019 m
.56548 .0867 L
s
P
[(6)] .56537 .06718 .00579 1 Mshowa
p
.002 w
.66308 .05376 m
.66331 .06026 L
s
P
[(7)] .66261 .04076 .03584 1 Mshowa
p
.002 w
.76552 .02602 m
.76597 .03251 L
s
P
[(8)] .76464 .01304 .06791 1 Mshowa
[(V )] .38716 .05152 -0.049 1 Mshowa
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{398, 281},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["MaxProduct", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
In the MaxProduct composition, the membership grades are found by taking the \
maximum of the products of corresponding membership grades in the rows of the \
first fuzzy relation and the columns of the second fuzzy relation. Let us see \
how this function behaves.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Comp2 = Composition[Rel1,Rel2,Type->MaxProduct];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzySurfacePlot[Comp2];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .70801 
MathPictureStart
%% Graphics3D
/Times-Bold findfont 10  scalefont  setfont
% Scaling calculations
0.0260223 1.04089 -0.0958739 1.04089 [
[(0)] .06597 .20303 -0.14121 1 Msboxa
[(1)] .14046 .18276 -0.12003 1 Msboxa
[(2)] .21815 .16161 -0.09768 1 Msboxa
[(3)] .29924 .13955 -0.07404 1 Msboxa
[(4)] .38398 .1165 -0.049 1 Msboxa
[(5)] .47259 .0924 -0.02244 1 Msboxa
[(6)] .56537 .06718 .00579 1 Msboxa
[(7)] .66261 .04076 .03584 1 Msboxa
[(8)] .76464 .01304 .06791 1 Msboxa
[(V )] .38716 .05152 -0.049 1 Msboxa
[(2)] .77808 .02262 -1 .27075 Msboxa
[(3)] .8189 .10134 -1 .24991 Msboxa
[(4)] .8545 .17002 -1 .23205 Msboxa
[(5)] .88584 .23047 -1 .21657 Msboxa
[(6)] .91362 .28407 -1 .20303 Msboxa
[(7)] .93843 .33194 -1 .19109 Msboxa
[(8)] .96071 .37494 -1 .18047 Msboxa
[( W)] .94942 .2167 -1 .21657 Msboxa
[(0)] .05159 .21932 1 -0.27075 Msboxa
[(0.25)] .04255 .28277 1 -0.25347 Msboxa
[(0.5)] .03317 .34863 1 -0.23545 Msboxa
[(0.75)] .02342 .41704 1 -0.21663 Msboxa
[(1)] .0133 .48815 1 -0.19696 Msboxa
[(Grade    )] -0.03018 .36368 1 -0.23542 Msboxa
[ 0 0 0 0 ]
[ 1 .70801 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.06415 .21592 m
.76552 .02602 L
s
P
p
.002 w
.06415 .21592 m
.06324 .22236 L
s
P
[(0)] .06597 .20303 -0.14121 1 Mshowa
p
.002 w
.13891 .19568 m
.13814 .20213 L
s
P
[(1)] .14046 .18276 -0.12003 1 Mshowa
p
.002 w
.21689 .17456 m
.21625 .18104 L
s
P
[(2)] .21815 .16161 -0.09768 1 Mshowa
p
.002 w
.29828 .15253 m
.2978 .15901 L
s
P
[(3)] .29924 .13955 -0.07404 1 Mshowa
p
.002 w
.38334 .1295 m
.38302 .136 L
s
P
[(4)] .38398 .1165 -0.049 1 Mshowa
p
.002 w
.4723 .10541 m
.47215 .11192 L
s
P
[(5)] .47259 .0924 -0.02244 1 Mshowa
p
.002 w
.56545 .08019 m
.56548 .0867 L
s
P
[(6)] .56537 .06718 .00579 1 Mshowa
p
.002 w
.66308 .05376 m
.66331 .06026 L
s
P
[(7)] .66261 .04076 .03584 1 Mshowa
p
.002 w
.76552 .02602 m
.76597 .03251 L
s
P
[(8)] .76464 .01304 .06791 1 Mshowa
[(V )] .38716 .05152 -0.049 1 Mshowa
P
p
p
.002 w
.76552 .02602 m
.94791 .37725 L
s
P
p
.002 w
.76552 .02602 m
.75925 .02772 L
s
P
[(2)] .77808 .02262 -1 .27075 Mshowa
p
.002 w
.80628 .1045 m
.79996 .10608 L
s
P
[(3)] .8189 .10134 -1 .24991 Mshowa
p
.002 w
.84183 .17296 m
.83549 .17444 L
s
P
[(4)] .8545 .17002 -1 .23205 Mshowa
p
.002 w
.87312 .23322 m
.86676 .2346 L
s
P
[(5)] .88584 .23047 -1 .21657 Mshowa
p
.002 w
.90087 .28666 m
.89449 .28796 L
s
P
[(6)] .91362 .28407 -1 .20303 Mshowa
p
.002 w
.92565 .33438 m
.91926 .3356 L
s
P
[(7)] .93843 .33194 -1 .19109 Mshowa
p
.002 w
.94791 .37725 m
.94151 .37841 L
s
P
[(8)] .96071 .37494 -1 .18047 Mshowa
[( W)] .94942 .2167 -1 .21657 Mshowa
P
p
p
.002 w
.06415 .21592 m
.02602 .48592 L
s
P
p
.002 w
.06415 .21592 m
.07043 .21422 L
s
P
[(0)] .05159 .21932 1 -0.27075 Mshowa
p
.002 w
.05516 .27958 m
.06147 .27798 L
s
P
[(0.25)] .04255 .28277 1 -0.25347 Mshowa
p
.002 w
.04583 .34565 m
.05216 .34416 L
s
P
[(0.5)] .03317 .34863 1 -0.23545 Mshowa
p
.002 w
.03614 .41429 m
.0425 .41291 L
s
P
[(0.75)] .02342 .41704 1 -0.21663 Mshowa
p
.002 w
.02606 .48563 m
.03245 .48437 L
s
P
[(1)] .0133 .48815 1 -0.19696 Mshowa
p
.001 w
.06238 .22846 m
.06615 .22745 L
s
P
p
.001 w
.06059 .2411 m
.06437 .2401 L
s
P
p
.001 w
.0588 .25383 m
.06257 .25285 L
s
P
p
.001 w
.05699 .26665 m
.06077 .26568 L
s
P
p
.001 w
.05332 .29259 m
.05711 .29165 L
s
P
p
.001 w
.05147 .30571 m
.05526 .30477 L
s
P
p
.001 w
.0496 .31892 m
.0534 .318 L
s
P
p
.001 w
.04772 .33224 m
.05152 .33133 L
s
P
p
.001 w
.04392 .35917 m
.04772 .35829 L
s
P
p
.001 w
.042 .37279 m
.0458 .37192 L
s
P
p
.001 w
.04006 .38652 m
.04387 .38566 L
s
P
p
.001 w
.03811 .40035 m
.04192 .39951 L
s
P
p
.001 w
.03415 .42833 m
.03797 .42752 L
s
P
p
.001 w
.03216 .44249 m
.03598 .44169 L
s
P
p
.001 w
.03014 .45676 m
.03396 .45597 L
s
P
p
.001 w
.02811 .47114 m
.03194 .47037 L
s
P
[(Grade    )] -0.03018 .36368 1 -0.23542 Mshowa
P
0 0 m
1 0 L
1 .70801 L
0 .70801 L
closepath
clip
newpath
p
.002 w
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.40498 .68199 L
s
.40498 .68199 m
.41257 .47386 L
s
.41257 .47386 m
.06415 .21592 L
s
.76552 .02602 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.76552 .02602 m
.06415 .21592 L
s
.41257 .47386 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.40498 .68199 L
s
.40498 .68199 m
.41257 .47386 L
s
p
.4 g
.06415 .21592 m
.41257 .47386 L
s
P
p
.4 g
.21689 .17456 m
.53392 .45196 L
s
P
p
.4 g
.38334 .1295 m
.66306 .42866 L
s
P
p
.4 g
.56545 .08019 m
.80076 .40381 L
s
P
p
.4 g
.76552 .02602 m
.94791 .37725 L
s
P
p
.4 g
.06415 .21592 m
.76552 .02602 L
s
P
p
.4 g
.20556 .32061 m
.84183 .17296 L
s
P
p
.4 g
.31922 .40476 m
.90087 .28666 L
s
P
p
.4 g
.41257 .47386 m
.94791 .37725 L
s
P
P
p
.002 w
.42844 .47622 m .47231 .46308 L .41257 .47386 L p
0 .266 .7 r
F P
1 0 0 r
s
P
p
.002 w
.41257 .47386 m .36808 .44092 L .42844 .47622 L p
0 .266 .7 r
F P
1 0 0 r
s
P
p
.002 w
.49243 .51364 m .53392 .45196 L .47231 .46308 L p
.628 .09 0 r
F P
1 0 0 r
s
P
p
.002 w
.47231 .46308 m .42844 .47622 L .49243 .51364 L p
.628 .09 0 r
F P
1 0 0 r
s
P
p
.002 w
.56021 .50233 m .59747 .44049 L .53392 .45196 L p
.365 0 .062 r
F P
1 0 0 r
s
P
p
.002 w
.53392 .45196 m .49243 .51364 L .56021 .50233 L p
.365 0 .062 r
F P
1 0 0 r
s
P
p
.002 w
.37885 .49107 m .42844 .47622 L .36808 .44092 L p
.78 .291 0 r
F P
1 0 0 r
s
P
p
.002 w
.36808 .44092 m .31922 .40476 L .37885 .49107 L p
.78 .291 0 r
F P
1 0 0 r
s
P
p
.002 w
.63033 .49063 m .66306 .42866 L .59747 .44049 L p
.365 0 .062 r
F P
1 0 0 r
s
P
p
.002 w
.59747 .44049 m .56021 .50233 L .63033 .49063 L p
.365 0 .062 r
F P
1 0 0 r
s
P
p
.002 w
.70293 .47852 m .73079 .41643 L .66306 .42866 L p
.365 0 .062 r
F P
1 0 0 r
s
P
p
.002 w
.66306 .42866 m .63033 .49063 L .70293 .47852 L p
.365 0 .062 r
F P
1 0 0 r
s
P
p
.002 w
.44526 .54217 m .49243 .51364 L .42844 .47622 L p
.689 .172 0 r
F P
1 0 0 r
s
P
p
.002 w
.42844 .47622 m .37885 .49107 L .44526 .54217 L p
.689 .172 0 r
F P
1 0 0 r
s
P
p
.002 w
.77594 .43127 m .80076 .40381 L .73079 .41643 L p
.092 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.73079 .41643 m .70293 .47852 L .77594 .43127 L p
.092 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.32562 .45395 m .37885 .49107 L .31922 .40476 L p
.78 .291 0 r
F P
1 0 0 r
s
P
p
.002 w
.31922 .40476 m .26533 .36485 L .32562 .45395 L p
.78 .291 0 r
F P
1 0 0 r
s
P
p
.002 w
.85017 .38323 m .87309 .39075 L .80076 .40381 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.80076 .40381 m .77594 .43127 L .85017 .38323 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.51702 .53057 m .56021 .50233 L .49243 .51364 L p
.124 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.49243 .51364 m .44526 .54217 L .51702 .53057 L p
.124 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.92565 .33438 m .94791 .37725 L .87309 .39075 L p
.64 .966 .854 r
F P
1 0 0 r
s
P
p
.002 w
.87309 .39075 m .85017 .38323 L .92565 .33438 L p
.64 .966 .854 r
F P
1 0 0 r
s
P
p
.002 w
.59146 .51854 m .63033 .49063 L .56021 .50233 L p
.124 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.56021 .50233 m .51702 .53057 L .59146 .51854 L p
.124 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.39378 .50653 m .44526 .54217 L .37885 .49107 L p
.465 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.37885 .49107 m .32562 .45395 L .39378 .50653 L p
.465 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.66871 .50606 m .70293 .47852 L .63033 .49063 L p
.124 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.63033 .49063 m .59146 .51854 L .66871 .50606 L p
.124 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.26631 .41257 m .32562 .45395 L .26533 .36485 L p
.78 .291 0 r
F P
1 0 0 r
s
P
p
.002 w
.26533 .36485 m .20556 .32061 L .26631 .41257 L p
.78 .291 0 r
F P
1 0 0 r
s
P
p
.002 w
.74566 .43334 m .77594 .43127 L .70293 .47852 L p
.536 .857 .565 r
F P
1 0 0 r
s
P
p
.002 w
.70293 .47852 m .66871 .50606 L .74566 .43334 L p
.536 .857 .565 r
F P
1 0 0 r
s
P
p
.002 w
.82417 .37471 m .85017 .38323 L .77594 .43127 L p
.634 .957 .785 r
F P
1 0 0 r
s
P
p
.002 w
.77594 .43127 m .74566 .43334 L .82417 .37471 L p
.634 .957 .785 r
F P
1 0 0 r
s
P
p
.002 w
.46865 .49358 m .51702 .53057 L .44526 .54217 L p
.501 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.44526 .54217 m .39378 .50653 L .46865 .49358 L p
.501 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.90087 .28666 m .92565 .33438 L .85017 .38323 L p
.822 .995 .759 r
F P
1 0 0 r
s
P
p
.002 w
.85017 .38323 m .82417 .37471 L .90087 .28666 L p
.822 .995 .759 r
F P
1 0 0 r
s
P
p
.002 w
.54647 .48012 m .59146 .51854 L .51702 .53057 L p
.501 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.51702 .53057 m .46865 .49358 L .54647 .48012 L p
.501 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.33619 .46666 m .39378 .50653 L .32562 .45395 L p
.465 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.32562 .45395 m .26631 .41257 L .33619 .46666 L p
.465 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.20538 .30885 m .26631 .41257 L .20556 .32061 L p
0 .266 .7 r
F P
1 0 0 r
s
P
p
.002 w
.20556 .32061 m .13893 .27128 L .20538 .30885 L p
0 .266 .7 r
F P
1 0 0 r
s
P
p
.002 w
.62741 .46613 m .66871 .50606 L .59146 .51854 L p
.501 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.59146 .51854 m .54647 .48012 L .62741 .46613 L p
.501 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.41442 .45211 m .46865 .49358 L .39378 .50653 L p
.501 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.39378 .50653 m .33619 .46666 L .41442 .45211 L p
.501 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.70882 .38895 m .74566 .43334 L .66871 .50606 L p
.85 .939 .881 r
F P
1 0 0 r
s
P
p
.002 w
.66871 .50606 m .62741 .46613 L .70882 .38895 L p
.85 .939 .881 r
F P
1 0 0 r
s
P
p
.002 w
.79178 .32648 m .82417 .37471 L .74566 .43334 L p
.799 .931 .92 r
F P
1 0 0 r
s
P
p
.002 w
.74566 .43334 m .70882 .38895 L .79178 .32648 L p
.799 .931 .92 r
F P
1 0 0 r
s
P
p
.002 w
.87312 .23322 m .90087 .28666 L .82417 .37471 L p
.888 .945 .842 r
F P
1 0 0 r
s
P
p
.002 w
.82417 .37471 m .79178 .32648 L .87312 .23322 L p
.888 .945 .842 r
F P
1 0 0 r
s
P
p
.002 w
.49592 .43695 m .54647 .48012 L .46865 .49358 L p
.501 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.46865 .49358 m .41442 .45211 L .49592 .43695 L p
.501 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.27683 .34924 m .33619 .46666 L .26631 .41257 L p
.093 .37 .834 r
F P
1 0 0 r
s
P
p
.002 w
.26631 .41257 m .20538 .30885 L .27683 .34924 L p
.093 .37 .834 r
F P
1 0 0 r
s
P
p
.002 w
.13891 .19568 m .20538 .30885 L .13893 .27128 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.13893 .27128 m .06415 .21592 L .13891 .19568 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.58089 .42115 m .62741 .46613 L .54647 .48012 L p
.501 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.54647 .48012 m .49592 .43695 L .58089 .42115 L p
.501 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.35714 .33157 m .41442 .45211 L .33619 .46666 L p
.585 .65 .881 r
F P
1 0 0 r
s
P
p
.002 w
.33619 .46666 m .27683 .34924 L .35714 .33157 L p
.585 .65 .881 r
F P
1 0 0 r
s
P
p
.002 w
.66732 .33895 m .70882 .38895 L .62741 .46613 L p
.85 .939 .881 r
F P
1 0 0 r
s
P
p
.002 w
.62741 .46613 m .58089 .42115 L .66732 .33895 L p
.85 .939 .881 r
F P
1 0 0 r
s
P
p
.002 w
.75525 .27209 m .79178 .32648 L .70882 .38895 L p
.799 .931 .92 r
F P
1 0 0 r
s
P
p
.002 w
.70882 .38895 m .66732 .33895 L .75525 .27209 L p
.799 .931 .92 r
F P
1 0 0 r
s
P
p
.002 w
.21689 .17456 m .27683 .34924 L .20538 .30885 L p
.59 .672 .897 r
F P
1 0 0 r
s
P
p
.002 w
.20538 .30885 m .13891 .19568 L .21689 .17456 L p
.59 .672 .897 r
F P
1 0 0 r
s
P
p
.002 w
.84183 .17296 m .87312 .23322 L .79178 .32648 L p
.888 .945 .842 r
F P
1 0 0 r
s
P
p
.002 w
.79178 .32648 m .75525 .27209 L .84183 .17296 L p
.888 .945 .842 r
F P
1 0 0 r
s
P
p
.002 w
.44095 .31313 m .49592 .43695 L .41442 .45211 L p
.585 .65 .881 r
F P
1 0 0 r
s
P
p
.002 w
.41442 .45211 m .35714 .33157 L .44095 .31313 L p
.585 .65 .881 r
F P
1 0 0 r
s
P
p
.002 w
.52849 .29386 m .58089 .42115 L .49592 .43695 L p
.585 .65 .881 r
F P
1 0 0 r
s
P
p
.002 w
.49592 .43695 m .44095 .31313 L .52849 .29386 L p
.585 .65 .881 r
F P
1 0 0 r
s
P
p
.002 w
.29828 .15253 m .35714 .33157 L .27683 .34924 L p
.58 .573 .81 r
F P
1 0 0 r
s
P
p
.002 w
.27683 .34924 m .21689 .17456 L .29828 .15253 L p
.58 .573 .81 r
F P
1 0 0 r
s
P
p
.002 w
.61914 .23207 m .66732 .33895 L .58089 .42115 L p
.734 .732 .849 r
F P
1 0 0 r
s
P
p
.002 w
.58089 .42115 m .52849 .29386 L .61914 .23207 L p
.734 .732 .849 r
F P
1 0 0 r
s
P
p
.002 w
.38334 .1295 m .44095 .31313 L .35714 .33157 L p
.58 .573 .81 r
F P
1 0 0 r
s
P
p
.002 w
.35714 .33157 m .29828 .15253 L .38334 .1295 L p
.58 .573 .81 r
F P
1 0 0 r
s
P
p
.002 w
.71171 .16896 m .75525 .27209 L .66732 .33895 L p
.752 .787 .881 r
F P
1 0 0 r
s
P
p
.002 w
.66732 .33895 m .61914 .23207 L .71171 .16896 L p
.752 .787 .881 r
F P
1 0 0 r
s
P
p
.002 w
.80628 .1045 m .84183 .17296 L .75525 .27209 L p
.758 .807 .892 r
F P
1 0 0 r
s
P
p
.002 w
.75525 .27209 m .71171 .16896 L .80628 .1045 L p
.758 .807 .892 r
F P
1 0 0 r
s
P
p
.002 w
.4723 .10541 m .52849 .29386 L .44095 .31313 L p
.58 .573 .81 r
F P
1 0 0 r
s
P
p
.002 w
.44095 .31313 m .38334 .1295 L .4723 .10541 L p
.58 .573 .81 r
F P
1 0 0 r
s
P
p
.002 w
.56545 .08019 m .61914 .23207 L .52849 .29386 L p
.58 .573 .81 r
F P
1 0 0 r
s
P
p
.002 w
.52849 .29386 m .4723 .10541 L .56545 .08019 L p
.58 .573 .81 r
F P
1 0 0 r
s
P
p
.002 w
.66308 .05376 m .71171 .16896 L .61914 .23207 L p
.588 .635 .865 r
F P
1 0 0 r
s
P
p
.002 w
.61914 .23207 m .56545 .08019 L .66308 .05376 L p
.588 .635 .865 r
F P
1 0 0 r
s
P
p
.002 w
.76552 .02602 m .80628 .1045 L .71171 .16896 L p
.589 .715 .931 r
F P
1 0 0 r
s
P
p
.002 w
.71171 .16896 m .66308 .05376 L .76552 .02602 L p
.589 .715 .931 r
F P
1 0 0 r
s
P
p
.002 w
.76552 .02602 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.76552 .02602 m
.06415 .21592 L
s
P
p
p
.002 w
.06415 .21592 m
.76552 .02602 L
s
P
p
.002 w
.06415 .21592 m
.06324 .22236 L
s
P
[(0)] .06597 .20303 -0.14121 1 Mshowa
p
.002 w
.13891 .19568 m
.13814 .20213 L
s
P
[(1)] .14046 .18276 -0.12003 1 Mshowa
p
.002 w
.21689 .17456 m
.21625 .18104 L
s
P
[(2)] .21815 .16161 -0.09768 1 Mshowa
p
.002 w
.29828 .15253 m
.2978 .15901 L
s
P
[(3)] .29924 .13955 -0.07404 1 Mshowa
p
.002 w
.38334 .1295 m
.38302 .136 L
s
P
[(4)] .38398 .1165 -0.049 1 Mshowa
p
.002 w
.4723 .10541 m
.47215 .11192 L
s
P
[(5)] .47259 .0924 -0.02244 1 Mshowa
p
.002 w
.56545 .08019 m
.56548 .0867 L
s
P
[(6)] .56537 .06718 .00579 1 Mshowa
p
.002 w
.66308 .05376 m
.66331 .06026 L
s
P
[(7)] .66261 .04076 .03584 1 Mshowa
p
.002 w
.76552 .02602 m
.76597 .03251 L
s
P
[(8)] .76464 .01304 .06791 1 Mshowa
[(V )] .38716 .05152 -0.049 1 Mshowa
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{398, 281},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["MaxStar", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
For the MaxStar composition, the membership grades are found by taking the \
maximum of the result of applying a user-defined function to corresponding \
membership grades in the rows of the first fuzzy relation and the columns of \
the second fuzzy relation. Let us see how to use this function.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
First, we create a function of our own for combining membership grades. We \
create a function which combines membership grades by taking half of the Min \
of the membership grades.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["MyFun[x__] := Min[x]/2", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Now we call the Compostition function with Type set to MaxStar with our \
function, MyFun, as a parameter.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Comp3 = Composition[Rel1,Rel2,Type->MaxStar[MyFun]];", "Input",
  PageWidth->Infinity,
  PageBreakAbove->True,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzySurfacePlot[Comp3];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .70801 
MathPictureStart
%% Graphics3D
/Times-Bold findfont 10  scalefont  setfont
% Scaling calculations
0.0260223 1.04089 -0.0958739 1.04089 [
[(0)] .06597 .20303 -0.14121 1 Msboxa
[(1)] .14046 .18276 -0.12003 1 Msboxa
[(2)] .21815 .16161 -0.09768 1 Msboxa
[(3)] .29924 .13955 -0.07404 1 Msboxa
[(4)] .38398 .1165 -0.049 1 Msboxa
[(5)] .47259 .0924 -0.02244 1 Msboxa
[(6)] .56537 .06718 .00579 1 Msboxa
[(7)] .66261 .04076 .03584 1 Msboxa
[(8)] .76464 .01304 .06791 1 Msboxa
[(V )] .38716 .05152 -0.049 1 Msboxa
[(2)] .77808 .02262 -1 .27075 Msboxa
[(3)] .8189 .10134 -1 .24991 Msboxa
[(4)] .8545 .17002 -1 .23205 Msboxa
[(5)] .88584 .23047 -1 .21657 Msboxa
[(6)] .91362 .28407 -1 .20303 Msboxa
[(7)] .93843 .33194 -1 .19109 Msboxa
[(8)] .96071 .37494 -1 .18047 Msboxa
[( W)] .94942 .2167 -1 .21657 Msboxa
[(0)] .05159 .21932 1 -0.27075 Msboxa
[(0.25)] .04255 .28277 1 -0.25347 Msboxa
[(0.5)] .03317 .34863 1 -0.23545 Msboxa
[(0.75)] .02342 .41704 1 -0.21663 Msboxa
[(1)] .0133 .48815 1 -0.19696 Msboxa
[(Grade    )] -0.03018 .36368 1 -0.23542 Msboxa
[ 0 0 0 0 ]
[ 1 .70801 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.06415 .21592 m
.76552 .02602 L
s
P
p
.002 w
.06415 .21592 m
.06324 .22236 L
s
P
[(0)] .06597 .20303 -0.14121 1 Mshowa
p
.002 w
.13891 .19568 m
.13814 .20213 L
s
P
[(1)] .14046 .18276 -0.12003 1 Mshowa
p
.002 w
.21689 .17456 m
.21625 .18104 L
s
P
[(2)] .21815 .16161 -0.09768 1 Mshowa
p
.002 w
.29828 .15253 m
.2978 .15901 L
s
P
[(3)] .29924 .13955 -0.07404 1 Mshowa
p
.002 w
.38334 .1295 m
.38302 .136 L
s
P
[(4)] .38398 .1165 -0.049 1 Mshowa
p
.002 w
.4723 .10541 m
.47215 .11192 L
s
P
[(5)] .47259 .0924 -0.02244 1 Mshowa
p
.002 w
.56545 .08019 m
.56548 .0867 L
s
P
[(6)] .56537 .06718 .00579 1 Mshowa
p
.002 w
.66308 .05376 m
.66331 .06026 L
s
P
[(7)] .66261 .04076 .03584 1 Mshowa
p
.002 w
.76552 .02602 m
.76597 .03251 L
s
P
[(8)] .76464 .01304 .06791 1 Mshowa
[(V )] .38716 .05152 -0.049 1 Mshowa
P
p
p
.002 w
.76552 .02602 m
.94791 .37725 L
s
P
p
.002 w
.76552 .02602 m
.75925 .02772 L
s
P
[(2)] .77808 .02262 -1 .27075 Mshowa
p
.002 w
.80628 .1045 m
.79996 .10608 L
s
P
[(3)] .8189 .10134 -1 .24991 Mshowa
p
.002 w
.84183 .17296 m
.83549 .17444 L
s
P
[(4)] .8545 .17002 -1 .23205 Mshowa
p
.002 w
.87312 .23322 m
.86676 .2346 L
s
P
[(5)] .88584 .23047 -1 .21657 Mshowa
p
.002 w
.90087 .28666 m
.89449 .28796 L
s
P
[(6)] .91362 .28407 -1 .20303 Mshowa
p
.002 w
.92565 .33438 m
.91926 .3356 L
s
P
[(7)] .93843 .33194 -1 .19109 Mshowa
p
.002 w
.94791 .37725 m
.94151 .37841 L
s
P
[(8)] .96071 .37494 -1 .18047 Mshowa
[( W)] .94942 .2167 -1 .21657 Mshowa
P
p
p
.002 w
.06415 .21592 m
.02602 .48592 L
s
P
p
.002 w
.06415 .21592 m
.07043 .21422 L
s
P
[(0)] .05159 .21932 1 -0.27075 Mshowa
p
.002 w
.05516 .27958 m
.06147 .27798 L
s
P
[(0.25)] .04255 .28277 1 -0.25347 Mshowa
p
.002 w
.04583 .34565 m
.05216 .34416 L
s
P
[(0.5)] .03317 .34863 1 -0.23545 Mshowa
p
.002 w
.03614 .41429 m
.0425 .41291 L
s
P
[(0.75)] .02342 .41704 1 -0.21663 Mshowa
p
.002 w
.02606 .48563 m
.03245 .48437 L
s
P
[(1)] .0133 .48815 1 -0.19696 Mshowa
p
.001 w
.06238 .22846 m
.06615 .22745 L
s
P
p
.001 w
.06059 .2411 m
.06437 .2401 L
s
P
p
.001 w
.0588 .25383 m
.06257 .25285 L
s
P
p
.001 w
.05699 .26665 m
.06077 .26568 L
s
P
p
.001 w
.05332 .29259 m
.05711 .29165 L
s
P
p
.001 w
.05147 .30571 m
.05526 .30477 L
s
P
p
.001 w
.0496 .31892 m
.0534 .318 L
s
P
p
.001 w
.04772 .33224 m
.05152 .33133 L
s
P
p
.001 w
.04392 .35917 m
.04772 .35829 L
s
P
p
.001 w
.042 .37279 m
.0458 .37192 L
s
P
p
.001 w
.04006 .38652 m
.04387 .38566 L
s
P
p
.001 w
.03811 .40035 m
.04192 .39951 L
s
P
p
.001 w
.03415 .42833 m
.03797 .42752 L
s
P
p
.001 w
.03216 .44249 m
.03598 .44169 L
s
P
p
.001 w
.03014 .45676 m
.03396 .45597 L
s
P
p
.001 w
.02811 .47114 m
.03194 .47037 L
s
P
[(Grade    )] -0.03018 .36368 1 -0.23542 Mshowa
P
0 0 m
1 0 L
1 .70801 L
0 .70801 L
closepath
clip
newpath
p
.002 w
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.40498 .68199 L
s
.40498 .68199 m
.41257 .47386 L
s
.41257 .47386 m
.06415 .21592 L
s
.76552 .02602 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.76552 .02602 m
.06415 .21592 L
s
.41257 .47386 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.40498 .68199 L
s
.40498 .68199 m
.41257 .47386 L
s
p
.4 g
.06415 .21592 m
.41257 .47386 L
s
P
p
.4 g
.21689 .17456 m
.53392 .45196 L
s
P
p
.4 g
.38334 .1295 m
.66306 .42866 L
s
P
p
.4 g
.56545 .08019 m
.80076 .40381 L
s
P
p
.4 g
.76552 .02602 m
.94791 .37725 L
s
P
p
.4 g
.06415 .21592 m
.76552 .02602 L
s
P
p
.4 g
.20556 .32061 m
.84183 .17296 L
s
P
p
.4 g
.31922 .40476 m
.90087 .28666 L
s
P
p
.4 g
.41257 .47386 m
.94791 .37725 L
s
P
P
p
.002 w
.42844 .47622 m .47231 .46308 L .41257 .47386 L p
0 .266 .7 r
F P
1 0 0 r
s
P
p
.002 w
.41257 .47386 m .36808 .44092 L .42844 .47622 L p
0 .266 .7 r
F P
1 0 0 r
s
P
p
.002 w
.49314 .46463 m .53392 .45196 L .47231 .46308 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.47231 .46308 m .42844 .47622 L .49314 .46463 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.56002 .45265 m .59747 .44049 L .53392 .45196 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.53392 .45196 m .49314 .46463 L .56002 .45265 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.38088 .44625 m .42844 .47622 L .36808 .44092 L p
0 .18 .624 r
F P
1 0 0 r
s
P
p
.002 w
.36808 .44092 m .31922 .40476 L .38088 .44625 L p
0 .18 .624 r
F P
1 0 0 r
s
P
p
.002 w
.62919 .44026 m .66306 .42866 L .59747 .44049 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.59747 .44049 m .56002 .45265 L .62919 .44026 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.70076 .42744 m .73079 .41643 L .66306 .42866 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.66306 .42866 m .62919 .44026 L .70076 .42744 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.44752 .45838 m .49314 .46463 L .42844 .47622 L p
.138 .606 .923 r
F P
1 0 0 r
s
P
p
.002 w
.42844 .47622 m .38088 .44625 L .44752 .45838 L p
.138 .606 .923 r
F P
1 0 0 r
s
P
p
.002 w
.77486 .41417 m .80076 .40381 L .73079 .41643 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.73079 .41643 m .70076 .42744 L .77486 .41417 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.51769 .44556 m .56002 .45265 L .49314 .46463 L p
.314 .798 .892 r
F P
1 0 0 r
s
P
p
.002 w
.49314 .46463 m .44752 .45838 L .51769 .44556 L p
.314 .798 .892 r
F P
1 0 0 r
s
P
p
.002 w
.32844 .40721 m .38088 .44625 L .31922 .40476 L p
0 .18 .624 r
F P
1 0 0 r
s
P
p
.002 w
.31922 .40476 m .26533 .36485 L .32844 .40721 L p
0 .18 .624 r
F P
1 0 0 r
s
P
p
.002 w
.85049 .38704 m .87309 .39075 L .80076 .40381 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.80076 .40381 m .77486 .41417 L .85049 .38704 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.59041 .43226 m .62919 .44026 L .56002 .45265 L p
.314 .798 .892 r
F P
1 0 0 r
s
P
p
.002 w
.56002 .45265 m .51769 .44556 L .59041 .43226 L p
.314 .798 .892 r
F P
1 0 0 r
s
P
p
.002 w
.92565 .33438 m .94791 .37725 L .87309 .39075 L p
.633 .96 .812 r
F P
1 0 0 r
s
P
p
.002 w
.87309 .39075 m .85049 .38704 L .92565 .33438 L p
.633 .96 .812 r
F P
1 0 0 r
s
P
p
.002 w
.66582 .41848 m .70076 .42744 L .62919 .44026 L p
.314 .798 .892 r
F P
1 0 0 r
s
P
p
.002 w
.62919 .44026 m .59041 .43226 L .66582 .41848 L p
.314 .798 .892 r
F P
1 0 0 r
s
P
p
.002 w
.39738 .419 m .44752 .45838 L .38088 .44625 L p
.193 .62 .946 r
F P
1 0 0 r
s
P
p
.002 w
.38088 .44625 m .32844 .40721 L .39738 .419 L p
.193 .62 .946 r
F P
1 0 0 r
s
P
p
.002 w
.74371 .39776 m .77486 .41417 L .70076 .42744 L p
.398 .849 .907 r
F P
1 0 0 r
s
P
p
.002 w
.70076 .42744 m .66582 .41848 L .74371 .39776 L p
.398 .849 .907 r
F P
1 0 0 r
s
P
p
.002 w
.27009 .36376 m .32844 .40721 L .26533 .36485 L p
0 .18 .624 r
F P
1 0 0 r
s
P
p
.002 w
.26533 .36485 m .20556 .32061 L .27009 .36376 L p
0 .18 .624 r
F P
1 0 0 r
s
P
p
.002 w
.47052 .40472 m .51769 .44556 L .44752 .45838 L p
.536 .814 .997 r
F P
1 0 0 r
s
P
p
.002 w
.44752 .45838 m .39738 .419 L .47052 .40472 L p
.536 .814 .997 r
F P
1 0 0 r
s
P
p
.002 w
.82168 .34264 m .85049 .38704 L .77486 .41417 L p
.737 .985 .903 r
F P
1 0 0 r
s
P
p
.002 w
.77486 .41417 m .74371 .39776 L .82168 .34264 L p
.737 .985 .903 r
F P
1 0 0 r
s
P
p
.002 w
.54647 .38989 m .59041 .43226 L .51769 .44556 L p
.536 .814 .997 r
F P
1 0 0 r
s
P
p
.002 w
.51769 .44556 m .47052 .40472 L .54647 .38989 L p
.536 .814 .997 r
F P
1 0 0 r
s
P
p
.002 w
.90087 .28666 m .92565 .33438 L .85049 .38704 L p
.788 .921 .926 r
F P
1 0 0 r
s
P
p
.002 w
.85049 .38704 m .82168 .34264 L .90087 .28666 L p
.788 .921 .926 r
F P
1 0 0 r
s
P
p
.002 w
.34144 .37506 m .39738 .419 L .32844 .40721 L p
.193 .62 .946 r
F P
1 0 0 r
s
P
p
.002 w
.32844 .40721 m .27009 .36376 L .34144 .37506 L p
.193 .62 .946 r
F P
1 0 0 r
s
P
p
.002 w
.62538 .37447 m .66582 .41848 L .59041 .43226 L p
.536 .814 .997 r
F P
1 0 0 r
s
P
p
.002 w
.59041 .43226 m .54647 .38989 L .62538 .37447 L p
.536 .814 .997 r
F P
1 0 0 r
s
P
p
.002 w
.20538 .30885 m .27009 .36376 L .20556 .32061 L p
0 .266 .7 r
F P
1 0 0 r
s
P
p
.002 w
.20556 .32061 m .13893 .27128 L .20538 .30885 L p
0 .266 .7 r
F P
1 0 0 r
s
P
p
.002 w
.41778 .35905 m .47052 .40472 L .39738 .419 L p
.536 .814 .997 r
F P
1 0 0 r
s
P
p
.002 w
.39738 .419 m .34144 .37506 L .41778 .35905 L p
.536 .814 .997 r
F P
1 0 0 r
s
P
p
.002 w
.70714 .35174 m .74371 .39776 L .66582 .41848 L p
.59 .841 .992 r
F P
1 0 0 r
s
P
p
.002 w
.66582 .41848 m .62538 .37447 L .70714 .35174 L p
.59 .841 .992 r
F P
1 0 0 r
s
P
p
.002 w
.78945 .29297 m .82168 .34264 L .74371 .39776 L p
.788 .921 .926 r
F P
1 0 0 r
s
P
p
.002 w
.74371 .39776 m .70714 .35174 L .78945 .29297 L p
.788 .921 .926 r
F P
1 0 0 r
s
P
p
.002 w
.49723 .3424 m .54647 .38989 L .47052 .40472 L p
.536 .814 .997 r
F P
1 0 0 r
s
P
p
.002 w
.47052 .40472 m .41778 .35905 L .49723 .3424 L p
.536 .814 .997 r
F P
1 0 0 r
s
P
p
.002 w
.87312 .23322 m .90087 .28666 L .82168 .34264 L p
.788 .921 .926 r
F P
1 0 0 r
s
P
p
.002 w
.82168 .34264 m .78945 .29297 L .87312 .23322 L p
.788 .921 .926 r
F P
1 0 0 r
s
P
p
.002 w
.28126 .291 m .34144 .37506 L .27009 .36376 L p
.559 .797 .988 r
F P
1 0 0 r
s
P
p
.002 w
.27009 .36376 m .20538 .30885 L .28126 .291 L p
.559 .797 .988 r
F P
1 0 0 r
s
P
p
.002 w
.57998 .32506 m .62538 .37447 L .54647 .38989 L p
.536 .814 .997 r
F P
1 0 0 r
s
P
p
.002 w
.54647 .38989 m .49723 .3424 L .57998 .32506 L p
.536 .814 .997 r
F P
1 0 0 r
s
P
p
.002 w
.13891 .19568 m .20538 .30885 L .13893 .27128 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.13893 .27128 m .06415 .21592 L .13891 .19568 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.36031 .2724 m .41778 .35905 L .34144 .37506 L p
.585 .726 .94 r
F P
1 0 0 r
s
P
p
.002 w
.34144 .37506 m .28126 .291 L .36031 .2724 L p
.585 .726 .94 r
F P
1 0 0 r
s
P
p
.002 w
.66599 .29995 m .70714 .35174 L .62538 .37447 L p
.59 .841 .992 r
F P
1 0 0 r
s
P
p
.002 w
.62538 .37447 m .57998 .32506 L .66599 .29995 L p
.59 .841 .992 r
F P
1 0 0 r
s
P
p
.002 w
.75314 .23701 m .78945 .29297 L .70714 .35174 L p
.788 .921 .926 r
F P
1 0 0 r
s
P
p
.002 w
.70714 .35174 m .66599 .29995 L .75314 .23701 L p
.788 .921 .926 r
F P
1 0 0 r
s
P
p
.002 w
.44275 .25301 m .49723 .3424 L .41778 .35905 L p
.585 .726 .94 r
F P
1 0 0 r
s
P
p
.002 w
.41778 .35905 m .36031 .2724 L .44275 .25301 L p
.585 .726 .94 r
F P
1 0 0 r
s
P
p
.002 w
.84183 .17296 m .87312 .23322 L .78945 .29297 L p
.788 .921 .926 r
F P
1 0 0 r
s
P
p
.002 w
.78945 .29297 m .75314 .23701 L .84183 .17296 L p
.788 .921 .926 r
F P
1 0 0 r
s
P
p
.002 w
.21689 .17456 m .28126 .291 L .20538 .30885 L p
.59 .672 .897 r
F P
1 0 0 r
s
P
p
.002 w
.20538 .30885 m .13891 .19568 L .21689 .17456 L p
.59 .672 .897 r
F P
1 0 0 r
s
P
p
.002 w
.5288 .23276 m .57998 .32506 L .49723 .3424 L p
.585 .726 .94 r
F P
1 0 0 r
s
P
p
.002 w
.49723 .3424 m .44275 .25301 L .5288 .23276 L p
.585 .726 .94 r
F P
1 0 0 r
s
P
p
.002 w
.29828 .15253 m .36031 .2724 L .28126 .291 L p
.59 .672 .897 r
F P
1 0 0 r
s
P
p
.002 w
.28126 .291 m .21689 .17456 L .29828 .15253 L p
.59 .672 .897 r
F P
1 0 0 r
s
P
p
.002 w
.6187 .21161 m .66599 .29995 L .57998 .32506 L p
.585 .726 .94 r
F P
1 0 0 r
s
P
p
.002 w
.57998 .32506 m .5288 .23276 L .6187 .21161 L p
.585 .726 .94 r
F P
1 0 0 r
s
P
p
.002 w
.38334 .1295 m .44275 .25301 L .36031 .2724 L p
.59 .672 .897 r
F P
1 0 0 r
s
P
p
.002 w
.36031 .2724 m .29828 .15253 L .38334 .1295 L p
.59 .672 .897 r
F P
1 0 0 r
s
P
p
.002 w
.71194 .1735 m .75314 .23701 L .66599 .29995 L p
.664 .787 .94 r
F P
1 0 0 r
s
P
p
.002 w
.66599 .29995 m .6187 .21161 L .71194 .1735 L p
.664 .787 .94 r
F P
1 0 0 r
s
P
p
.002 w
.80628 .1045 m .84183 .17296 L .75314 .23701 L p
.788 .921 .926 r
F P
1 0 0 r
s
P
p
.002 w
.75314 .23701 m .71194 .1735 L .80628 .1045 L p
.788 .921 .926 r
F P
1 0 0 r
s
P
p
.002 w
.4723 .10541 m .5288 .23276 L .44275 .25301 L p
.59 .672 .897 r
F P
1 0 0 r
s
P
p
.002 w
.44275 .25301 m .38334 .1295 L .4723 .10541 L p
.59 .672 .897 r
F P
1 0 0 r
s
P
p
.002 w
.56545 .08019 m .6187 .21161 L .5288 .23276 L p
.59 .672 .897 r
F P
1 0 0 r
s
P
p
.002 w
.5288 .23276 m .4723 .10541 L .56545 .08019 L p
.59 .672 .897 r
F P
1 0 0 r
s
P
p
.002 w
.66308 .05376 m .71194 .1735 L .6187 .21161 L p
.59 .672 .897 r
F P
1 0 0 r
s
P
p
.002 w
.6187 .21161 m .56545 .08019 L .66308 .05376 L p
.59 .672 .897 r
F P
1 0 0 r
s
P
p
.002 w
.76552 .02602 m .80628 .1045 L .71194 .1735 L p
.59 .705 .923 r
F P
1 0 0 r
s
P
p
.002 w
.71194 .1735 m .66308 .05376 L .76552 .02602 L p
.59 .705 .923 r
F P
1 0 0 r
s
P
p
.002 w
.76552 .02602 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.76552 .02602 m
.06415 .21592 L
s
P
p
p
.002 w
.06415 .21592 m
.76552 .02602 L
s
P
p
.002 w
.06415 .21592 m
.06324 .22236 L
s
P
[(0)] .06597 .20303 -0.14121 1 Mshowa
p
.002 w
.13891 .19568 m
.13814 .20213 L
s
P
[(1)] .14046 .18276 -0.12003 1 Mshowa
p
.002 w
.21689 .17456 m
.21625 .18104 L
s
P
[(2)] .21815 .16161 -0.09768 1 Mshowa
p
.002 w
.29828 .15253 m
.2978 .15901 L
s
P
[(3)] .29924 .13955 -0.07404 1 Mshowa
p
.002 w
.38334 .1295 m
.38302 .136 L
s
P
[(4)] .38398 .1165 -0.049 1 Mshowa
p
.002 w
.4723 .10541 m
.47215 .11192 L
s
P
[(5)] .47259 .0924 -0.02244 1 Mshowa
p
.002 w
.56545 .08019 m
.56548 .0867 L
s
P
[(6)] .56537 .06718 .00579 1 Mshowa
p
.002 w
.66308 .05376 m
.66331 .06026 L
s
P
[(7)] .66261 .04076 .03584 1 Mshowa
p
.002 w
.76552 .02602 m
.76597 .03251 L
s
P
[(8)] .76464 .01304 .06791 1 Mshowa
[(V )] .38716 .05152 -0.049 1 Mshowa
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{398, 281},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]]}, Open]]}, Open]]}, Open]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{496, 599},
WindowMargins->{{55, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False}
]



(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 78, 7, 70, "Title"],

Cell[CellGroupData[{
Cell[1840, 60, 67, 1, 70, "Subsection"],
Cell[1910, 63, 265, 5, 70, "Text"],
Cell[2178, 70, 143, 4, 70, "Text"],
Cell[2324, 76, 102, 2, 70, "Input"],
Cell[2429, 80, 304, 6, 70, "SmallText"],
Cell[2736, 88, 526, 9, 70, "Text"],
Cell[3265, 99, 164, 5, 70, "Input"],
Cell[3432, 106, 166, 5, 70, "Input"],
Cell[3601, 113, 311, 6, 70, "Text"],
Cell[3915, 121, 237, 5, 70, "Text"],

Cell[CellGroupData[{
Cell[4175, 128, 96, 2, 70, "Input"],
Cell[4274, 132, 14986, 1311, 70, 14828, 1306, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19292, 1445, 96, 2, 70, "Input"],
Cell[19391, 1449, 12627, 1099, 70, 12469, 1094, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],
Cell[32039, 2550, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[32112, 2553, 67, 1, 70, "Subsection"],
Cell[32182, 2556, 403, 7, 70, "Text"],
Cell[32588, 2565, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[32661, 2568, 64, 1, 70, "Subsubsection"],
Cell[32728, 2571, 647, 10, 70, "Text"],
Cell[33378, 2583, 104, 2, 70, "Input"],

Cell[CellGroupData[{
Cell[33505, 2587, 97, 2, 70, "Input"],
Cell[33605, 2591, 15042, 1321, 70, 14884, 1316, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],
Cell[48668, 3914, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[48741, 3917, 68, 1, 70, "Subsubsection"],
Cell[48812, 3920, 322, 6, 70, "Text"],
Cell[49137, 3928, 121, 2, 70, "Input"],

Cell[CellGroupData[{
Cell[49281, 3932, 97, 2, 70, "Input"],
Cell[49381, 3936, 14842, 1301, 70, 14684, 1296, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],
Cell[64244, 5239, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[64317, 5242, 65, 1, 70, "Subsubsection"],
Cell[64385, 5245, 353, 6, 70, "Text"],
Cell[64741, 5253, 238, 5, 70, "Text"],
Cell[64982, 5260, 95, 2, 70, "Input"],
Cell[65080, 5264, 163, 4, 70, "Text"],
Cell[65246, 5270, 149, 3, 70, "Input",
  PageBreakAbove->True],

Cell[CellGroupData[{
Cell[65418, 5275, 97, 2, 70, "Input"],
Cell[65518, 5279, 14840, 1301, 70, 14682, 1296, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)
