(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     38101,       3243]*)
(*NotebookOutlinePosition[     38969,       3275]*)
(*  CellTagsIndexPosition[     38925,       3271]*)
(*WindowFrame->Normal*)



Notebook[{


Cell[CellGroupData[{Cell["\<\
Fuzzy Arithmetic
 
 
 
 \
\>", "Title",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Introduction", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
The Fuzzy Logic Pack provides a number of functions for performing fuzzy \
arithmetic. In this chapter, we will demonstrate these functions and the \
options associated with each function. \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
First we need to load the proper routines. This is done with the following \
command. \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Needs[\"FuzzyLogic`Master`\"]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
If the package loading command fails, verify that the directory containing \
the Fuzzy Logic directory is on Mathematica's $Path. You can use the command \
AppendTo[$Path, \"directory\"]. For convenience, this should be in your \
init.m file.\
\>", "SmallText",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
The arithmetic operations described in this chapter are designed to work with \
triangular or trapezoidal fuzzy numbers. The arithmetic functions are a \
little different than the rest of the Fuzzy Logic Pack's functions in that \
they operate on lists of numbers which represent vertices of fuzzy sets, \
rather than fuzzy sets themselves. This makes working with these operations a \
little awkward, but we show a convenient way to work with these functions in \
this section. For fuzzy arithmetic operations which work on actual fuzzy \
sets, see the section on Discrete Fuzzy Arithmetic. \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
First we need to set up an appropriate universal space. Since we are working \
with fuzzy numbers, and since they can be positive or negative, our universal \
space should be symmetic around zero. The universal space should also be big \
enough so that the results of the arithmetic operations will still fall \
within the universal space. We set the default universal space from -30 to 30 \
here using the SetOptions command.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["SetOptions[FuzzySet,UniversalSpace->{-30,30}];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Now that the universal space is defined, we need some fuzzy numbers to \
operate on. As mentioned earlier, these operations work on lists of vertices, \
so we create two lists now which represent two triangular fuzzy numbers. \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["num1 := {-2,3,3,8}", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["num2 := {7,10,10,13}", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
We can convert the list of vertices, num1 and num2, into actual fuzzy sets \
using the FuzzyTrapezoid function and look at the results with the FuzzyPlot \
function.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["A1 = FuzzyTrapezoid[num1];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["A2 = FuzzyTrapezoid[num2];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzyPlot[A1,A2,PlotJoined->True];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.016129 0 0.618034 [
[(-30)] .01613 0 0 2 Msboxa
[(-20)] .17742 0 0 2 Msboxa
[(-10)] .33871 0 0 2 Msboxa
[(0)] .5 0 0 2 Msboxa
[(10)] .66129 0 0 2 Msboxa
[(20)] .82258 0 0 2 Msboxa
[(30)] .98387 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.01613 0 m
.01613 .00625 L
s
P
[(-30)] .01613 0 0 2 Mshowa
p
.002 w
.17742 0 m
.17742 .00625 L
s
P
[(-20)] .17742 0 0 2 Mshowa
p
.002 w
.33871 0 m
.33871 .00625 L
s
P
[(-10)] .33871 0 0 2 Mshowa
p
.002 w
.5 0 m
.5 .00625 L
s
P
[(0)] .5 0 0 2 Mshowa
p
.002 w
.66129 0 m
.66129 .00625 L
s
P
[(10)] .66129 0 0 2 Mshowa
p
.002 w
.82258 0 m
.82258 .00625 L
s
P
[(20)] .82258 0 0 2 Mshowa
p
.002 w
.98387 0 m
.98387 .00625 L
s
P
[(30)] .98387 0 0 2 Mshowa
p
.001 w
.04839 0 m
.04839 .00375 L
s
P
p
.001 w
.08065 0 m
.08065 .00375 L
s
P
p
.001 w
.1129 0 m
.1129 .00375 L
s
P
p
.001 w
.14516 0 m
.14516 .00375 L
s
P
p
.001 w
.20968 0 m
.20968 .00375 L
s
P
p
.001 w
.24194 0 m
.24194 .00375 L
s
P
p
.001 w
.27419 0 m
.27419 .00375 L
s
P
p
.001 w
.30645 0 m
.30645 .00375 L
s
P
p
.001 w
.37097 0 m
.37097 .00375 L
s
P
p
.001 w
.40323 0 m
.40323 .00375 L
s
P
p
.001 w
.43548 0 m
.43548 .00375 L
s
P
p
.001 w
.46774 0 m
.46774 .00375 L
s
P
p
.001 w
.53226 0 m
.53226 .00375 L
s
P
p
.001 w
.56452 0 m
.56452 .00375 L
s
P
p
.001 w
.59677 0 m
.59677 .00375 L
s
P
p
.001 w
.62903 0 m
.62903 .00375 L
s
P
p
.001 w
.69355 0 m
.69355 .00375 L
s
P
p
.001 w
.72581 0 m
.72581 .00375 L
s
P
p
.001 w
.75806 0 m
.75806 .00375 L
s
P
p
.001 w
.79032 0 m
.79032 .00375 L
s
P
p
.001 w
.85484 0 m
.85484 .00375 L
s
P
p
.001 w
.8871 0 m
.8871 .00375 L
s
P
p
.001 w
.91935 0 m
.91935 .00375 L
s
P
p
.001 w
.95161 0 m
.95161 .00375 L
s
P
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
1.76777 Mabswid
.01613 0 m
.03226 0 L
.04839 0 L
.06452 0 L
.08065 0 L
.09677 0 L
.1129 0 L
.12903 0 L
.14516 0 L
.16129 0 L
.17742 0 L
.19355 0 L
.20968 0 L
.22581 0 L
.24194 0 L
.25806 0 L
.27419 0 L
.29032 0 L
.30645 0 L
.32258 0 L
.33871 0 L
.35484 0 L
.37097 0 L
.3871 0 L
.40323 0 L
.41935 0 L
.43548 0 L
.45161 0 L
.46774 0 L
.48387 .12361 L
.5 .24721 L
.51613 .37082 L
.53226 .49443 L
.54839 .61803 L
.56452 .49443 L
.58065 .37082 L
.59677 .24721 L
.6129 .12361 L
.62903 0 L
.64516 0 L
.66129 0 L
.67742 0 L
.69355 0 L
.70968 0 L
.72581 0 L
.74194 0 L
.75806 0 L
.77419 0 L
.79032 0 L
.80645 0 L
Mistroke
.82258 0 L
.83871 0 L
.85484 0 L
.87097 0 L
.8871 0 L
.90323 0 L
.91935 0 L
.93548 0 L
.95161 0 L
.96774 0 L
.98387 0 L
Mfstroke
P
p
.2 0 1 r
1.76777 Mabswid
.01613 0 m
.03226 0 L
.04839 0 L
.06452 0 L
.08065 0 L
.09677 0 L
.1129 0 L
.12903 0 L
.14516 0 L
.16129 0 L
.17742 0 L
.19355 0 L
.20968 0 L
.22581 0 L
.24194 0 L
.25806 0 L
.27419 0 L
.29032 0 L
.30645 0 L
.32258 0 L
.33871 0 L
.35484 0 L
.37097 0 L
.3871 0 L
.40323 0 L
.41935 0 L
.43548 0 L
.45161 0 L
.46774 0 L
.48387 0 L
.5 0 L
.51613 0 L
.53226 0 L
.54839 0 L
.56452 0 L
.58065 0 L
.59677 0 L
.6129 0 L
.62903 .20601 L
.64516 .41202 L
.66129 .61803 L
.67742 .41202 L
.69355 .20601 L
.70968 0 L
.72581 0 L
.74194 0 L
.75806 0 L
.77419 0 L
.79032 0 L
.80645 0 L
Mistroke
.82258 0 L
.83871 0 L
.85484 0 L
.87097 0 L
.8871 0 L
.90323 0 L
.91935 0 L
.93548 0 L
.95161 0 L
.96774 0 L
.98387 0 L
Mfstroke
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{398, 246},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Fuzzy Addition", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
FuzzyPlus[{a1,b1,c1,d1},{a2,b2,c2,d2},opts] returns the sum of the fuzzy \
numbers represented by the two lists. The fuzzy sum is returned as an \
unevaluated FuzzyTrapezoid. To evaluate the FuzzyTrapezoid use the \
ReleaseHold function.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Sum1 = FuzzyPlus[num1,num2]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
HoldForm[FuzzyTrapezoid[5, 13, 13, 21, UniversalSpace -> {-30, 30}]]








\
\>", "\<\
FuzzyTrapezoid[5, 13, 13, 21, UniversalSpace -> {-30, 30}]\
\>"], "Output",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell["\<\
The result of the fuzzy addition of the two fuzzy numbers is an unevaluated \
fuzzy trapezoid. To evaluate the result as a normal fuzzy set, you must use \
Mathematica's ReleaseHold command. Below we plot our two original fuzzy sets \
with their sum. Notice the use of the ReleaseHold command.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzyPlot[A1,A2,ReleaseHold[Sum1],PlotJoined->True];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.016129 0 0.618034 [
[(-30)] .01613 0 0 2 Msboxa
[(-20)] .17742 0 0 2 Msboxa
[(-10)] .33871 0 0 2 Msboxa
[(0)] .5 0 0 2 Msboxa
[(10)] .66129 0 0 2 Msboxa
[(20)] .82258 0 0 2 Msboxa
[(30)] .98387 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.01613 0 m
.01613 .00625 L
s
P
[(-30)] .01613 0 0 2 Mshowa
p
.002 w
.17742 0 m
.17742 .00625 L
s
P
[(-20)] .17742 0 0 2 Mshowa
p
.002 w
.33871 0 m
.33871 .00625 L
s
P
[(-10)] .33871 0 0 2 Mshowa
p
.002 w
.5 0 m
.5 .00625 L
s
P
[(0)] .5 0 0 2 Mshowa
p
.002 w
.66129 0 m
.66129 .00625 L
s
P
[(10)] .66129 0 0 2 Mshowa
p
.002 w
.82258 0 m
.82258 .00625 L
s
P
[(20)] .82258 0 0 2 Mshowa
p
.002 w
.98387 0 m
.98387 .00625 L
s
P
[(30)] .98387 0 0 2 Mshowa
p
.001 w
.04839 0 m
.04839 .00375 L
s
P
p
.001 w
.08065 0 m
.08065 .00375 L
s
P
p
.001 w
.1129 0 m
.1129 .00375 L
s
P
p
.001 w
.14516 0 m
.14516 .00375 L
s
P
p
.001 w
.20968 0 m
.20968 .00375 L
s
P
p
.001 w
.24194 0 m
.24194 .00375 L
s
P
p
.001 w
.27419 0 m
.27419 .00375 L
s
P
p
.001 w
.30645 0 m
.30645 .00375 L
s
P
p
.001 w
.37097 0 m
.37097 .00375 L
s
P
p
.001 w
.40323 0 m
.40323 .00375 L
s
P
p
.001 w
.43548 0 m
.43548 .00375 L
s
P
p
.001 w
.46774 0 m
.46774 .00375 L
s
P
p
.001 w
.53226 0 m
.53226 .00375 L
s
P
p
.001 w
.56452 0 m
.56452 .00375 L
s
P
p
.001 w
.59677 0 m
.59677 .00375 L
s
P
p
.001 w
.62903 0 m
.62903 .00375 L
s
P
p
.001 w
.69355 0 m
.69355 .00375 L
s
P
p
.001 w
.72581 0 m
.72581 .00375 L
s
P
p
.001 w
.75806 0 m
.75806 .00375 L
s
P
p
.001 w
.79032 0 m
.79032 .00375 L
s
P
p
.001 w
.85484 0 m
.85484 .00375 L
s
P
p
.001 w
.8871 0 m
.8871 .00375 L
s
P
p
.001 w
.91935 0 m
.91935 .00375 L
s
P
p
.001 w
.95161 0 m
.95161 .00375 L
s
P
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
1.44338 Mabswid
.01613 0 m
.03226 0 L
.04839 0 L
.06452 0 L
.08065 0 L
.09677 0 L
.1129 0 L
.12903 0 L
.14516 0 L
.16129 0 L
.17742 0 L
.19355 0 L
.20968 0 L
.22581 0 L
.24194 0 L
.25806 0 L
.27419 0 L
.29032 0 L
.30645 0 L
.32258 0 L
.33871 0 L
.35484 0 L
.37097 0 L
.3871 0 L
.40323 0 L
.41935 0 L
.43548 0 L
.45161 0 L
.46774 0 L
.48387 .12361 L
.5 .24721 L
.51613 .37082 L
.53226 .49443 L
.54839 .61803 L
.56452 .49443 L
.58065 .37082 L
.59677 .24721 L
.6129 .12361 L
.62903 0 L
.64516 0 L
.66129 0 L
.67742 0 L
.69355 0 L
.70968 0 L
.72581 0 L
.74194 0 L
.75806 0 L
.77419 0 L
.79032 0 L
.80645 0 L
Mistroke
.82258 0 L
.83871 0 L
.85484 0 L
.87097 0 L
.8871 0 L
.90323 0 L
.91935 0 L
.93548 0 L
.95161 0 L
.96774 0 L
.98387 0 L
Mfstroke
P
p
.2 0 1 r
1.44338 Mabswid
.01613 0 m
.03226 0 L
.04839 0 L
.06452 0 L
.08065 0 L
.09677 0 L
.1129 0 L
.12903 0 L
.14516 0 L
.16129 0 L
.17742 0 L
.19355 0 L
.20968 0 L
.22581 0 L
.24194 0 L
.25806 0 L
.27419 0 L
.29032 0 L
.30645 0 L
.32258 0 L
.33871 0 L
.35484 0 L
.37097 0 L
.3871 0 L
.40323 0 L
.41935 0 L
.43548 0 L
.45161 0 L
.46774 0 L
.48387 0 L
.5 0 L
.51613 0 L
.53226 0 L
.54839 0 L
.56452 0 L
.58065 0 L
.59677 0 L
.6129 0 L
.62903 .20601 L
.64516 .41202 L
.66129 .61803 L
.67742 .41202 L
.69355 .20601 L
.70968 0 L
.72581 0 L
.74194 0 L
.75806 0 L
.77419 0 L
.79032 0 L
.80645 0 L
Mistroke
.82258 0 L
.83871 0 L
.85484 0 L
.87097 0 L
.8871 0 L
.90323 0 L
.91935 0 L
.93548 0 L
.95161 0 L
.96774 0 L
.98387 0 L
Mfstroke
P
p
0 1 .4 r
1.44338 Mabswid
.01613 0 m
.03226 0 L
.04839 0 L
.06452 0 L
.08065 0 L
.09677 0 L
.1129 0 L
.12903 0 L
.14516 0 L
.16129 0 L
.17742 0 L
.19355 0 L
.20968 0 L
.22581 0 L
.24194 0 L
.25806 0 L
.27419 0 L
.29032 0 L
.30645 0 L
.32258 0 L
.33871 0 L
.35484 0 L
.37097 0 L
.3871 0 L
.40323 0 L
.41935 0 L
.43548 0 L
.45161 0 L
.46774 0 L
.48387 0 L
.5 0 L
.51613 0 L
.53226 0 L
.54839 0 L
.56452 0 L
.58065 0 L
.59677 .07725 L
.6129 .15451 L
.62903 .23176 L
.64516 .30902 L
.66129 .38627 L
.67742 .46353 L
.69355 .54078 L
.70968 .61803 L
.72581 .54078 L
.74194 .46353 L
.75806 .38627 L
.77419 .30902 L
.79032 .23176 L
.80645 .15451 L
Mistroke
.82258 .07725 L
.83871 0 L
.85484 0 L
.87097 0 L
.8871 0 L
.90323 0 L
.91935 0 L
.93548 0 L
.95161 0 L
.96774 0 L
.98387 0 L
Mfstroke
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{398, 246},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Fuzzy Subtraction", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
FuzzyMinus[{a1,b1,c1,d1},{a2,b2,c2,d2},opts] returns the fuzzy difference \
between the two fuzzy numbers represented by the two lists. The fuzzy \
difference is returned as an unevaluated FuzzyTrapezoid. To evaluate the \
FuzzyTrapezoid use ReleaseHold.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Diff1 = FuzzyMinus[num1,num2]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
HoldForm[FuzzyTrapezoid[-15, -7, -7, 1, UniversalSpace -> {-30, 30}]]








\
\>", "\<\
FuzzyTrapezoid[-15, -7, -7, 1, UniversalSpace -> {-30, 30}]\
\>"], "Output",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell["\<\
The fuzzy difference between the two fuzzy numbers is returned in the same \
form as the fuzzy sum. Here we plot the original fuzzy sets with their fuzzy \
difference.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzyPlot[A1,A2,ReleaseHold[Diff1],PlotJoined->True];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.016129 0 0.618034 [
[(-30)] .01613 0 0 2 Msboxa
[(-20)] .17742 0 0 2 Msboxa
[(-10)] .33871 0 0 2 Msboxa
[(0)] .5 0 0 2 Msboxa
[(10)] .66129 0 0 2 Msboxa
[(20)] .82258 0 0 2 Msboxa
[(30)] .98387 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.01613 0 m
.01613 .00625 L
s
P
[(-30)] .01613 0 0 2 Mshowa
p
.002 w
.17742 0 m
.17742 .00625 L
s
P
[(-20)] .17742 0 0 2 Mshowa
p
.002 w
.33871 0 m
.33871 .00625 L
s
P
[(-10)] .33871 0 0 2 Mshowa
p
.002 w
.5 0 m
.5 .00625 L
s
P
[(0)] .5 0 0 2 Mshowa
p
.002 w
.66129 0 m
.66129 .00625 L
s
P
[(10)] .66129 0 0 2 Mshowa
p
.002 w
.82258 0 m
.82258 .00625 L
s
P
[(20)] .82258 0 0 2 Mshowa
p
.002 w
.98387 0 m
.98387 .00625 L
s
P
[(30)] .98387 0 0 2 Mshowa
p
.001 w
.04839 0 m
.04839 .00375 L
s
P
p
.001 w
.08065 0 m
.08065 .00375 L
s
P
p
.001 w
.1129 0 m
.1129 .00375 L
s
P
p
.001 w
.14516 0 m
.14516 .00375 L
s
P
p
.001 w
.20968 0 m
.20968 .00375 L
s
P
p
.001 w
.24194 0 m
.24194 .00375 L
s
P
p
.001 w
.27419 0 m
.27419 .00375 L
s
P
p
.001 w
.30645 0 m
.30645 .00375 L
s
P
p
.001 w
.37097 0 m
.37097 .00375 L
s
P
p
.001 w
.40323 0 m
.40323 .00375 L
s
P
p
.001 w
.43548 0 m
.43548 .00375 L
s
P
p
.001 w
.46774 0 m
.46774 .00375 L
s
P
p
.001 w
.53226 0 m
.53226 .00375 L
s
P
p
.001 w
.56452 0 m
.56452 .00375 L
s
P
p
.001 w
.59677 0 m
.59677 .00375 L
s
P
p
.001 w
.62903 0 m
.62903 .00375 L
s
P
p
.001 w
.69355 0 m
.69355 .00375 L
s
P
p
.001 w
.72581 0 m
.72581 .00375 L
s
P
p
.001 w
.75806 0 m
.75806 .00375 L
s
P
p
.001 w
.79032 0 m
.79032 .00375 L
s
P
p
.001 w
.85484 0 m
.85484 .00375 L
s
P
p
.001 w
.8871 0 m
.8871 .00375 L
s
P
p
.001 w
.91935 0 m
.91935 .00375 L
s
P
p
.001 w
.95161 0 m
.95161 .00375 L
s
P
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
1.44338 Mabswid
.01613 0 m
.03226 0 L
.04839 0 L
.06452 0 L
.08065 0 L
.09677 0 L
.1129 0 L
.12903 0 L
.14516 0 L
.16129 0 L
.17742 0 L
.19355 0 L
.20968 0 L
.22581 0 L
.24194 0 L
.25806 0 L
.27419 0 L
.29032 0 L
.30645 0 L
.32258 0 L
.33871 0 L
.35484 0 L
.37097 0 L
.3871 0 L
.40323 0 L
.41935 0 L
.43548 0 L
.45161 0 L
.46774 0 L
.48387 .12361 L
.5 .24721 L
.51613 .37082 L
.53226 .49443 L
.54839 .61803 L
.56452 .49443 L
.58065 .37082 L
.59677 .24721 L
.6129 .12361 L
.62903 0 L
.64516 0 L
.66129 0 L
.67742 0 L
.69355 0 L
.70968 0 L
.72581 0 L
.74194 0 L
.75806 0 L
.77419 0 L
.79032 0 L
.80645 0 L
Mistroke
.82258 0 L
.83871 0 L
.85484 0 L
.87097 0 L
.8871 0 L
.90323 0 L
.91935 0 L
.93548 0 L
.95161 0 L
.96774 0 L
.98387 0 L
Mfstroke
P
p
.2 0 1 r
1.44338 Mabswid
.01613 0 m
.03226 0 L
.04839 0 L
.06452 0 L
.08065 0 L
.09677 0 L
.1129 0 L
.12903 0 L
.14516 0 L
.16129 0 L
.17742 0 L
.19355 0 L
.20968 0 L
.22581 0 L
.24194 0 L
.25806 0 L
.27419 0 L
.29032 0 L
.30645 0 L
.32258 0 L
.33871 0 L
.35484 0 L
.37097 0 L
.3871 0 L
.40323 0 L
.41935 0 L
.43548 0 L
.45161 0 L
.46774 0 L
.48387 0 L
.5 0 L
.51613 0 L
.53226 0 L
.54839 0 L
.56452 0 L
.58065 0 L
.59677 0 L
.6129 0 L
.62903 .20601 L
.64516 .41202 L
.66129 .61803 L
.67742 .41202 L
.69355 .20601 L
.70968 0 L
.72581 0 L
.74194 0 L
.75806 0 L
.77419 0 L
.79032 0 L
.80645 0 L
Mistroke
.82258 0 L
.83871 0 L
.85484 0 L
.87097 0 L
.8871 0 L
.90323 0 L
.91935 0 L
.93548 0 L
.95161 0 L
.96774 0 L
.98387 0 L
Mfstroke
P
p
0 1 .4 r
1.44338 Mabswid
.01613 0 m
.03226 0 L
.04839 0 L
.06452 0 L
.08065 0 L
.09677 0 L
.1129 0 L
.12903 0 L
.14516 0 L
.16129 0 L
.17742 0 L
.19355 0 L
.20968 0 L
.22581 0 L
.24194 0 L
.25806 0 L
.27419 .07725 L
.29032 .15451 L
.30645 .23176 L
.32258 .30902 L
.33871 .38627 L
.35484 .46353 L
.37097 .54078 L
.3871 .61803 L
.40323 .54078 L
.41935 .46353 L
.43548 .38627 L
.45161 .30902 L
.46774 .23176 L
.48387 .15451 L
.5 .07725 L
.51613 0 L
.53226 0 L
.54839 0 L
.56452 0 L
.58065 0 L
.59677 0 L
.6129 0 L
.62903 0 L
.64516 0 L
.66129 0 L
.67742 0 L
.69355 0 L
.70968 0 L
.72581 0 L
.74194 0 L
.75806 0 L
.77419 0 L
.79032 0 L
.80645 0 L
Mistroke
.82258 0 L
.83871 0 L
.85484 0 L
.87097 0 L
.8871 0 L
.90323 0 L
.91935 0 L
.93548 0 L
.95161 0 L
.96774 0 L
.98387 0 L
Mfstroke
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{398, 246},
  ImageMargins->{{35, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Constant Multiplication", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
FuzzyConstantTimes[{a,b,c,d},k,opts] returns the fuzzy number which is the \
result of the multiplication of constant k by the fuzzy number represented by \
the list, {a,b,c,d}. The result is returned as an unevaluated FuzzyTrapezoid. \
To evaluate the FuzzyTrapezoid use ReleaseHold.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Prod1 = FuzzyConstantTimes[num1,-3]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
HoldForm[FuzzyTrapezoid[-24, -9, -9, 6, UniversalSpace -> {-30, 30}]]








\
\>", "\<\
FuzzyTrapezoid[-24, -9, -9, 6, UniversalSpace -> {-30, 30}]\
\>"], "Output",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["FuzzyPlot[A1,ReleaseHold[Prod1],PlotJoined->True];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.016129 0 0.618034 [
[(-30)] .01613 0 0 2 Msboxa
[(-20)] .17742 0 0 2 Msboxa
[(-10)] .33871 0 0 2 Msboxa
[(0)] .5 0 0 2 Msboxa
[(10)] .66129 0 0 2 Msboxa
[(20)] .82258 0 0 2 Msboxa
[(30)] .98387 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.01613 0 m
.01613 .00625 L
s
P
[(-30)] .01613 0 0 2 Mshowa
p
.002 w
.17742 0 m
.17742 .00625 L
s
P
[(-20)] .17742 0 0 2 Mshowa
p
.002 w
.33871 0 m
.33871 .00625 L
s
P
[(-10)] .33871 0 0 2 Mshowa
p
.002 w
.5 0 m
.5 .00625 L
s
P
[(0)] .5 0 0 2 Mshowa
p
.002 w
.66129 0 m
.66129 .00625 L
s
P
[(10)] .66129 0 0 2 Mshowa
p
.002 w
.82258 0 m
.82258 .00625 L
s
P
[(20)] .82258 0 0 2 Mshowa
p
.002 w
.98387 0 m
.98387 .00625 L
s
P
[(30)] .98387 0 0 2 Mshowa
p
.001 w
.04839 0 m
.04839 .00375 L
s
P
p
.001 w
.08065 0 m
.08065 .00375 L
s
P
p
.001 w
.1129 0 m
.1129 .00375 L
s
P
p
.001 w
.14516 0 m
.14516 .00375 L
s
P
p
.001 w
.20968 0 m
.20968 .00375 L
s
P
p
.001 w
.24194 0 m
.24194 .00375 L
s
P
p
.001 w
.27419 0 m
.27419 .00375 L
s
P
p
.001 w
.30645 0 m
.30645 .00375 L
s
P
p
.001 w
.37097 0 m
.37097 .00375 L
s
P
p
.001 w
.40323 0 m
.40323 .00375 L
s
P
p
.001 w
.43548 0 m
.43548 .00375 L
s
P
p
.001 w
.46774 0 m
.46774 .00375 L
s
P
p
.001 w
.53226 0 m
.53226 .00375 L
s
P
p
.001 w
.56452 0 m
.56452 .00375 L
s
P
p
.001 w
.59677 0 m
.59677 .00375 L
s
P
p
.001 w
.62903 0 m
.62903 .00375 L
s
P
p
.001 w
.69355 0 m
.69355 .00375 L
s
P
p
.001 w
.72581 0 m
.72581 .00375 L
s
P
p
.001 w
.75806 0 m
.75806 .00375 L
s
P
p
.001 w
.79032 0 m
.79032 .00375 L
s
P
p
.001 w
.85484 0 m
.85484 .00375 L
s
P
p
.001 w
.8871 0 m
.8871 .00375 L
s
P
p
.001 w
.91935 0 m
.91935 .00375 L
s
P
p
.001 w
.95161 0 m
.95161 .00375 L
s
P
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
1.76777 Mabswid
.01613 0 m
.03226 0 L
.04839 0 L
.06452 0 L
.08065 0 L
.09677 0 L
.1129 0 L
.12903 0 L
.14516 0 L
.16129 0 L
.17742 0 L
.19355 0 L
.20968 0 L
.22581 0 L
.24194 0 L
.25806 0 L
.27419 0 L
.29032 0 L
.30645 0 L
.32258 0 L
.33871 0 L
.35484 0 L
.37097 0 L
.3871 0 L
.40323 0 L
.41935 0 L
.43548 0 L
.45161 0 L
.46774 0 L
.48387 .12361 L
.5 .24721 L
.51613 .37082 L
.53226 .49443 L
.54839 .61803 L
.56452 .49443 L
.58065 .37082 L
.59677 .24721 L
.6129 .12361 L
.62903 0 L
.64516 0 L
.66129 0 L
.67742 0 L
.69355 0 L
.70968 0 L
.72581 0 L
.74194 0 L
.75806 0 L
.77419 0 L
.79032 0 L
.80645 0 L
Mistroke
.82258 0 L
.83871 0 L
.85484 0 L
.87097 0 L
.8871 0 L
.90323 0 L
.91935 0 L
.93548 0 L
.95161 0 L
.96774 0 L
.98387 0 L
Mfstroke
P
p
.2 0 1 r
1.76777 Mabswid
.01613 0 m
.03226 0 L
.04839 0 L
.06452 0 L
.08065 0 L
.09677 0 L
.1129 0 L
.12903 .0412 L
.14516 .0824 L
.16129 .12361 L
.17742 .16481 L
.19355 .20601 L
.20968 .24721 L
.22581 .28842 L
.24194 .32962 L
.25806 .37082 L
.27419 .41202 L
.29032 .45322 L
.30645 .49443 L
.32258 .53563 L
.33871 .57683 L
.35484 .61803 L
.37097 .57683 L
.3871 .53563 L
.40323 .49443 L
.41935 .45322 L
.43548 .41202 L
.45161 .37082 L
.46774 .32962 L
.48387 .28842 L
.5 .24721 L
.51613 .20601 L
.53226 .16481 L
.54839 .12361 L
.56452 .0824 L
.58065 .0412 L
.59677 0 L
.6129 0 L
.62903 0 L
.64516 0 L
.66129 0 L
.67742 0 L
.69355 0 L
.70968 0 L
.72581 0 L
.74194 0 L
.75806 0 L
.77419 0 L
.79032 0 L
.80645 0 L
Mistroke
.82258 0 L
.83871 0 L
.85484 0 L
.87097 0 L
.8871 0 L
.90323 0 L
.91935 0 L
.93548 0 L
.95161 0 L
.96774 0 L
.98387 0 L
Mfstroke
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{398, 246},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Fuzzy Image", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
FuzzyImage[{a,b,c,d}] returns the image of the fuzzy number represented by \
the list {a,b,c,d}. The result is returned as an unevaluated FuzzyTrapezoid. \
To evaluate the FuzzyTrapezoid use ReleaseHold.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Im1 = FuzzyImage[num1]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
HoldForm[FuzzyTrapezoid[-8, -3, -3, 2, UniversalSpace -> {-30, 30}]]








\
\>", "\<\
FuzzyTrapezoid[-8, -3, -3, 2, UniversalSpace -> {-30, 30}]\
\>"], "Output",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell["\<\
The image of a fuzzy set is a new fuzzy set which is a mirror image of the \
first one flipped around zero. Here is a plot of our first fuzzy set and its \
image.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzyPlot[A1,ReleaseHold[Im1],PlotJoined->True];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.016129 0 0.618034 [
[(-30)] .01613 0 0 2 Msboxa
[(-20)] .17742 0 0 2 Msboxa
[(-10)] .33871 0 0 2 Msboxa
[(0)] .5 0 0 2 Msboxa
[(10)] .66129 0 0 2 Msboxa
[(20)] .82258 0 0 2 Msboxa
[(30)] .98387 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.01613 0 m
.01613 .00625 L
s
P
[(-30)] .01613 0 0 2 Mshowa
p
.002 w
.17742 0 m
.17742 .00625 L
s
P
[(-20)] .17742 0 0 2 Mshowa
p
.002 w
.33871 0 m
.33871 .00625 L
s
P
[(-10)] .33871 0 0 2 Mshowa
p
.002 w
.5 0 m
.5 .00625 L
s
P
[(0)] .5 0 0 2 Mshowa
p
.002 w
.66129 0 m
.66129 .00625 L
s
P
[(10)] .66129 0 0 2 Mshowa
p
.002 w
.82258 0 m
.82258 .00625 L
s
P
[(20)] .82258 0 0 2 Mshowa
p
.002 w
.98387 0 m
.98387 .00625 L
s
P
[(30)] .98387 0 0 2 Mshowa
p
.001 w
.04839 0 m
.04839 .00375 L
s
P
p
.001 w
.08065 0 m
.08065 .00375 L
s
P
p
.001 w
.1129 0 m
.1129 .00375 L
s
P
p
.001 w
.14516 0 m
.14516 .00375 L
s
P
p
.001 w
.20968 0 m
.20968 .00375 L
s
P
p
.001 w
.24194 0 m
.24194 .00375 L
s
P
p
.001 w
.27419 0 m
.27419 .00375 L
s
P
p
.001 w
.30645 0 m
.30645 .00375 L
s
P
p
.001 w
.37097 0 m
.37097 .00375 L
s
P
p
.001 w
.40323 0 m
.40323 .00375 L
s
P
p
.001 w
.43548 0 m
.43548 .00375 L
s
P
p
.001 w
.46774 0 m
.46774 .00375 L
s
P
p
.001 w
.53226 0 m
.53226 .00375 L
s
P
p
.001 w
.56452 0 m
.56452 .00375 L
s
P
p
.001 w
.59677 0 m
.59677 .00375 L
s
P
p
.001 w
.62903 0 m
.62903 .00375 L
s
P
p
.001 w
.69355 0 m
.69355 .00375 L
s
P
p
.001 w
.72581 0 m
.72581 .00375 L
s
P
p
.001 w
.75806 0 m
.75806 .00375 L
s
P
p
.001 w
.79032 0 m
.79032 .00375 L
s
P
p
.001 w
.85484 0 m
.85484 .00375 L
s
P
p
.001 w
.8871 0 m
.8871 .00375 L
s
P
p
.001 w
.91935 0 m
.91935 .00375 L
s
P
p
.001 w
.95161 0 m
.95161 .00375 L
s
P
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
1.76777 Mabswid
.01613 0 m
.03226 0 L
.04839 0 L
.06452 0 L
.08065 0 L
.09677 0 L
.1129 0 L
.12903 0 L
.14516 0 L
.16129 0 L
.17742 0 L
.19355 0 L
.20968 0 L
.22581 0 L
.24194 0 L
.25806 0 L
.27419 0 L
.29032 0 L
.30645 0 L
.32258 0 L
.33871 0 L
.35484 0 L
.37097 0 L
.3871 0 L
.40323 0 L
.41935 0 L
.43548 0 L
.45161 0 L
.46774 0 L
.48387 .12361 L
.5 .24721 L
.51613 .37082 L
.53226 .49443 L
.54839 .61803 L
.56452 .49443 L
.58065 .37082 L
.59677 .24721 L
.6129 .12361 L
.62903 0 L
.64516 0 L
.66129 0 L
.67742 0 L
.69355 0 L
.70968 0 L
.72581 0 L
.74194 0 L
.75806 0 L
.77419 0 L
.79032 0 L
.80645 0 L
Mistroke
.82258 0 L
.83871 0 L
.85484 0 L
.87097 0 L
.8871 0 L
.90323 0 L
.91935 0 L
.93548 0 L
.95161 0 L
.96774 0 L
.98387 0 L
Mfstroke
P
p
.2 0 1 r
1.76777 Mabswid
.01613 0 m
.03226 0 L
.04839 0 L
.06452 0 L
.08065 0 L
.09677 0 L
.1129 0 L
.12903 0 L
.14516 0 L
.16129 0 L
.17742 0 L
.19355 0 L
.20968 0 L
.22581 0 L
.24194 0 L
.25806 0 L
.27419 0 L
.29032 0 L
.30645 0 L
.32258 0 L
.33871 0 L
.35484 0 L
.37097 0 L
.3871 .12361 L
.40323 .24721 L
.41935 .37082 L
.43548 .49443 L
.45161 .61803 L
.46774 .49443 L
.48387 .37082 L
.5 .24721 L
.51613 .12361 L
.53226 0 L
.54839 0 L
.56452 0 L
.58065 0 L
.59677 0 L
.6129 0 L
.62903 0 L
.64516 0 L
.66129 0 L
.67742 0 L
.69355 0 L
.70968 0 L
.72581 0 L
.74194 0 L
.75806 0 L
.77419 0 L
.79032 0 L
.80645 0 L
Mistroke
.82258 0 L
.83871 0 L
.85484 0 L
.87097 0 L
.8871 0 L
.90323 0 L
.91935 0 L
.93548 0 L
.95161 0 L
.96774 0 L
.98387 0 L
Mfstroke
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{398, 246},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]]}, Open]]}, Open]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{496, 599},
WindowMargins->{{Automatic, 6}, {Automatic, 0}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False}
]



(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 82, 7, 70, "Title"],

Cell[CellGroupData[{
Cell[1844, 60, 67, 1, 70, "Subsection"],
Cell[1914, 63, 246, 5, 70, "Text"],
Cell[2163, 70, 143, 4, 70, "Text"],
Cell[2309, 76, 102, 2, 70, "Input"],
Cell[2414, 80, 304, 6, 70, "SmallText"],
Cell[2721, 88, 649, 10, 70, "Text"],
Cell[3373, 100, 483, 8, 70, "Text"],
Cell[3859, 110, 119, 2, 70, "Input"],
Cell[3981, 114, 283, 5, 70, "Text"],
Cell[4267, 121, 91, 2, 70, "Input"],
Cell[4361, 125, 93, 2, 70, "Input"],
Cell[4457, 129, 222, 5, 70, "Text"],
Cell[4682, 136, 99, 2, 70, "Input"],
Cell[4784, 140, 99, 2, 70, "Input"],

Cell[CellGroupData[{
Cell[4906, 144, 107, 2, 70, "Input"],
Cell[5016, 148, 5308, 555, 70, 5150, 550, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],
Cell[10345, 705, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[10418, 708, 69, 1, 70, "Subsection"],
Cell[10490, 711, 294, 6, 70, "Text"],

Cell[CellGroupData[{
Cell[10807, 719, 100, 2, 70, "Input"],
Cell[10910, 723, 245, 15, 70, "Output"]
}, Open  ]],
Cell[11167, 740, 350, 6, 70, "Text"],

Cell[CellGroupData[{
Cell[11540, 748, 125, 2, 70, "Input"],
Cell[11668, 752, 6093, 622, 70, 5935, 617, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],
Cell[17782, 1376, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[17855, 1379, 72, 1, 70, "Subsection"],
Cell[17930, 1382, 311, 6, 70, "Text"],

Cell[CellGroupData[{
Cell[18264, 1390, 102, 2, 70, "Input"],
Cell[18369, 1394, 247, 15, 70, "Output"]
}, Open  ]],
Cell[18628, 1411, 224, 5, 70, "Text"],

Cell[CellGroupData[{
Cell[18875, 1418, 126, 2, 70, "Input"],
Cell[19004, 1422, 6093, 622, 70, 5935, 617, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],
Cell[25118, 2046, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[25191, 2049, 78, 1, 70, "Subsection"],
Cell[25272, 2052, 341, 6, 70, "Text"],

Cell[CellGroupData[{
Cell[25636, 2060, 108, 2, 70, "Input"],
Cell[25747, 2064, 247, 15, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26026, 2081, 123, 2, 70, "Input"],
Cell[26152, 2085, 5424, 555, 70, 5266, 550, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],
Cell[31597, 2642, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[31670, 2645, 66, 1, 70, "Subsection"],
Cell[31739, 2648, 260, 5, 70, "Text"],

Cell[CellGroupData[{
Cell[32022, 2655, 95, 2, 70, "Input"],
Cell[32120, 2659, 245, 15, 70, "Output"]
}, Open  ]],
Cell[32377, 2676, 219, 5, 70, "Text"],

Cell[CellGroupData[{
Cell[32619, 2683, 121, 2, 70, "Input"],
Cell[32743, 2687, 5328, 555, 70, 5170, 550, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)
