(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     65777,       2117]*)
(*NotebookOutlinePosition[     66648,       2149]*)
(*  CellTagsIndexPosition[     66604,       2145]*)
(*WindowFrame->Normal*)



Notebook[{


Cell[CellGroupData[{Cell["\<\
Fuzzy Logic Quick Reference
 
 
 
 \
\>", "Title",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["I. Getting Started", "Section",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["About the Quick Reference", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
This QuickReference was created to serve two purposes. First, it may be used \
as an interactive introduction to the Fuzzy Logic Pack. In the sections which \
follow, are explanations of all of the functions in the Fuzzy Logic Pack. \
Following each explanation, is one or more Mathematica input cells which \
demonstrate the operation of each function. The input cells which can be \
evaluated are displayed in blue text. If you've never used the Fuzzy Logic \
Pack before, this QuickReference should provide a good introduction to \
Mathematica and the Fuzzy Logic Pack.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
The second purpose for creating the QuickReference was to provide a document \
which could be used as an on-line reference manual or user's guide for those \
already familiar with the functions in this pack. This reference is organized \
so that you can quickly locate functions for particular tasks. \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Terminology", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzySet form", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
A fuzzy set is characterized by two items. First is a list of pairs, \
{{u1,x1}, {u2,x2},...{un,xn}}, which contains the elements of the fuzzy set \
(u1,u2,...un) and the membership grades for each of these elements \
(x1,x2,...xn). The membership grades are values which ranges from 0 to 1 \
inclusive. The second item associated with each fuzzy set is its universal \
space. This can be thought of as a range which contains all the possible \
elements being considered for the current application. Below is an example \
showing how fuzzy sets are represented in this package. Note that in this \
pack, the universal space is defined as a range of integers. By expanding the \
universal space, the user can acheive any desired precision. For instance, if \
you want to describe a region from 0 to 10 with a precision of 0.1, you can \
use a universal space defined over the integers from 0 to 100, where 0 would \
represent 0.0 and 100 would be 10.0. This technique can be used to create \
fuzzy sets with arbitrary precision for the universal space.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
A := FuzzySet[{{1,0.1}, {2,0.5}, {3,0.7}},
           UniversalSpace->{0,4}]\
\>", "Special2",
  ImageRegion->{{0, 1}, {0, 1}},
  FontWeight->"Bold",
  Background->GrayLevel[1]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzyRelation form", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
A fuzzy relation is again characterized by the same two items as a fuzzy set. \
First is a list containing element and membership grade pairs, \
{{{uv1,uw1},x1},{{uv1,uw2},x2},... {{uvn,uwm},xnm}}. Note that now the \
elements of the relation are defined as ordered pairs, {uv1, uw1},{uv1, \
uw2},...{uvn,uwn}. These elements are again grouped with their membership \
grades (x1,x2,.., xnm) which range from 0 to 1 inclusive. The second item \
characterizing fuzzy relations is again a universal space. For relations, \
however, the universal space consists of a pair of ordered pairs, \
{{Vmin,Vmax}, {Wmin,Wmax}}. The first pair defines the universal space to be \
used for the first set under consideration in the relation, and the second \
pair defines the universal space for the second set. Below is an example \
showing how fuzzy relations are represented in this package.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
B := FuzzyRelation[{{{1,1},0.1}, {{1,2},0.5}, {{2,1},0.9},
                               {{2,2},0.7}, {{3,1},0.4}, {{3,2},1}},
                              UniversalSpace->{{0,3},{0,2}}] \
\>", "Special2",
  ImageRegion->{{0, 1}, {0, 1}},
  FontWeight->"Bold",
  Background->GrayLevel[1]]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Loading the Fuzzy Logic Pack", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
First we need to load all the necessary routines. This is done with the \
following command. \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Needs[\"Fuzzy Logic`Master`\"]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
If the package loading command fails, verify that the directory containing \
the Fuzzy Logic directory is on Mathematica's $Path. You can use the command \
AppendTo[$Path, \"directory\"]. For convenience, this should be in your \
init.m file.\
\>", "SmallText",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
With the proper routines loaded, you may now use all of the functions and \
operations in the Fuzzy Logic Pack. \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["II. Creation Functions", "Section",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Creating Fuzzy Sets", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Create a trapezoidal fuzzy set", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
FuzzyTrapezoid[a,b,c,d,h,opts] returns a fuzzy set with membership grades \
which linearly increase from zero to h in the range a to b, is h in the range \
b to c, and linearly decrease from h to zero in the range c to d. Arguments \
a,b,c, and d must be integers in increasing order, and h must be a value \
beteen 0 and 1 inclusive. If a value for h isn't specified, the function will \
use h=1. The universal space may be explicitly defined using the \
UniversalSpace option, or if a universal space isn't specified, the default \
universal space will be given. \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["FS1 = FuzzyTrapezoid[1,5,9,15,UniversalSpace->{0,20}]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell["\<\
When studying fuzzy sets, it is more meaningful to look at fuzzy sets or \
relations in their graphical form. To do this you can use one of the graphing \
functions in this package after each input. Here we will use the FuzzyPlot \
command. The other graphing functions are detailed in the Visualization \
Operation section of this manual.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["FuzzyPlot[FS1]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell["FS2 = FuzzyTrapezoid[3,9,9,17,.9]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell["\<\
Note: In the function description, arguments surrounded by parenthesis \
indicate that they are optional. Also note that this function can also be \
used to create triangular fuzzy sets by setting b and c to the same value as \
is done for FS2 above.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Create a fuzzy set from a function", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
CreateFuzzySet[func,{a,b},opts] returns a fuzzy set with membership grades \
defined by func in the range a to b inclusive. If no range is given, the \
function will apply the function to all of the elements in the universal \
space. \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Below is an example of creating a fuzzy set using a piece-wise function.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
MyFunc1[x_] := Which[x<=5,0,
                     x>5 && x<10,(x-5)/5,
                     x>=10 && x<=15,10/x,
                     x>15,0.6]\
\>", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell["FS3 = CreateFuzzySet[MyFunc1,UniversalSpace->{0,20}]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell["\<\
Note: The function you provide must return values between 0 and 1 inclusive \
over the range provided to create a valid fuzzy set.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Create a Gaussian fuzzy set", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
FuzzyGaussian[mu,sigma,opts] returns a new fuzzy set whose membership grades \
form a Gaussian function with a mean of mu and a width of sigma. The \
universal space can be optionally set with this function as well.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["FS4 = FuzzyGaussian[8,4,UniversalSpace->{0,15}]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Create a set of fuzzy sets", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
CreateFuzzySets[num, opts] returns a list of num overlapping fuzzy sets which \
span the universal space. The fuzzy sets can be either triangular or Guassian \
with triangular fuzzy sets being the default. The shape of the membership \
functions is controlled by setting the Type option to either Triangle or \
Gaussian[sigma].\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
MyInput1 = CreateFuzzySets[7,Type->Triangular,
             UniversalSpace->{0,40}];\
\>", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell["FuzzyPlot[MyInput1,PlotJoined->True]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell["\<\
MyInput2 = CreateFuzzySets[6,Type->Gaussian[3],
             UniversalSpace->{0,30}];\
\>", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell["FuzzyPlot[MyInput2,PlotJoined->True]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Create a fuzzy set manually", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Fuzzy sets can also be created manually be typing in the appropriate \
descriptors surrounded by the FuzzySet head.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
FS5=FuzzySet[{{1,.2},{2,.3},{3,.4},{4,.5}},
      UniversalSpace->{0,6}]\
\>", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Creating Fuzzy Relations", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Create a trapezoidal fuzzy relation", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
FuzzyTrapezoid[{ax,bx,cx,dx},{ay,by,cy,dy},h,opts] returns a trapezoidal \
fuzzy relation with membership grades which linearly increases from zero to h \
in both the x and y directions from a to b, is h from b to c, and linearly \
decreases from h to zero from d to d. Again if h isn't explicitly given the \
function uses h=1. As with fuzzy sets, it is possible to explicitly define \
the universal space or to accept the default setting for relations.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Rel1 = FuzzyTrapezoid[{1,3,5,7},{0,3,6,8},0.8,
         UniversalSpace->{{0,7},{0,8}}]\
\>", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Create a fuzzy relation from a function", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
CreateFuzzyRelation[func,{{va,vb},{wa,wb}},opts] returns a fuzzy relation \
with membership grades that are the result of applying func to all the \
elements in the specified range. If no range is given, the function is \
applied to all of the elements in the universal space. Make sure the function \
provided causes membership grades to be in the correct range, 0 to 1.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["MyFunc2[x_,y_] := (Sin[x+y]+1)/2", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell["\<\
Rel2 = CreateFuzzyRelation[MyFunc2,
         UniversalSpace->{{0,7},{0,8}}]\
\>", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Create a fuzzy relation from two fuzzy sets", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
SetsToRelation[func,A,B] returns a fuzzy relation with elements representing \
the Cartesian product of the universal spaces of A and B and membership \
grades which are the result of applying func to the corresponding membership \
grades of A and B.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Rel3 = SetsToRelation[Min,FS1,FS2]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Create a fuzzy relation from a membership matrix", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
FromMembershipMatrix[mat,({{va,vb},{wa,wb}})] returns a fuzzy relation, using \
the matrix of membership grades, mat, for the elements specified by the \
ranges {va,vb} and {wa,wb}. If no ranges are given, the function assumes the \
membership grades are for the elements from 1 through the dimension of the \
matrix.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
MyMembMat := {{.1, .2, .3, .4, .5},
              {.2, .3, .4, .5, .6},
              {.3, .4, .5, .6, .7},
              {.4, .5, .6, .7, .8}}\
\>", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell["Rel4 = FromMembershipMatrix[MyMembMat]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Create a fuzzy relation manually", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Fuzzy relations can also be created manually by surrounding the appropriate \
descriptors with the FuzzyRelation head.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Rel5 = FuzzyRelation[{{{1,1},.1},{{2,1},.2},{{2,2},.3}},
         UniversalSpace->{{0,5},{0,4}}] \
\>", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]]}, Open]]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["III. General Operations", "Section",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Single Fuzzy Set Operations", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Height", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Height[A] returns the value of the largest membership grade in fuzzy set A.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Height[FS2]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["Cardinality", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Cardinality[A] returns the sum of all of the membership grades in fuzzy set \
A.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Cardinality[FS1]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["Relative Cardinality", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
RelativeCardinality[A] returns the cardinality of fuzzy set A divided by the \
total number of elements in the universal space of A.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["RelativeCardinality[FS1]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["Center of Area (Defuzzification)", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
CenterOfArea[A,opts] returns the center of area defuzification of fuzzy set \
A. If the option ShowGraph is set to True, this function will return a plot \
of fuzzy set A with a dot along the base axis indicating where the center of \
area is located.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["CenterOfArea[FS1]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell["CenterOfArea[FS1,ShowGraph->True]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["Mean of Max (Defuzzification)", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
MeanOfMax[A,opts] returns the mean of maximum defuzzification of fuzzy set A. \
This function also has a ShowGraph option (see CenterOfArea above).\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["MeanOfMax[FS1,ShowGraph->True]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["Support", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Support[A] returns a list of all elements of fuzzy set A with non-zero \
membership grades.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Support[FS1]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["Nucleus", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Nucleus[A] returns a list of all elements of fuzzy set A which have a \
membership grade equal to 1.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Nucleus[FS1]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["Alpha Level Set", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
AlphaLevelSet[A, alpha] returns a list of all elements of fuzzy set A with \
membership grades greater than or equal to alpha.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["AlphaLevelSet[FS1,0.6]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["Strong Alpha Level Set", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
StrongAlphaLevelSet[A, alpha] returns a list of all elements of fuzzy set A \
with membership grades greater than alpha.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["StrongAlphaLevelSet[FS1,0.5]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["Equilibrium Set", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
EquilibriumSet[A] returns a list of all elements of fuzzy set A which have \
membership grades, yn equal to 1-yn.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["EquilibriumSet[FS1]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]]}, Open]],

Cell[CellGroupData[{Cell["Single Fuzzy Relation Operations", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Projections", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
FirstProjection[A] returns a fuzzy set which is the projection of relation A \
onto the first space of the relation.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["FirstProjection[Rel1]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell["\<\
SecondProjection[A] returns a fuzzy set which is the projection of relation A \
onto the second space of the relation.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["SecondProjection[Rel1]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell["\<\
GlobalProjection[A] returns a value which represents the maximum membership \
grade in relation A.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["GlobalProjection[Rel1]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]]}, Open]],

Cell[CellGroupData[{Cell["Operations for Either a Fuzzy Set or a Fuzzy Relation", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Concentration", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Concentrate[A] returns a fuzzy set/relation with membership grades equal to \
the square of the grades in the original fuzzy set/relation A.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Concentrate[FS1]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["Dilation", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Dilate[A] returns a fuzzy set/relation with membership grades equal to the \
square root of the grades in the original fuzzy set/relation A.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Dilate[Rel1]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["Intensify Contrast", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
IntensifyContrast[A] returns a fuzzy set/relation in which the new membership \
grades equal:
2*(yn)^2           if yn <= 0.5,
1-2 (1-yn)^2     otherwise,       yn=previous membership grade\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["IntensifyContrast[FS1]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["Normalize", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Normalize[A] returns the fuzzy set/relation A with the height normalized to \
1.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Normalize[FS2]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["Complement (standard and non-standard)", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Complement[A,opts] returns the fuzzy set/relation which is the complement of \
fuzzy set/relation A. There is a type option with this function. The standard \
complement is the default, but the following complements are also \
available:\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
   Type\t\t\t\tParameter Range
    Sugeno[alpha]\t\talpha in the range -1 to Infinity
    Yager[w]\t\t\tw in the range 0 to Infinity\
\>", "Special3",
  CellFrame->True,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Complement[FS1]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell["Complement[Rel1,Type->Yager[2]]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["User Defined Operator", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
FuzzyModify[fun,A] returns fuzzy set/relation A with membership grades \
adjusted according to the function.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["MyModFun[x_] := x^3", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell["FuzzyModify[MyModFun,FS1]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["Equality", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Equality[A,B] returns True if fuzzy sets/relations A and B are equal and \
False otherwise.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Equality[FS1,FS2]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["Inclusion", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Included[A,B] returns True if fuzzy set/relation A is included in fuzzy \
set/relation B and False otherwise.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Included[FS1,FS1]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]]}, Open]]}, Open]],

Cell[CellGroupData[{Cell["IV. Aggregation Operations", "Section",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Intersection (t-norm) Operations", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Intersections (standard and non-standard)", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Intersection[A,B,...,opts] returns a fuzzy set/relation which is the \
intersection of the listed sets/relations (A,B,...). This function has a Type \
option for specifying different types of intersections. The default setting \
is the standard min-intersection. Other valid types of intersections include: \
\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
   Type\t\t\t\tParameter Range
    Hamacher[v]\t\t\tv in the range 0 to Infinity
    Frank[s]\t\t\ts in the range 0 to Infinity except 1
    Yager[w]\t\t\tw in the range 0 to Infinity
    DuboisPrade[a]\t\ta in the range 0 to 1
    Dombi[alpha]\t\talpha in the range 0 to Infinity\
\>", "Special3",
  CellFrame->True,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Intersection[FS1,FS2]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell["Intersection[Rel1,Rel2,Type->Hamacher[2]]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell["Intersection[FS1,FS2,FS3,Type->Yager[13]]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Products", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
There is a collection of t-norm operators which can be grouped under the name \
products. Each of these operations is simply a specific case of one of the \
intersections listed before, so we don't include explicit functions for these \
operations. If you desire to use one one of these operators, however, you may \
use the appropriate intersection type from the table below. \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
   Product Type\t\tIntersection Type Equivalent
    Drastic Product\t\tHamacher[Infinity], Yager[0]
    Bounded Product\t\tYager[1]
    Einstein Product\t\tHamacher[2]
    Algebraic Product\t\tHamacher[1], DuboisPrade[1]
    Hamacher Product\t\tHamacher[0]\
\>", "Special3",
  CellFrame->True,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
For example, if you wanted the Bounded Product of FS1 and FS2, you would \
enter.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Intersection[FS1,FS2,Type->Yager[1]]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]]}, Open]],

Cell[CellGroupData[{Cell["Union (s-norm) Operations", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Unions (standard and non-standard)", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Union[A,B,...,opts] returns a fuzzy set/relation which is the union of the \
given sets/relations (A,B,...). This function has a type option for \
specifying different types of unions. The default is the standard max-union. \
Other valid union types include:\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
   Type\t\t\t\tParameter Range
    Hamacher[v]\t\t\tv in the range 0 to Infinity
    Frank[s]\t\t\ts in the range 0 to Infinity except 1
    Yager[w]\t\t\tw in the range 0 to Infinity
    DuboisPrade[a]\t\ta in the range 0 to 1
    Dombi[alpha]\t\talpha in the range 0 to Infinity\
\>", "Special3",
  CellFrame->True,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Union[FS1,FS2]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell["Union[FS1,FS2,Type->Frank[3]]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell["Union[FS1,FS2,FS3,Type->DuboisPrade[.8]]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Sums", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
There is a collection of s-norm operators which can be grouped under the name \
sums. Each of these operations is simply a specific case of one of the unions \
listed before, so we don't include explicit functions for these operations. \
If you desire to use one one of these operators, however, you may use the \
appropriate union type from the table below. \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
   Sum Type\t\t\tSum Type Equivalent
    Drastic Sum\t\t\tHamacher[Infinity], Yager[0]
    Bounded Sum\t\tYager[1]
    Einstein Sum\t\t\tHamacher[2]
    Algebraic Sum\t\tHamacher[1], DuboisPrade[1]
    Hamacher Sum\t\tHamacher[0]\
\>", "Special3",
  CellFrame->True,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
For example, if you wanted the Drastic Sum of FS1 and FS2, you could enter.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Union[FS1,FS2,Type->Hamacher[Infinity]]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Difference Operations", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["General difference", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Difference[A,B] returns a fuzzy set/relation which is the general difference \
between fuzzy sets/relations A and B.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Difference[FS1,FS2]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["Absolute difference", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
AbsoluteDifference[A,B] returns a fuzzy set/relation whose membership grades \
are equal to the absolute value of the difference between the membership \
grades of the element of fuzzy sets/relations A and B.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["AbsoluteDifference[FS1,FS2]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["Symmetric difference", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
SymmetricDifference[A,B] returns a fuzzy set/relation which is the symmetric \
difference between fuzzy sets/relations A and B.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["SymmetricDifference[FS1,FS2]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]]}, Open]],

Cell[CellGroupData[{Cell["Averaging Operations", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Arithmetic mean", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
ArithmeticMean[A1,A2,...,An] returns a fuzzy set/relation which is the \
arithmetic mean of the given fuzzy sets/relations (A1,..,An).\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["ArithmeticMean[FS1,FS2]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["Geometric mean", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
GeometricMean[A1,A2,..,An] returns a fuzzy set/relation which is the \
geometric mean of the given fuzzy sets/relations (A1,..,An).\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["GeometricMean[FS1,FS2]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["Harmonic mean", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
HarmonicMean[A1,A2,...,An] returns a fuzzy set/relation which is the harmonic \
mean of the given fuzzy sets/relations (A1,..,An).\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["HarmonicMean[Rel1,Rel2]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["Generalized mean", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
GeneralizedMean[A1,A2,...,An,alpha] returns a fuzzy set/relation which is the \
generalized mean of the given fuzzy sets/relations (A1,..,An) using the \
parameter alpha.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["GeneralizedMean[FS1,FS2,2]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]]}, Open]],

Cell[CellGroupData[{Cell["Miscellaneous Operations", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["User defined aggregator", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
GeneralAggregator[func,A1,A2,..,An] returns a fuzzy set/relation that is the \
result of combining the membership grades of the fuzzy sets/relations \
(A1,..,An) using function func.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["GeneralAggregator[Max[#]/2&,FS1,FS2]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]]}, Open]]}, Open]],

Cell[CellGroupData[{Cell["V. Composition Operations", "Section",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Set-up", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
To perform a composition between two fuzzy relation, you must have relations \
in which the second space of the first relation is equal to the first space \
of the second relation. We will create two such relations below to be used in \
the next section.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Crel1=FuzzyTrapezoid[{0,4,6,8},{1,3,5,7},
        UniversalSpace->{{0,8},{1,7}}]\
\>", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell["\<\
Crel2=FuzzyTrapezoid[{1,1,4,7},{0,2,4,5},
        UniversalSpace->{{1,7},{0,5}}]\
\>", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["Compositions", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Composition[A,B,opts] returns a fuzzy relation which is the result of \
performing a composition between fuzzy sets A and B. There is a Type option \
with this funtion which defaults to a MaxMin composition. Other types \
available are MaxProduct and MaxStar[fun] which allows you to define your own \
function for combining the relations.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Composition[Crel1,Crel2]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell["Composition[Crel1,Crel2,Type->MaxProduct]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell["Composition[Crel1,Crel2,Type->MaxStar[Min[#]/2&]]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell["\<\
Note: Make sure you are using the Composition function with appropriate \
relations (see Set-up section above).\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]]}, Open]],

Cell[CellGroupData[{Cell["VI. Visualization Functions", "Section",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Viewing Fuzzy Sets", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Digital Plot", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
FuzzyPlot[A,B,...,opts] displays a fuzzy set(s) as a plot of vertical lines \
whose heights represent the membership grades of the respective elements. \
This function has a number of options. One of the options called ShowDots \
displays a dot at the top of all the vertical lines. This option works best \
when plotting more than 1 fuzzy set. This function also takes all the options \
of the regular plot function as well as a couple options which are used in \
the next two subsections.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["FuzzyPlot[FS1]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell["FuzzyPlot[FS1,FS2,FS3,ShowDots->True]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["Line Plot", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
FuzzyPlot[A,B,...,PlotJoined->True] displays a fuzzy set(s) as a continuous \
line over the universal space.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["FuzzyPlot[FS1,FS2,PlotJoined->True]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["Crisp Set Plot", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
FuzzyPlot[A,B,...,Crisp->True] displays a fuzzy set(s) in a crisp form. This \
function allows you to plot classical sets in the correct form.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["FuzzyPlot[FS1,Crisp->True]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]]}, Open]],

Cell[CellGroupData[{Cell["Viewing Fuzzy Relations", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Digital 3D Plot", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
FuzzyPlot3D[A,B,...,opts] displays a fuzzy relation(s) as a plot of vertical \
lines with heights representing the respective membership grades. This \
function has an option called ShowDots which if set to True causes a dot to \
be place at the top of each vertical line.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["FuzzyPlot3D[Rel1]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell["FuzzyPlot3D[Rel1,Rel2,ShowDots->True]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["Surface Plot", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
FuzzySurfacePlot[A,B,...,opts] displays a surface plot of a fuzzy \
relation(s).\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["FuzzySurfacePlot[Rel1]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["Mesh Plot", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
FuzzySurfacePlot[A,B,...,HideSurfaces->True] displays a fuzzy relation(s) as \
a mesh. This option is nice for viewing more than one relation on the same \
graph.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["FuzzySurfacePlot[Rel1,HideSurfaces->True]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["Membership Matrix", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
ToMembershipMatrix[A] displays the membership matrix of fuzzy relation A.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["ToMembershipMatrix[Rel4]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]]}, Open]]}, Open]],

Cell[CellGroupData[{Cell["VII. Inferencing Operations", "Section",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Composition Based Inference", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
The inferencing functions in this package are a little more involved the \
other functions and consequently need some special inputs. Below we \
demonstrate how these functions can be used.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Defining Inputs", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
To create a model, a set of input fuzzy sets must be defined. Each individual \
fuzzy set used in the collection of input fuzzy sets may be created \
individually using some of the creation functions from this package, or they \
may all be created at once using the CreateFuzzySets function as shown below. \
\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
INPUT = {NegBig,NegSmall,Zero,PosSmall,PosBig} =
  CreateFuzzySets[5,UniversalSpace->{0,10}];\
\>", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell["FuzzyPlot[INPUT,PlotJoined->True]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell["\<\
The line above will create 5 fuzzy sets which will be named NegBig, \
NegSmall,...,PosBig. Notice that these fuzzy sets are labeled with linguistic \
terms which describe the overall input space.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["Defining Outputs", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
The next requirement for modelling is a collection of output fuzzy sets. In \
this example we will use the CreateFuzzySets function to create 5 bell shaped \
membership functions.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
OUTPUT = {NBO,NSO,ZO,PSO,PBO} =
  CreateFuzzySets[5,Type->Gaussian[3]];\
\>", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell["FuzzyPlot[OUTPUT,PlotJoined->True]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["Defining Rules", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
The final requirement for building a fuzzy model is a set of rules relating \
the input condition to the output response. These rules are formed as a list \
of if-then pairs, where the input condition is the first element of the pair, \
and the output response is the second element. Below is an example of a set \
of rules for the input and output we defined above.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
TheRules = {{NegBig,PBO},{NegSmall,PSO},
  {Zero,ZO},{PosBig,NBO}};\
\>", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell["\<\
In general, there can be a rule corresponding to each input membership \
function, but there shouldn't be more than one.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["Building the Model", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
To build a fuzzy model in the form of a fuzzy relation, call the BuildModel \
function with a set of model rules. This function applies the SetsToRelation \
function from this pack to all of the input-output pairs and unions the \
result to form a single fuzzy relation.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["FuzzyModel = BuildModel[TheRules];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell["FuzzySurfacePlot[FuzzyModel]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["Inferencing", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
To make an inference using the model created above, we need to provide a \
fuzzy input with a universal space equal to that of the input used to build \
the model. We will do that now.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
MyModelInp = FuzzyTrapezoid[3,5,5,7,
               UniversalSpace->{0,10}]\
\>", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell["\<\
Now we can use the CompositionBasedInference function to evaluate the model \
response to the input.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
CompositionBasedInference[A,B,opts] returns a fuzzy set that is the result of \
performing a composition based inference, where A is the input fuzzy set, and \
B is the model fuzzy relation. To obtain a crisp output, the output can be \
defuzzified using either the CenterOfArea or MeanOfMax strategies.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
CenterOfArea[
  CompositionBasedInference[MyModelInp,FuzzyModel,
    Defuzzify->MOM]]\
\>", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]]}, Open]],

Cell[CellGroupData[{Cell["Rule Based Inference ", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Like the CompositionBasedInference funtion, the RuleBasedInference function \
requires a fair amount of set-up to use. Below we will demonstrate how to \
set-up and use the RuleBasedInference function.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Defining Inputs", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
The first thing you need to do to use this inferencing function is to define \
your inputs. The inputs should be a sets of membership functions or fuzzy \
sets which are used to describe the input variable. When defining your inputs \
be sure to name the individual fuzzy sets that make up the input variable. We \
show how to do this below.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
FirstInput = {LE,LC,CE,RC,RI} =
  CreateFuzzySets[5,UniversalSpace->{0,100}];\
\>", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell["\<\
SecondInput = {RB,RU,RV,VE,LV,LU,LB} =
  CreateFuzzySets[7,UniversalSpace->{-90,270}];\
\>", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["Defining Outputs", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
The second thing that must be done to use the inferencing function is to \
define your output. This can be done in the same manner as we defined the \
inputs.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
TheOutput = {NB,NM,NS,ZE,PS,PM,PB} =
  CreateFuzzySets[7,UniversalSpace->{-30,30}];\
\>", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["Defining Rules", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
The final thing that must be done to use the RuleBasedInference funtion is to \
create a rule base which relates input conditions to the proper output \
response. The rule base should be a set of ordered triplets. The first two \
items in the triplet correspond to the input conditions, and the last item \
refers to the output condition. Below is a sample rule base which uses the \
inputs and outputs which we defined above.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
ControlRules=
  {{LE,RB,PS},{LC,RB,PM},{CE,RB,PM},{RC,RB,PB},{RI,RB,PB},
   {LE,RU,NS},{LC,RU,PS},{CE,RU,PM},{RC,RU,PB},{RI,RU,PB},
   {LE,RV,NM},{LC,RV,NS},{CE,RV,PS},{RC,RV,PM},{RI,RV,PB},
   {LE,VE,NM},{LC,VE,NM},{CE,VE,ZE},{RC,VE,PM},{RI,VE,PM},
   {LE,LV,NB},{LC,LV,NM},{CE,LV,NS},{RC,LV,PS},{RI,LV,PM},
   {LE,LU,NB},{LC,LU,NB},{CE,LU,NM},{RC,LU,NS},{RI,LU,PS},
   {LE,LB,NB},{LC,LB,NB},{CE,LB,NM},{RC,LB,NM},{RI,LB,NS}};\
\>", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["Inferencing", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
We now have all the parts needed to perform a RuleBasedInference. We can \
perform the inference by providing the function with the inputs and output, \
the rules, and a pair of crisp inputs. The order of the crisp inputs should \
match the order of the fuzzy set inputs. Also, the fuzzy set inputs should be \
in the order that was indicated by the control rules. In other words, the \
first item in the control rule triplet should correspond to the first set of \
fuzzy sets given to the inference function.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
RuleBasedInference[A,B,C,{Rules},a,b] returns a fuzzy set that is the result \
of performing a rule based inference, where A and B are the sets of input \
fuzzy sets, C is the set of output fuzzy sets, {Rules} is a list of rules, \
and a and b are the crisp inputs.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
rbi = RuleBasedInference[FirstInput,SecondInput,
        TheOutput,ControlRules,30,210]\
\>", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell["CenterOfArea[rbi]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]]}, Open]]}, Open]],

Cell[CellGroupData[{Cell["VIII. Arithmetic Operations", "Section",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Fuzzy Numbers", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
To use fuzzy arithmetic operations, you need to start with fuzzy numbers. \
Fuzzy numbers are generally defined as normalized convex fuzzy sets. In the \
examples below we will generally be using triangular fuzzy sets to represent \
fuzzy numbers, but other fuzzy sets can also be used. Because we want to use \
fuzzy numbers just as normal numbers, we need to have both positive and \
negative values. To account for this, we can set the default universal space \
to be a symmetric range around zero. We do this below with the SetOptions \
function.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["SetOptions[FuzzySet,UniversalSpace->{-35,35}]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["Real Number Fuzzy Arithmetic", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
The arithmetic operations are specifically designed to work with triangular \
or trapezoidal fuzzy numbers. These operations are a little different than \
the rest of the package operations in that they operate on lists of numbers \
which represent vertices of fuzzy sets rather than fuzzy sets themselves. \
This makes working with these operations a little awkward, but we show a \
convenient way to work with these functions below.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
First, we are going to need some numbers to operate on. As mentioned earlier, \
these operations work on lists of vertices, so we will create two lists below \
which will represent two triangular fuzzy numbers. \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["num1 := {-2,3,3,8}", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell["num2 := {7,10,10,13}", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell["\<\
These lists can be converted to normal fuzzy sets by using the lists as \
arguments to the FuzzyTrapezoid function. For example, you could type:\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["FuzzyNum1 = FuzzyTrapezoid[num1]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Fuzzy Addition", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
FuzzyPlus[{a1,b1,c1,d1},{a2,b2,c2,d2},opts] returns the fuzzy sum between the \
two fuzzy numbers represented by the two lists. The fuzzy sum will be \
returned as an unevaluated fuzzy trapezoid. To evaluate the FuzzyTrapezoid \
use ReleaseHold.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Sum1 = FuzzyPlus[num1,num2]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell["\<\
The function above will return an unevaluated fuzzy trapezoid. To evaluate \
the fuzzy trapezoid to return a fuzzy set, you must use the ReleaseHold \
function. For example, you could type:\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["FuzzySum = ReleaseHold[Sum1]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["Fuzzy Subtraction", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
FuzzyMinus[{a1,b1,c1,d1},{a2,b2,c2,d2},opts] returns the fuzzy difference \
between the two fuzzy numbers represented by the two lists. The fuzzy \
difference will be returned as an unevaluated fuzzy trapezoid. To evaluate \
the FuzzyTrapezoid use ReleaseHold.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Diff1 = FuzzyMinus[num1,num2]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell["FuzzyDiff = ReleaseHold[Diff1]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["Multiplication by a Constant", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
FuzzyConstantTimes[{a,b,c,d},k,opts] returns the fuzzy number which is the \
result of the multiplication of constant k by the fuzzy number represented by \
the list, {a,b,c,d}. The result will be returned as an unevaluated fuzzy \
trapezoid. To evaluate the FuzzyTrapezoid use ReleaseHold.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Prod1 = FuzzyConstantTimes[num1,-3]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["Image of a Fuzzy Number", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
FuzzyImage[{a,b,c,d}] returns the image of the fuzzy number represented by \
the list. The result will be returned as an unevaluated fuzzy trapezoid. To \
evaluate the FuzzyTrapezoid use ReleaseHold.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Im1 = FuzzyImage[num1]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]]}, Open]],

Cell[CellGroupData[{Cell["Discrete Fuzzy Arithmetic", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Unlike the real number fuzzy arithmetic functions, the discrete fuzzy \
arithmetic functions take arguments in the form of normal fuzzy sets. To \
demonstrate the discrete fuzzy arithmetic functions, we will start by \
defining two triangular fuzzy sets which will represent fuzzy numbers 3 and \
5.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["TriFS1 = FuzzyTrapezoid[1,3,3,5];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell["TriFS2 = FuzzyTrapezoid[3,5,5,7];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Fuzzy Addition", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
DiscreteFuzzyPlus[A,B] returns a fuzzy set that is the result of applying \
fuzzy addition to fuzzy sets A and B.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["DiscreteFuzzyPlus[TriFS1,TriFS2]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["Fuzzy Subtraction", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
DiscreteFuzzyMinus[A,B] returns a fuzzy set that is the result of applying \
fuzzy subtraction to fuzzy set A and B.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["DiscreteFuzzyMinus[TriFS1,TriFS2]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["Fuzzy Multiplication", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
DiscreteFuzzyMultiply[A,B] returns a fuzzy set which is the result of \
perfroming a discrete fuzzy multiplication of fuzzy sets A and B.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["DiscreteFuzzyMultiply[TriFS1,TriFS2]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["Fuzzy Image", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
DiscreteFuzzyImage[A] returns a fuzzy set that is the image of fuzzy set A.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["DiscreteFuzzyImage[TriFS1]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}},
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[1]]}, Open]]}, Open]]}, Open]]}, Open]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{496, 599},
WindowMargins->{{165, Automatic}, {23, Automatic}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False}
]



(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 93, 7, 70, "Title"],

Cell[CellGroupData[{
Cell[1855, 60, 70, 1, 70, "Section"],
Cell[1928, 63, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[2001, 66, 80, 1, 70, "Subsection"],
Cell[2084, 69, 629, 10, 70, "Text"],
Cell[2716, 81, 358, 6, 70, "Text"]
}, Open  ]],
Cell[3086, 89, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[3159, 92, 66, 1, 70, "Subsection"],
Cell[3228, 95, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[3301, 98, 71, 1, 70, "Subsubsection"],
Cell[3375, 101, 1108, 16, 70, "Text"],
Cell[4486, 119, 187, 6, 70, "Special2"]
}, Open  ]],
Cell[4685, 127, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[4758, 130, 76, 1, 70, "Subsubsection"],
Cell[4837, 133, 936, 14, 70, "Text"],
Cell[5776, 149, 300, 7, 70, "Special2"]
}, Open  ]]
}, Open  ]],
Cell[6097, 158, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[6170, 161, 83, 1, 70, "Subsection"],
Cell[6256, 164, 150, 4, 70, "Text"],
Cell[6409, 170, 103, 2, 70, "Input"],
Cell[6515, 174, 304, 6, 70, "SmallText"],
Cell[6822, 182, 169, 4, 70, "Text"]
}, Open  ]]
}, Open  ]],
Cell[7012, 188, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[7085, 191, 74, 1, 70, "Section"],
Cell[7162, 194, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[7235, 197, 74, 1, 70, "Subsection"],
Cell[7312, 200, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[7385, 203, 88, 1, 70, "Subsubsection"],
Cell[7476, 206, 622, 10, 70, "Text"],
Cell[8101, 218, 186, 4, 70, "Input"],
Cell[8290, 224, 396, 7, 70, "Text"],
Cell[8689, 233, 147, 4, 70, "Input"],
Cell[8839, 239, 166, 4, 70, "Input"],
Cell[9008, 245, 307, 6, 70, "Text"]
}, Open  ]],
Cell[9327, 253, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[9400, 256, 92, 1, 70, "Subsubsection"],
Cell[9495, 259, 291, 6, 70, "Text"],
Cell[9789, 267, 129, 3, 70, "Text"],
Cell[9921, 272, 284, 9, 70, "Input"],
Cell[10208, 283, 185, 4, 70, "Input"],
Cell[10396, 289, 187, 4, 70, "Text"]
}, Open  ]],
Cell[10595, 295, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[10668, 298, 85, 1, 70, "Subsubsection"],
Cell[10756, 301, 272, 5, 70, "Text"],
Cell[11031, 308, 180, 4, 70, "Input"]
}, Open  ]],
Cell[11223, 314, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[11296, 317, 84, 1, 70, "Subsubsection"],
Cell[11383, 320, 384, 7, 70, "Text"],
Cell[11770, 329, 225, 7, 70, "Input"],
Cell[11998, 338, 169, 4, 70, "Input"],
Cell[12170, 344, 226, 7, 70, "Input"],
Cell[12399, 353, 169, 4, 70, "Input"]
}, Open  ]],
Cell[12580, 359, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[12653, 362, 85, 1, 70, "Subsubsection"],
Cell[12741, 365, 172, 4, 70, "Text"],
Cell[12916, 371, 213, 7, 70, "Input"]
}, Open  ]]
}, Open  ]],
Cell[13150, 380, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[13223, 383, 79, 1, 70, "Subsection"],
Cell[13305, 386, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[13378, 389, 93, 1, 70, "Subsubsection"],
Cell[13474, 392, 511, 8, 70, "Text"],
Cell[13988, 402, 227, 7, 70, "Input"]
}, Open  ]],
Cell[14227, 411, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[14300, 414, 97, 1, 70, "Subsubsection"],
Cell[14400, 417, 428, 7, 70, "Text"],
Cell[14831, 426, 165, 4, 70, "Input"],
Cell[14999, 432, 216, 7, 70, "Input"]
}, Open  ]],
Cell[15227, 441, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[15300, 444, 101, 1, 70, "Subsubsection"],
Cell[15404, 447, 307, 6, 70, "Text"],
Cell[15714, 455, 167, 4, 70, "Input"]
}, Open  ]],
Cell[15893, 461, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[15966, 464, 106, 1, 70, "Subsubsection"],
Cell[16075, 467, 374, 7, 70, "Text"],
Cell[16452, 476, 284, 9, 70, "Input"],
Cell[16739, 487, 171, 4, 70, "Input"]
}, Open  ]],
Cell[16922, 493, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[16995, 496, 90, 1, 70, "Subsubsection"],
Cell[17088, 499, 175, 4, 70, "Text"],
Cell[17266, 505, 238, 7, 70, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[17534, 514, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[17607, 517, 75, 1, 70, "Section"],
Cell[17685, 520, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[17758, 523, 82, 1, 70, "Subsection"],
Cell[17843, 526, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[17916, 529, 64, 1, 70, "Subsubsection"],
Cell[17983, 532, 132, 3, 70, "Text"],
Cell[18118, 537, 144, 4, 70, "Input"],
Cell[18265, 543, 50, 1, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18347, 546, 69, 1, 70, "Subsubsection"],
Cell[18419, 549, 137, 4, 70, "Text"],
Cell[18559, 555, 149, 4, 70, "Input"],
Cell[18711, 561, 50, 1, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18793, 564, 78, 1, 70, "Subsubsection"],
Cell[18874, 567, 189, 4, 70, "Text"],
Cell[19066, 573, 157, 4, 70, "Input"],
Cell[19226, 579, 50, 1, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19308, 582, 90, 1, 70, "Subsubsection"],
Cell[19401, 585, 308, 6, 70, "Text"],
Cell[19712, 593, 150, 4, 70, "Input"],
Cell[19865, 599, 166, 4, 70, "Input"],
Cell[20034, 605, 50, 1, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20116, 608, 87, 1, 70, "Subsubsection"],
Cell[20206, 611, 204, 4, 70, "Text"],
Cell[20413, 617, 163, 4, 70, "Input"],
Cell[20579, 623, 50, 1, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20661, 626, 65, 1, 70, "Subsubsection"],
Cell[20729, 629, 148, 4, 70, "Text"],
Cell[20880, 635, 145, 4, 70, "Input"],
Cell[21028, 641, 50, 1, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21110, 644, 65, 1, 70, "Subsubsection"],
Cell[21178, 647, 157, 4, 70, "Text"],
Cell[21338, 653, 145, 4, 70, "Input"],
Cell[21486, 659, 50, 1, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21568, 662, 73, 1, 70, "Subsubsection"],
Cell[21644, 665, 183, 4, 70, "Text"],
Cell[21830, 671, 155, 4, 70, "Input"],
Cell[21988, 677, 50, 1, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22070, 680, 80, 1, 70, "Subsubsection"],
Cell[22153, 683, 177, 4, 70, "Text"],
Cell[22333, 689, 161, 4, 70, "Input"],
Cell[22497, 695, 50, 1, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22579, 698, 73, 1, 70, "Subsubsection"],
Cell[22655, 701, 170, 4, 70, "Text"],
Cell[22828, 707, 152, 4, 70, "Input"],
Cell[22983, 713, 50, 1, 70, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[23074, 716, 87, 1, 70, "Subsection"],
Cell[23164, 719, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[23237, 722, 69, 1, 70, "Subsubsection"],
Cell[23309, 725, 173, 4, 70, "Text"],
Cell[23485, 731, 154, 4, 70, "Input"],
Cell[23642, 737, 175, 4, 70, "Text"],
Cell[23820, 743, 155, 4, 70, "Input"],
Cell[23978, 749, 155, 4, 70, "Text"],
Cell[24136, 755, 155, 4, 70, "Input"],
Cell[24294, 761, 50, 1, 70, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[24385, 764, 108, 1, 70, "Subsection"],
Cell[24496, 767, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[24569, 770, 71, 1, 70, "Subsubsection"],
Cell[24643, 773, 197, 4, 70, "Text"],
Cell[24843, 779, 149, 4, 70, "Input"],
Cell[24995, 785, 50, 1, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25077, 788, 66, 1, 70, "Subsubsection"],
Cell[25146, 791, 197, 4, 70, "Text"],
Cell[25346, 797, 145, 4, 70, "Input"],
Cell[25494, 803, 50, 1, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25576, 806, 76, 1, 70, "Subsubsection"],
Cell[25655, 809, 246, 6, 70, "Text"],
Cell[25904, 817, 155, 4, 70, "Input"],
Cell[26062, 823, 50, 1, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26144, 826, 67, 1, 70, "Subsubsection"],
Cell[26214, 829, 137, 4, 70, "Text"],
Cell[26354, 835, 147, 4, 70, "Input"],
Cell[26504, 841, 50, 1, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26586, 844, 96, 1, 70, "Subsubsection"],
Cell[26685, 847, 294, 6, 70, "Text"],
Cell[26982, 855, 212, 6, 70, "Special3"],
Cell[27197, 863, 148, 4, 70, "Input"],
Cell[27348, 869, 164, 4, 70, "Input"],
Cell[27515, 875, 50, 1, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27597, 878, 79, 1, 70, "Subsubsection"],
Cell[27679, 881, 165, 4, 70, "Text"],
Cell[27847, 887, 152, 4, 70, "Input"],
Cell[28002, 893, 158, 4, 70, "Input"],
Cell[28163, 899, 50, 1, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28245, 902, 66, 1, 70, "Subsubsection"],
Cell[28314, 905, 148, 4, 70, "Text"],
Cell[28465, 911, 150, 4, 70, "Input"],
Cell[28618, 917, 50, 1, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28700, 920, 67, 1, 70, "Subsubsection"],
Cell[28770, 923, 166, 4, 70, "Text"],
Cell[28939, 929, 150, 4, 70, "Input"],
Cell[29092, 935, 50, 1, 70, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[29192, 938, 78, 1, 70, "Section"],
Cell[29273, 941, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[29346, 944, 87, 1, 70, "Subsection"],
Cell[29436, 947, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[29509, 950, 99, 1, 70, "Subsubsection"],
Cell[29611, 953, 366, 7, 70, "Text"],
Cell[29980, 962, 360, 9, 70, "Special3"],
Cell[30343, 973, 154, 4, 70, "Input"],
Cell[30500, 979, 174, 4, 70, "Input"],
Cell[30677, 985, 174, 4, 70, "Input"]
}, Open  ]],
Cell[30863, 991, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[30936, 994, 66, 1, 70, "Subsubsection"],
Cell[31005, 997, 434, 7, 70, "Text"],
Cell[31442, 1006, 336, 9, 70, "Special3"],
Cell[31781, 1017, 138, 4, 70, "Text"],
Cell[31922, 1023, 169, 4, 70, "Input"],
Cell[32094, 1029, 50, 1, 70, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[32185, 1032, 80, 1, 70, "Subsection"],
Cell[32268, 1035, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[32341, 1038, 92, 1, 70, "Subsubsection"],
Cell[32436, 1041, 315, 6, 70, "Text"],
Cell[32754, 1049, 360, 9, 70, "Special3"],
Cell[33117, 1060, 147, 4, 70, "Input"],
Cell[33267, 1066, 162, 4, 70, "Input"],
Cell[33432, 1072, 173, 4, 70, "Input"]
}, Open  ]],
Cell[33617, 1078, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[33690, 1081, 62, 1, 70, "Subsubsection"],
Cell[33755, 1084, 416, 7, 70, "Text"],
Cell[34174, 1093, 309, 9, 70, "Special3"],
Cell[34486, 1104, 132, 3, 70, "Text"],
Cell[34621, 1109, 172, 4, 70, "Input"]
}, Open  ]]
}, Open  ]],
Cell[34814, 1115, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[34887, 1118, 76, 1, 70, "Subsection"],
Cell[34966, 1121, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[35039, 1124, 76, 1, 70, "Subsubsection"],
Cell[35118, 1127, 173, 4, 70, "Text"],
Cell[35294, 1133, 152, 4, 70, "Input"],
Cell[35449, 1139, 50, 1, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[35531, 1142, 77, 1, 70, "Subsubsection"],
Cell[35611, 1145, 265, 5, 70, "Text"],
Cell[35879, 1152, 160, 4, 70, "Input"],
Cell[36042, 1158, 50, 1, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[36124, 1161, 78, 1, 70, "Subsubsection"],
Cell[36205, 1164, 184, 4, 70, "Text"],
Cell[36392, 1170, 161, 4, 70, "Input"],
Cell[36556, 1176, 50, 1, 70, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[36647, 1179, 75, 1, 70, "Subsection"],
Cell[36725, 1182, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[36798, 1185, 73, 1, 70, "Subsubsection"],
Cell[36874, 1188, 191, 4, 70, "Text"],
Cell[37068, 1194, 156, 4, 70, "Input"],
Cell[37227, 1200, 50, 1, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[37309, 1203, 72, 1, 70, "Subsubsection"],
Cell[37384, 1206, 188, 4, 70, "Text"],
Cell[37575, 1212, 155, 4, 70, "Input"],
Cell[37733, 1218, 50, 1, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[37815, 1221, 71, 1, 70, "Subsubsection"],
Cell[37889, 1224, 187, 4, 70, "Text"],
Cell[38079, 1230, 156, 4, 70, "Input"],
Cell[38238, 1236, 50, 1, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[38320, 1239, 74, 1, 70, "Subsubsection"],
Cell[38397, 1242, 227, 5, 70, "Text"],
Cell[38627, 1249, 159, 4, 70, "Input"],
Cell[38789, 1255, 50, 1, 70, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[38880, 1258, 79, 1, 70, "Subsection"],
Cell[38962, 1261, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[39035, 1264, 81, 1, 70, "Subsubsection"],
Cell[39119, 1267, 239, 5, 70, "Text"],
Cell[39361, 1274, 169, 4, 70, "Input"],
Cell[39533, 1280, 50, 1, 70, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[39633, 1283, 77, 1, 70, "Section"],
Cell[39713, 1286, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[39786, 1289, 61, 1, 70, "Subsection"],
Cell[39850, 1292, 311, 6, 70, "Text"],
Cell[40164, 1300, 221, 7, 70, "Input"],
Cell[40388, 1309, 221, 7, 70, "Input"],
Cell[40612, 1318, 50, 1, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[40694, 1321, 67, 1, 70, "Subsection"],
Cell[40764, 1324, 396, 7, 70, "Text"],
Cell[41163, 1333, 157, 4, 70, "Input"],
Cell[41323, 1339, 174, 4, 70, "Input"],
Cell[41500, 1345, 182, 4, 70, "Input"],
Cell[41685, 1351, 168, 4, 70, "Text"],
Cell[41856, 1357, 50, 1, 70, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[41947, 1360, 79, 1, 70, "Section"],
Cell[42029, 1363, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[42102, 1366, 73, 1, 70, "Subsection"],
Cell[42178, 1369, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[42251, 1372, 70, 1, 70, "Subsubsection"],
Cell[42324, 1375, 547, 9, 70, "Text"],
Cell[42874, 1386, 147, 4, 70, "Input"],
Cell[43024, 1392, 170, 4, 70, "Input"],
Cell[43197, 1398, 50, 1, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[43279, 1401, 67, 1, 70, "Subsubsection"],
Cell[43349, 1404, 165, 4, 70, "Text"],
Cell[43517, 1410, 168, 4, 70, "Input"],
Cell[43688, 1416, 50, 1, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[43770, 1419, 72, 1, 70, "Subsubsection"],
Cell[43845, 1422, 199, 4, 70, "Text"],
Cell[44047, 1428, 159, 4, 70, "Input"],
Cell[44209, 1434, 50, 1, 70, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[44300, 1437, 78, 1, 70, "Subsection"],
Cell[44381, 1440, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[44454, 1443, 73, 1, 70, "Subsubsection"],
Cell[44530, 1446, 329, 6, 70, "Text"],
Cell[44862, 1454, 150, 4, 70, "Input"],
Cell[45015, 1460, 170, 4, 70, "Input"],
Cell[45188, 1466, 50, 1, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[45270, 1469, 70, 1, 70, "Subsubsection"],
Cell[45343, 1472, 137, 4, 70, "Text"],
Cell[45483, 1478, 155, 4, 70, "Input"],
Cell[45641, 1484, 50, 1, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[45723, 1487, 67, 1, 70, "Subsubsection"],
Cell[45793, 1490, 219, 5, 70, "Text"],
Cell[46015, 1497, 174, 4, 70, "Input"],
Cell[46192, 1503, 50, 1, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[46274, 1506, 75, 1, 70, "Subsubsection"],
Cell[46352, 1509, 130, 3, 70, "Text"],
Cell[46485, 1514, 157, 4, 70, "Input"],
Cell[46645, 1520, 50, 1, 70, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[46745, 1523, 79, 1, 70, "Section"],
Cell[46827, 1526, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[46900, 1529, 82, 1, 70, "Subsection"],
Cell[46985, 1532, 246, 5, 70, "Text"],
Cell[47234, 1539, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[47307, 1542, 73, 1, 70, "Subsubsection"],
Cell[47383, 1545, 366, 7, 70, "Text"],
Cell[47752, 1554, 234, 7, 70, "Input"],
Cell[47989, 1563, 166, 4, 70, "Input"],
Cell[48158, 1569, 252, 5, 70, "Text"],
Cell[48413, 1576, 50, 1, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[48495, 1579, 74, 1, 70, "Subsubsection"],
Cell[48572, 1582, 236, 5, 70, "Text"],
Cell[48811, 1589, 212, 7, 70, "Input"],
Cell[49026, 1598, 167, 4, 70, "Input"],
Cell[49196, 1604, 50, 1, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[49278, 1607, 72, 1, 70, "Subsubsection"],
Cell[49353, 1610, 423, 7, 70, "Text"],
Cell[49779, 1619, 208, 7, 70, "Input"],
Cell[49990, 1628, 177, 4, 70, "Text"],
Cell[50170, 1634, 50, 1, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[50252, 1637, 76, 1, 70, "Subsubsection"],
Cell[50331, 1640, 327, 6, 70, "Text"],
Cell[50661, 1648, 167, 4, 70, "Input"],
Cell[50831, 1654, 161, 4, 70, "Input"],
Cell[50995, 1660, 50, 1, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[51077, 1663, 69, 1, 70, "Subsubsection"],
Cell[51149, 1666, 241, 5, 70, "Text"],
Cell[51393, 1673, 216, 7, 70, "Input"],
Cell[51612, 1682, 157, 4, 70, "Text"],
Cell[51772, 1688, 360, 6, 70, "Text"],
Cell[52135, 1696, 226, 8, 70, "Input"],
Cell[52364, 1706, 50, 1, 70, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[52455, 1709, 76, 1, 70, "Subsection"],
Cell[52534, 1712, 258, 5, 70, "Text"],
Cell[52795, 1719, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[52868, 1722, 73, 1, 70, "Subsubsection"],
Cell[52944, 1725, 398, 7, 70, "Text"],
Cell[53345, 1734, 218, 7, 70, "Input"],
Cell[53566, 1743, 227, 7, 70, "Input"],
Cell[53796, 1752, 50, 1, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[53878, 1755, 74, 1, 70, "Subsubsection"],
Cell[53955, 1758, 215, 5, 70, "Text"],
Cell[54173, 1765, 224, 7, 70, "Input"],
Cell[54400, 1774, 50, 1, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[54482, 1777, 72, 1, 70, "Subsubsection"],
Cell[54557, 1780, 483, 8, 70, "Text"],
Cell[55043, 1790, 568, 13, 70, "Input"],
Cell[55614, 1805, 50, 1, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[55696, 1808, 69, 1, 70, "Subsubsection"],
Cell[55768, 1811, 566, 9, 70, "Text"],
Cell[56337, 1822, 322, 6, 70, "Text"],
Cell[56662, 1830, 228, 7, 70, "Input"],
Cell[56893, 1839, 150, 4, 70, "Input"],
Cell[57046, 1845, 50, 1, 70, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[57146, 1848, 79, 1, 70, "Section"],
Cell[57228, 1851, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[57301, 1854, 68, 1, 70, "Subsection"],
Cell[57372, 1857, 607, 10, 70, "Text"],
Cell[57982, 1869, 178, 4, 70, "Input"],
Cell[58163, 1875, 50, 1, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[58245, 1878, 83, 1, 70, "Subsection"],
Cell[58331, 1881, 491, 8, 70, "Text"],
Cell[58825, 1891, 268, 5, 70, "Text"],
Cell[59096, 1898, 151, 4, 70, "Input"],
Cell[59250, 1904, 153, 4, 70, "Input"],
Cell[59406, 1910, 201, 4, 70, "Text"],
Cell[59610, 1916, 165, 4, 70, "Input"],
Cell[59778, 1922, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[59851, 1925, 72, 1, 70, "Subsubsection"],
Cell[59926, 1928, 302, 6, 70, "Text"],
Cell[60231, 1936, 160, 4, 70, "Input"],
Cell[60394, 1942, 246, 5, 70, "Text"],
Cell[60643, 1949, 161, 4, 70, "Input"],
Cell[60807, 1955, 50, 1, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[60889, 1958, 75, 1, 70, "Subsubsection"],
Cell[60967, 1961, 317, 6, 70, "Text"],
Cell[61287, 1969, 162, 4, 70, "Input"],
Cell[61452, 1975, 163, 4, 70, "Input"],
Cell[61618, 1981, 50, 1, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[61700, 1984, 86, 1, 70, "Subsubsection"],
Cell[61789, 1987, 347, 6, 70, "Text"],
Cell[62139, 1995, 168, 4, 70, "Input"],
Cell[62310, 2001, 50, 1, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[62392, 2004, 81, 1, 70, "Subsubsection"],
Cell[62476, 2007, 256, 5, 70, "Text"],
Cell[62735, 2014, 155, 4, 70, "Input"],
Cell[62893, 2020, 50, 1, 70, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[62984, 2023, 80, 1, 70, "Subsection"],
Cell[63067, 2026, 356, 7, 70, "Text"],
Cell[63426, 2035, 166, 4, 70, "Input"],
Cell[63595, 2041, 166, 4, 70, "Input"],
Cell[63764, 2047, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[63837, 2050, 72, 1, 70, "Subsubsection"],
Cell[63912, 2053, 170, 4, 70, "Text"],
Cell[64085, 2059, 165, 4, 70, "Input"],
Cell[64253, 2065, 50, 1, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[64335, 2068, 75, 1, 70, "Subsubsection"],
Cell[64413, 2071, 173, 4, 70, "Text"],
Cell[64589, 2077, 166, 4, 70, "Input"],
Cell[64758, 2083, 50, 1, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[64840, 2086, 78, 1, 70, "Subsubsection"],
Cell[64921, 2089, 194, 4, 70, "Text"],
Cell[65118, 2095, 169, 4, 70, "Input"],
Cell[65290, 2101, 50, 1, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[65372, 2104, 69, 1, 70, "Subsubsection"],
Cell[65444, 2107, 132, 3, 70, "Text"],
Cell[65579, 2112, 159, 4, 70, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)
